---
title: wls_datasource
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a datasource in an WebLogic domain.

Here is an example on how you should use this:

    # this will use default as wls_setting identifier, no XA properties
    wls_datasource { 'hrDS':
      ensure                           => 'present',
      connectioncreationretryfrequency => '0',
      drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
      extraproperties                  => ['SendStreamAsBlob=true', 'oracle.net.CONNECT_TIMEOUT=10001'],
      fanenabled                       => '0',
      globaltransactionsprotocol       => 'TwoPhaseCommit',
      initialcapacity                  => '2',
      initsql                          => 'None',
      jndinames                        => ['jdbc/hrDS', 'jdbc/hrDS2'],
      maxcapacity                      => '15',
      mincapacity                      => '1',
      rowprefetchenabled               => '0',
      rowprefetchsize                  => '48',
      secondstotrustidlepoolconnection => '10',
      statementcachesize               => '10',
      target                           => ['wlsServer1', 'wlsServer2'],
      targettype                       => ['Server', 'Server'],
      testconnectionsonreserve         => '0',
      testfrequency                    => '120',
      testtablename                    => 'SQL SELECT 1 FROM DUAL',
      url                              => 'jdbc:oracle:thin:@dbagent2.alfa.local:1521/test.oracle.com',
      user                             => 'hr',
      usexa                            => '0',
    }

In this example you are managing a datasource in the default domain. When you want to
manage a datasource in a specific domain, you can use:

    # this will use default as wls_setting identifier, no XA properties
    wls_datasource{'mydomain/hrDS':
      ...
      ensure                           => 'present',
      connectioncreationretryfrequency => '0',
      drivername                       => 'oracle.jdbc.xa.client.OracleXADataSource',
      ...
    }

Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/jdbc.htm#INTRO215) for more information
about configuring and managing datasources.

## Attributes



Attribute Name                                                                                                       | Short Description                                                                                                                                                                                                                                 |
-------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[compatibility_name](#wls_datasource_compatibility_name)                                                             |  This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean.                                                                                                       |
[connectioncreationretryfrequency](#wls_datasource_connectioncreationretryfrequency)                                 | The number of seconds between attempts to establish connections to the database.                                                                                                                                                                  |
[datasource_name](#wls_datasource_datasource_name)                                                                   | The datasource name.                                                                                                                                                                                                                              |
[deployment_order](#wls_datasource_deployment_order)                                                                 | An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.                                                                                                                       |
[deployment_principal_name](#wls_datasource_deployment_principal_name)                                               | A string value that indicates the principal that should be used when deploying the file or archive during startup and shutdown.                                                                                                                   |
[domain](#wls_datasource_domain)                                                                                     | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                                           |
[driver_name](#wls_datasource_driver_name)                                                                           | The full package name of JDBC driver class used to create the physical database connections in the connection pool in the data source.                                                                                                            |
[driver_password](#wls_datasource_driver_password)                                                                   | The password attribute passed to the JDBC driver when creating physical database connections.                                                                                                                                                     |
[driver_url](#wls_datasource_driver_url)                                                                             | The URL of the database to connect to.                                                                                                                                                                                                            |
[driver_use_password_indirection](#wls_datasource_driver_use_password_indirection)                                   |  Specifies whether the database credentials are to be obtained from the credential mapper using the "user" property as the key.                                                                                                                   |
[driver_use_xa_data_source_interface](#wls_datasource_driver_use_xa_data_source_interface)                           | Specifies that WebLogic Server should use the XA interface of the JDBC driver.                                                                                                                                                                    |
[drivername](#wls_datasource_drivername)                                                                             | The drivername.                                                                                                                                                                                                                                   |
[ds_algorithm_type](#wls_datasource_ds_algorithm_type)                                                               | The algorithm determines the connection request processing for the multi data source.                                                                                                                                                             |
[ds_connection_pool_failover_callback_handler](#wls_datasource_ds_connection_pool_failover_callback_handler)         | The name of the application class to handle the callback sent when a multi data source is ready to failover or fail back connection requests to another data source within the multi data source.                                                 |
[ds_data_source_list](#wls_datasource_ds_data_source_list)                                                           | The list of data sources to which the multi data source will route connection requests.                                                                                                                                                           |
[ds_failover_request_if_busy](#wls_datasource_ds_failover_request_if_busy)                                           | For multi data sources with the <code>failover</code> algorithm, enables the multi data source to failover connection requests to the next data source if all connections in the current data source are in use.                                  |
[ds_global_transactions_protocol](#wls_datasource_ds_global_transactions_protocol)                                   | Determines the transaction protocol (global transaction processing behavior) for the data source.                                                                                                                                                 |
[ds_jndi_names](#wls_datasource_ds_jndi_names)                                                                       | The JNDI path to where this Data Source is bound.                                                                                                                                                                                                 |
[ds_keep_conn_after_global_tx](#wls_datasource_ds_keep_conn_after_global_tx)                                         | Enables WebLogic Server to keep the physical database connection associated with the logical connection when committing a global transaction instead releasing it and getting another physical connection when needed.                            |
[ds_keep_conn_after_local_tx](#wls_datasource_ds_keep_conn_after_local_tx)                                           | Enables WebLogic Server to keep the physical database connection associated with the logical connection when committing a local transaction instead releasing it and getting another physical connection when needed.                             |
[ds_proxy_switching_callback](#wls_datasource_ds_proxy_switching_callback)                                           | The name of the switching callback class for a Proxy data source.                                                                                                                                                                                 |
[ds_proxy_switching_properties](#wls_datasource_ds_proxy_switching_properties)                                       | Specifies the switching properties passed to the switching callback method for a Proxy data source.                                                                                                                                               |
[ds_row_prefetch](#wls_datasource_ds_row_prefetch)                                                                   | Enables multiple rows to be "prefetched" (that is, sent from the server to the client) in one server access.                                                                                                                                      |
[ds_row_prefetch_size](#wls_datasource_ds_row_prefetch_size)                                                         | If row prefetching is enabled, specifies the number of result set rows to prefetch for a client.                                                                                                                                                  |
[ds_scope](#wls_datasource_ds_scope)                                                                                 | Specifies the scoping of the data source.                                                                                                                                                                                                         |
[ds_stream_chunk_size](#wls_datasource_ds_stream_chunk_size)                                                         | Specifies the data chunk size for steaming data types.                                                                                                                                                                                            |
[ensure](#wls_datasource_ensure)                                                                                     | The basic property that the resource should be in.                                                                                                                                                                                                |
[extraproperties](#wls_datasource_extraproperties)                                                                   | The extra properties.                                                                                                                                                                                                                             |
[fanenabled](#wls_datasource_fanenabled)                                                                             | Enables the data source to subscribe to and process Oracle FAN events.                                                                                                                                                                            |
[globaltransactionsprotocol](#wls_datasource_globaltransactionsprotocol)                                             | The global Transactions Protocol.                                                                                                                                                                                                                 |
[initialcapacity](#wls_datasource_initialcapacity)                                                                   | The number of physical connections to create when creating the connection pool in the data source.                                                                                                                                                |
[initsql](#wls_datasource_initsql)                                                                                   | SQL statement to execute that will initialize newly created physical database connections.                                                                                                                                                        |
[jndinames](#wls_datasource_jndinames)                                                                               | The datasource jndi names.                                                                                                                                                                                                                        |
[maxcapacity](#wls_datasource_maxcapacity)                                                                           | The max capacity of the datasource.                                                                                                                                                                                                               |
[mincapacity](#wls_datasource_mincapacity)                                                                           | The min capacity of the datasource.                                                                                                                                                                                                               |
[module_type](#wls_datasource_module_type)                                                                           | The values match those defined by jsr88.                                                                                                                                                                                                          |
[name](#wls_datasource_name)                                                                                         | The name.                                                                                                                                                                                                                                         |
[notes](#wls_datasource_notes)                                                                                       | Optional information that you can include to describe this configuration.                                                                                                                                                                         |
[onsnodelist](#wls_datasource_onsnodelist)                                                                           | A comma-separate list of ONS daemon listen addresses and ports to which connect to for receiving ONS-based FAN events.                                                                                                                            |
[oracle_active_gridlink](#wls_datasource_oracle_active_gridlink)                                                     | Indicates a configured Active GridLink datasource.                                                                                                                                                                                                |
[oracle_affinity_policy](#wls_datasource_oracle_affinity_policy)                                                     | Specifies the affinity policy for the datasource.                                                                                                                                                                                                 |
[oracle_connection_initialization_callback](#wls_datasource_oracle_connection_initialization_callback)               | The name of the Connection Initialization Callback class.                                                                                                                                                                                         |
[oracle_enable_java_net_fast_path](#wls_datasource_oracle_enable_java_net_fast_path)                                 | Deprecated.                                                                                                                                                                                                                                       |
[oracle_fan_enabled](#wls_datasource_oracle_fan_enabled)                                                             | Enables the data source to subscribe to and process Oracle FAN events.                                                                                                                                                                            |
[oracle_ons_node_list](#wls_datasource_oracle_ons_node_list)                                                         | A comma-separate list of ONS daemon listen addresses and ports to which connect to for receiving ONS-based FAN events.                                                                                                                            |
[oracle_ons_wallet_file](#wls_datasource_oracle_ons_wallet_file)                                                     | The location of the Oracle wallet file in which the SSL certificates are stored.                                                                                                                                                                  |
[oracle_ons_wallet_password](#wls_datasource_oracle_ons_wallet_password)                                             | The wallet password attribute that is included as part of the ONS client configuration string.                                                                                                                                                    |
[oracle_optimize_utf8_conversion](#wls_datasource_oracle_optimize_utf8_conversion)                                   | Enables the Oracle JDBC optimize UTF-8 conversion option.                                                                                                                                                                                         |
[oracle_proxy_session](#wls_datasource_oracle_proxy_session)                                                         | Enables Oracle JDBC Proxy Authentication.                                                                                                                                                                                                         |
[oracle_replay_initiation_timeout](#wls_datasource_oracle_replay_initiation_timeout)                                 | The amount of time, in seconds, a data source allows for Application Continuity replay processing before timing out and ending a replay session context.                                                                                          |
[oracle_use_database_credentials](#wls_datasource_oracle_use_database_credentials)                                   | If enabled, Oracle database credentials are used in getConnection instead of application server credentials.                                                                                                                                      |
[password](#wls_datasource_password)                                                                                 | The datasource password.                                                                                                                                                                                                                          |
[pool_capacity_increment](#wls_datasource_pool_capacity_increment)                                                   | The increment by which this JDBC connection pool's capacity is expanded.                                                                                                                                                                          |
[pool_connection_creation_retry_frequency_seconds](#wls_datasource_pool_connection_creation_retry_frequency_seconds) | The number of seconds between attempts to establish connections to the database.                                                                                                                                                                  |
[pool_connection_harvest_max_count](#wls_datasource_pool_connection_harvest_max_count)                               | The maximum number of connections that may be harvested when the connection harvesting occurs.                                                                                                                                                    |
[pool_connection_harvest_trigger_count](#wls_datasource_pool_connection_harvest_trigger_count)                       | Specifies the number of available connections (trigger value) used to determine when connection harvesting occurs.                                                                                                                                |
[pool_connection_labeling_callback](#wls_datasource_pool_connection_labeling_callback)                               | The class name of the connection labeling callback.                                                                                                                                                                                               |
[pool_connection_reserve_timeout_seconds](#wls_datasource_pool_connection_reserve_timeout_seconds)                   | The number of seconds after which a call to reserve a connection from the connection pool will timeout.                                                                                                                                           |
[pool_count_of_refresh_failures_till_disable](#wls_datasource_pool_count_of_refresh_failures_till_disable)           | Specifies the number of reconnect failures allowed before WebLogic Server disables a connection pool to minimize the delay in handling the connection request caused by a database failure.                                                       |
[pool_count_of_test_failures_till_flush](#wls_datasource_pool_count_of_test_failures_till_flush)                     | Specifies the number of test failures allowed before WebLogic Server closes all unused connections in a connection pool to minimize the delay caused by further database testing.                                                                 |
[pool_credential_mapping_enabled](#wls_datasource_pool_credential_mapping_enabled)                                   | Enables Set Client ID on connection for the data source.                                                                                                                                                                                          |
[pool_driver_interceptor](#wls_datasource_pool_driver_interceptor)                                                   | Specifies the absolute name of the application class used to intercept method calls to the JDBC driver.                                                                                                                                           |
[pool_fatal_error_codes](#wls_datasource_pool_fatal_error_codes)                                                     | Specifies a comma-separated list of error codes that are treated as fatal errors.                                                                                                                                                                 |
[pool_highest_num_waiters](#wls_datasource_pool_highest_num_waiters)                                                 | The maximum number of connection requests that can concurrently block threads while waiting to reserve a connection from the data source's connection pool.                                                                                       |
[pool_identity_based_connection_pooling_enabled](#wls_datasource_pool_identity_based_connection_pooling_enabled)     | Enables identity-based-connection-pooling for the data source.                                                                                                                                                                                    |
[pool_ignore_in_use_connections_enabled](#wls_datasource_pool_ignore_in_use_connections_enabled)                     | Enables the data source to be shutdown even if connections obtained from the pool are still in use.                                                                                                                                               |
[pool_inactive_connection_timeout_seconds](#wls_datasource_pool_inactive_connection_timeout_seconds)                 | The number of inactive seconds on a reserved connection before WebLogic Server reclaims the connection and releases it back into the connection pool.                                                                                             |
[pool_init_sql](#wls_datasource_pool_init_sql)                                                                       | SQL statement to execute that will initialize newly created physical database connections.                                                                                                                                                        |
[pool_initial_capacity](#wls_datasource_pool_initial_capacity)                                                       | The number of physical connections to create when creating the connection pool in the data source.                                                                                                                                                |
[pool_jdbcxa_debug_level](#wls_datasource_pool_jdbcxa_debug_level)                                                   | Specifies level of JDBC debugging for XA drivers, where larger values in the range provide more debugging information.                                                                                                                            |
[pool_login_delay_seconds](#wls_datasource_pool_login_delay_seconds)                                                 | The number of seconds to delay before creating each physical database connection.                                                                                                                                                                 |
[pool_max_capacity](#wls_datasource_pool_max_capacity)                                                               | The maximum number of physical connections that this connection pool can contain.                                                                                                                                                                 |
[pool_min_capacity](#wls_datasource_pool_min_capacity)                                                               | The minimum number of physical connections that this connection pool can contain after it is initialized.                                                                                                                                         |
[pool_pinned_to_thread](#wls_datasource_pool_pinned_to_thread)                                                       | Enables an option to improve performance by enabling execute threads to keep a pooled database connection even after the application closes the logical connection.                                                                               |
[pool_profile_connection_leak_timeout_seconds](#wls_datasource_pool_profile_connection_leak_timeout_seconds)         | The number of seconds that a JDBC connection needs to be held by an application before triggering a connection leak diagnostic profiling record.                                                                                                  |
[pool_profile_harvest_frequency_seconds](#wls_datasource_pool_profile_harvest_frequency_seconds)                     | The number of seconds between when WebLogic Server harvests profile data.                                                                                                                                                                         |
[pool_profile_type](#wls_datasource_pool_profile_type)                                                               | Specifies that type of profile data to be collected for the JDBC subsystem.                                                                                                                                                                       |
[pool_remove_infected_connections](#wls_datasource_pool_remove_infected_connections)                                 | Specifies whether a connection will be removed from the connection pool after the application uses the underlying vendor connection object.                                                                                                       |
[pool_seconds_to_trust_an_idle_pool_connection](#wls_datasource_pool_seconds_to_trust_an_idle_pool_connection)       | The number of seconds within a connection use that WebLogic Server trusts that the connection is still viable and will skip the connection test, either before delivering it to an application or during the periodic connection testing process. |
[pool_shrink_frequency_seconds](#wls_datasource_pool_shrink_frequency_seconds)                                       | The number of seconds to wait before shrinking a connection pool that has incrementally increased to meet demand.                                                                                                                                 |
[pool_statement_cache_size](#wls_datasource_pool_statement_cache_size)                                               | The number of prepared and callable statements stored in the cache.                                                                                                                                                                               |
[pool_statement_cache_type](#wls_datasource_pool_statement_cache_type)                                               | The algorithm used for maintaining the prepared statements stored in the statement cache.                                                                                                                                                         |
[pool_statement_timeout](#wls_datasource_pool_statement_timeout)                                                     | The time after which a statement currently being executed will time out.                                                                                                                                                                          |
[pool_test_connections_on_reserve](#wls_datasource_pool_test_connections_on_reserve)                                 | Enables WebLogic Server to test a connection before giving it to a client.                                                                                                                                                                        |
[pool_test_frequency_seconds](#wls_datasource_pool_test_frequency_seconds)                                           | The number of seconds a WebLogic Server instance waits between attempts when testing unused connections.                                                                                                                                          |
[pool_test_table_name](#wls_datasource_pool_test_table_name)                                                         | The name of the database table to use when testing physical database connections.                                                                                                                                                                 |
[pool_wrap_jdbc](#wls_datasource_pool_wrap_jdbc)                                                                     | By default, SQL objects for <code>CallableStatement</code>, <code>PreparedStatement</code>, <code>ResultSet</code>, <code>Statement</code>, and <code>DatabaseMetaData</code> are wrapped with a WebLogic wrapper.                                |
[pool_wrap_types](#wls_datasource_pool_wrap_types)                                                                   | By default, data type objects for Array, Blob, Clob, NClob, Ref, SQLXML, and Struct, plus ParameterMetaData and ResultSetMetaData objects are wrapped with a WebLogic wrapper.                                                                    |
[provider](#wls_datasource_provider)                                                                                 | resource.                                                                                                                                                                                                                                         |
[rowprefetchenabled](#wls_datasource_rowprefetchenabled)                                                             | Enables the data source to prefetch rows.                                                                                                                                                                                                         |
[rowprefetchsize](#wls_datasource_rowprefetchsize)                                                                   | The row prefetch size of the datasource.                                                                                                                                                                                                          |
[secondstotrustidlepoolconnection](#wls_datasource_secondstotrustidlepoolconnection)                                 | The number of seconds within a connection use that WebLogic Server trusts that the connection is still viable and will skip the connection test, either before delivering it to an application or during the periodic connection testing process. |
[shrinkfrequencyseconds](#wls_datasource_shrinkfrequencyseconds)                                                     | Shrink Frequency Seconds.                                                                                                                                                                                                                         |
[source_path](#wls_datasource_source_path)                                                                           | 
                                                                                                                                                                                                                                                 |
[statementcachesize](#wls_datasource_statementcachesize)                                                             | The statement cache size of the datasource.                                                                                                                                                                                                       |
[tags](#wls_datasource_tags)                                                                                         | Return all tags on this Configuration MBean
                                                                                                                                                                                                      |
[target](#wls_datasource_target)                                                                                     | An array of target names.                                                                                                                                                                                                                         |
[targettype](#wls_datasource_targettype)                                                                             | An array of target types.                                                                                                                                                                                                                         |
[testconnectionsonreserve](#wls_datasource_testconnectionsonreserve)                                                 | the testconnectionsonreserve enabled on the jdbc driver
                                                                                                                                                                                          |
[testfrequency](#wls_datasource_testfrequency)                                                                       | The number of seconds a WebLogic Server instance waits between attempts when testing unused connections.                                                                                                                                          |
[testtablename](#wls_datasource_testtablename)                                                                       | The test table statement for the datasource.                                                                                                                                                                                                      |
[timeout](#wls_datasource_timeout)                                                                                   | Timeout for applying a resource.                                                                                                                                                                                                                  |
[url](#wls_datasource_url)                                                                                           | The jdbc url.                                                                                                                                                                                                                                     |
[user](#wls_datasource_user)                                                                                         | The username to use when connection to the database.                                                                                                                                                                                              |
[usexa](#wls_datasource_usexa)                                                                                       | the UseXaDataSourceInterface enabled on the jdbc driver.                                                                                                                                                                                          |
[wrapdatatypes](#wls_datasource_wrapdatatypes)                                                                       | Should weblogic wrap data types.                                                                                                                                                                                                                  |
[xa_end_only_once](#wls_datasource_xa_end_only_once)                                                                 | Specifies that <code>XAResource.end()</code> is called only once for each pending <code>XAResource.start()</code>.                                                                                                                                |
[xa_keep_logical_conn_open_on_release](#wls_datasource_xa_keep_logical_conn_open_on_release)                         | Enables WebLogic Server to keep the logical JDBC connection open for a global transaction when the physical XA connection is returned to the connection pool.                                                                                     |
[xa_keep_xa_conn_till_tx_complete](#wls_datasource_xa_keep_xa_conn_till_tx_complete)                                 | Enables WebLogic Server to associate the same XA database connection from the connection pool with a global transaction until the transaction completes.                                                                                          |
[xa_need_tx_ctx_on_close](#wls_datasource_xa_need_tx_ctx_on_close)                                                   | Specifies whether the XA driver requires a distributed transaction context when closing various JDBC objects (result sets, statements, connections, and so forth).                                                                                |
[xa_new_xa_conn_for_commit](#wls_datasource_xa_new_xa_conn_for_commit)                                               | Specifies that a dedicated XA connection is used for commit and rollback processing for a global transaction.                                                                                                                                     |
[xa_recover_only_once](#wls_datasource_xa_recover_only_once)                                                         | Specifies that the transaction manager calls recover on the resource only once.                                                                                                                                                                   |
[xa_resource_health_monitoring](#wls_datasource_xa_resource_health_monitoring)                                       | Enables JTA resource health monitoring for an XA data source.                                                                                                                                                                                     |
[xa_retry_duration_seconds](#wls_datasource_xa_retry_duration_seconds)                                               | Determines the duration in seconds for which the transaction manager will perform recover operations on the resource.                                                                                                                             |
[xa_retry_interval_seconds](#wls_datasource_xa_retry_interval_seconds)                                               | The number of seconds between XA retry operations if XARetryDurationSeconds is set to a positive value.                                                                                                                                           |
[xa_rollback_local_tx_upon_conn_close](#wls_datasource_xa_rollback_local_tx_upon_conn_close)                         | Enables WebLogic Server to call <code>rollback()</code> on the connection before returning the connection to the connection pool.                                                                                                                 |
[xa_set_transaction_timeout](#wls_datasource_xa_set_transaction_timeout)                                             | Enables WebLogic Server to set a transaction branch timeout based on the value for XaTransactionTimeout.                                                                                                                                          |
[xa_transaction_timeout](#wls_datasource_xa_transaction_timeout)                                                     | The number of seconds to set as the transaction branch timeout.                                                                                                                                                                                   |
[xaproperties](#wls_datasource_xaproperties)                                                                         | Datasource XA properties.                                                                                                                                                                                                                         |




### compatibility_name<a name='wls_datasource_compatibility_name'>

 This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean.  Standalone modules in 8.1 have both an ApplicationMBean name and ComponentMBean name. This attribute stores the name of the latter, to be used when the server creates the transient ComponentMBean for backward compatibility.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       compatibility_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:compatibility_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### connectioncreationretryfrequency<a name='wls_datasource_connectioncreationretryfrequency'>

The number of seconds between attempts to establish connections to the database.


[Back to overview of wls_datasource](#attributes)


### datasource_name<a name='wls_datasource_datasource_name'>

The datasource name.


[Back to overview of wls_datasource](#attributes)


### deployment_order<a name='wls_datasource_deployment_order'>

An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.  Units with lower values are deployed before those with higher values.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       deployment_order => '100'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### deployment_principal_name<a name='wls_datasource_deployment_principal_name'>

A string value that indicates the principal that should be used when deploying the file or archive during startup and shutdown. This principal will be used to set the current subject when calling out into application code for interfaces such as ApplicationLifecycleListener. If no principal name is specified, then the anonymous principal will be used.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       deployment_principal_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:deployment_principal_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### domain<a name='wls_datasource_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_datasource](#attributes)


### driver_name<a name='wls_datasource_driver_name'>

The full package name of JDBC driver class used to create the physical database connections in the connection pool in the data source.  For example: <code>oracle.jdbc.OracleDriver</code>  The driver must be the name of a class that implements the <code>java.sql.Driver</code> interface. Check the driver documentation to find the full pathname.  Note that the driver class must be in the classpath of any server to which the data source is deployed.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       driver_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:driver_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### driver_password<a name='wls_datasource_driver_password'>

The password attribute passed to the JDBC driver when creating physical database connections.  The value is stored in an encrypted form in the descriptor file and when displayed in an administration console.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       driver_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:driver_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### driver_url<a name='wls_datasource_driver_url'>

The URL of the database to connect to. The format of the URL varies by JDBC driver.  The URL is passed to the JDBC driver to create the physical database connections.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       driver_url => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:driver_url']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### driver_use_password_indirection<a name='wls_datasource_driver_use_password_indirection'>

 Specifies whether the database credentials are to be obtained from the credential mapper using the "user" property as the key. When true, the credentials are obtained from the credential mapper. When false, the database user name and password are obtained from the "user" property and Password element, respectively.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       driver_use_password_indirection => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:driver_use_password_indirection']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### driver_use_xa_data_source_interface<a name='wls_datasource_driver_use_xa_data_source_interface'>

Specifies that WebLogic Server should use the XA interface of the JDBC driver.  If the JDBC driver class used to create database connections implements both XA and non-XA versions of a JDBC driver, you can set this attribute to indicate that WebLogic Server should treat the JDBC driver as an XA driver or as a non-XA driver.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       driver_use_xa_data_source_interface => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:driver_use_xa_data_source_interface']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### drivername<a name='wls_datasource_drivername'>

The drivername.


[Back to overview of wls_datasource](#attributes)


### ds_algorithm_type<a name='wls_datasource_ds_algorithm_type'>

The algorithm determines the connection request processing for the multi data source.  You can specify one of the following algorithm types:  <ul> <li>Failover  Connection requests are sent to the first data source in the list; if the request fails, the request is sent to the next data source in the list, and so forth. The process is repeated until a valid connection is obtained, or until the end of the list is reached, in which case an exception is thrown. </li>  <li>Load balancing  The multi data source distributes connection requests evenly to its member data sources. With this algorithm, the multi data source also provides failover processing. That is, if a request fails, the multi data source sends the request to the next data source in the list until a valid connection is obtained, or until the end of the list is reached, in which case an exception is thrown. </li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_algorithm_type => 'Failover'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_algorithm_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_connection_pool_failover_callback_handler<a name='wls_datasource_ds_connection_pool_failover_callback_handler'>

The name of the application class to handle the callback sent when a multi data source is ready to failover or fail back connection requests to another data source within the multi data source.  The name must be the absolute name of an application class that implements the <code>weblogic.jdbc.extensions.ConnectionPoolFailoverCallback</code> interface.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_connection_pool_failover_callback_handler => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_connection_pool_failover_callback_handler']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_data_source_list<a name='wls_datasource_ds_data_source_list'>

The list of data sources to which the multi data source will route connection requests. The order of data sources in the list determines the failover order.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_data_source_list => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_data_source_list']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_failover_request_if_busy<a name='wls_datasource_ds_failover_request_if_busy'>

For multi data sources with the <code>failover</code> algorithm, enables the multi data source to failover connection requests to the next data source if all connections in the current data source are in use.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_failover_request_if_busy => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_failover_request_if_busy']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### ds_global_transactions_protocol<a name='wls_datasource_ds_global_transactions_protocol'>

Determines the transaction protocol (global transaction processing behavior) for the data source. Options include:  <ul> <li> TwoPhaseCommit - Standard XA transaction processing. Requires an XA driver. </li>  <li> LoggingLastResource - A performance enhancement for one non-XA resource. </li>  <li> EmulateTwoPhaseCommit - Enables one non-XA resource to participate in a global transaction, but has some risk to data. </li>  <li> OnePhaseCommit - One-phase XA transaction processing using a non-XA driver. This is the default setting. </li>  <li> None - Support for local transactions only. </li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_global_transactions_protocol => 'OnePhaseCommit'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_global_transactions_protocol']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_jndi_names<a name='wls_datasource_ds_jndi_names'>

The JNDI path to where this Data Source is bound. By default, the JNDI name is the name of the data source.  Applications that look up the JNDI path will get a <code>javax.sql.DataSource</code> instance that corresponds to this data source.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_jndi_names => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_jndi_names']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_keep_conn_after_global_tx<a name='wls_datasource_ds_keep_conn_after_global_tx'>

Enables WebLogic Server to keep the physical database connection associated with the logical connection when committing a global transaction instead releasing it and getting another physical connection when needed.  Setting this option to true may require additional connections to be configured on the database.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_keep_conn_after_global_tx => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_keep_conn_after_global_tx']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### ds_keep_conn_after_local_tx<a name='wls_datasource_ds_keep_conn_after_local_tx'>

Enables WebLogic Server to keep the physical database connection associated with the logical connection when committing a local transaction instead releasing it and getting another physical connection when needed.  Setting this option to true may require additional connections to be configured on the database.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_keep_conn_after_local_tx => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_keep_conn_after_local_tx']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### ds_proxy_switching_callback<a name='wls_datasource_ds_proxy_switching_callback'>

The name of the switching callback class for a Proxy data source. This class implements the <code>weblogic.jdbc.extensions.DataSourceSwitchingCallback</code> interface.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_proxy_switching_callback => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_proxy_switching_callback']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_proxy_switching_properties<a name='wls_datasource_ds_proxy_switching_properties'>

Specifies the switching properties passed to the switching callback method for a Proxy data source.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_proxy_switching_properties => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_proxy_switching_properties']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_row_prefetch<a name='wls_datasource_ds_row_prefetch'>

Enables multiple rows to be "prefetched" (that is, sent from the server to the client) in one server access.  When an external client accesses a database using JDBC through WebLogic Server, row prefetching improves performance by fetching multiple rows from the server to the client in one server access. WebLogic Server ignores this setting and does not use row prefetching when the client and WebLogic Server are in the same JVM.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_row_prefetch => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_row_prefetch']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### ds_row_prefetch_size<a name='wls_datasource_ds_row_prefetch_size'>

If row prefetching is enabled, specifies the number of result set rows to prefetch for a client.  The optimal prefetch size depends on the particulars of the query. In general, increasing this number will increase performance, until a particular value is reached. At that point further increases do not result in any significant performance increase. Very rarely will increased performance result from exceeding 100 rows. The default value should be reasonable for most situations.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_row_prefetch_size => '48'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_row_prefetch_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_scope<a name='wls_datasource_ds_scope'>

Specifies the scoping of the data source.  You can specify one of the following scopes:  <ul> <li>Global  Specifies that the data source is bound in the cluster-wide JNDI tree with the JNDIName specified so that the data source is available for use to any JDBC client across the cluster.  This is the default setting. </li>  <li>Application  Specifies that the data source is bound in the application's local namespace with the JNDIName specified so that the data source is available for use only by JDBC clients within the application.  This can only be used for packaged datasources and is ignored for JDBC System resources. </li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_scope => 'Global'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_scope']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ds_stream_chunk_size<a name='wls_datasource_ds_stream_chunk_size'>

Specifies the data chunk size for steaming data types.  Streaming data types (for example resulting from a call to <code>getBinaryStream()</code>) are sent in sized chunks from WebLogic Server to the client as needed.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       ds_stream_chunk_size => '256'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:ds_stream_chunk_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### ensure<a name='wls_datasource_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_datasource](#attributes)


### extraproperties<a name='wls_datasource_extraproperties'>

The extra properties.


[Back to overview of wls_datasource](#attributes)


### fanenabled<a name='wls_datasource_fanenabled'>

Enables the data source to subscribe to and process Oracle FAN events.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_datasource](#attributes)


### globaltransactionsprotocol<a name='wls_datasource_globaltransactionsprotocol'>

The global Transactions Protocol.

Valid values are `TwoPhaseCommit`, `EmulateTwoPhaseCommit`, `OnePhaseCommit`, `LoggingLastResource`, `None`. 
[Back to overview of wls_datasource](#attributes)


### initialcapacity<a name='wls_datasource_initialcapacity'>

The number of physical connections to create when creating the connection pool in the data source. If unable to create this number of connections, creation of the data source will fail.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       initialcapacity => '1'
       ...
    }


[Back to overview of wls_datasource](#attributes)


### initsql<a name='wls_datasource_initsql'>

SQL statement to execute that will initialize newly created physical database connections. Start the statement with SQL followed by a space.  If the Init SQL value begins with <code>"SQL "</code>, then the rest of the string following that leading token will be taken as a literal SQL statement that will be used to initialize database connections. If the Init SQL value does not begin with "SQL ", the value will be treated as the name of a table and the following SQL statement will be used to initialize connections: <code><br clear="none" /> "select count(*) from InitSQL"</code>  The table <code>InitSQL</code> must exist and be accessible to the database user for the connection. Most database servers optimize this SQL to avoid a table scan, but it is still a good idea to set <code>InitSQL</code> to the name of a table that is known to have few rows, or even no rows.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       initsql => 'sqlstatement'
       ...
    }


[Back to overview of wls_datasource](#attributes)


### jndinames<a name='wls_datasource_jndinames'>

The datasource jndi names.


[Back to overview of wls_datasource](#attributes)


### maxcapacity<a name='wls_datasource_maxcapacity'>

The max capacity of the datasource.


[Back to overview of wls_datasource](#attributes)


### mincapacity<a name='wls_datasource_mincapacity'>

The min capacity of the datasource.


[Back to overview of wls_datasource](#attributes)


### module_type<a name='wls_datasource_module_type'>

The values match those defined by jsr88. This attribute may move to another MBean.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       module_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:module_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### name<a name='wls_datasource_name'>

The name.


[Back to overview of wls_datasource](#attributes)


### notes<a name='wls_datasource_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### onsnodelist<a name='wls_datasource_onsnodelist'>

A comma-separate list of ONS daemon listen addresses and ports to which connect to for receiving ONS-based FAN events.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       onsnodelist => 'node_a, node_b'
       ...
    }


[Back to overview of wls_datasource](#attributes)


### oracle_active_gridlink<a name='wls_datasource_oracle_active_gridlink'>

Indicates a configured Active GridLink datasource. This attributed is set to <code>true</code> when using the console to create an Active GridLink datasource. It is ignored if FanEnabled is <code>true</code> or OnsNodeList is a non-null string.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_active_gridlink => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_active_gridlink']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### oracle_affinity_policy<a name='wls_datasource_oracle_affinity_policy'>

Specifies the affinity policy for the datasource. Options include: <ul> <li>Transaction: Transaction affinity</li> <li>Session: Web-session affinity</li> <li>Data: Data affinity</li> </ul> The default value is Session.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_affinity_policy => 'Session'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_affinity_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### oracle_connection_initialization_callback<a name='wls_datasource_oracle_connection_initialization_callback'>

The name of the Connection Initialization Callback class.  This name is automatically passed to <code>registerConnectionInitializationCallback</code> when a data source is created. The class must implement <code>oracle.ucp.jdbc.ConnectionInitializationCallback</code>.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_connection_initialization_callback => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_connection_initialization_callback']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### oracle_enable_java_net_fast_path<a name='wls_datasource_oracle_enable_java_net_fast_path'>

Deprecated.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_enable_java_net_fast_path => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_enable_java_net_fast_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### oracle_fan_enabled<a name='wls_datasource_oracle_fan_enabled'>

Enables the data source to subscribe to and process Oracle FAN events.  This attribute is only applicable for RAC configurations that publish FAN notification events using the ONS protocol.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_fan_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_fan_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### oracle_ons_node_list<a name='wls_datasource_oracle_ons_node_list'>

A comma-separate list of ONS daemon listen addresses and ports to which connect to for receiving ONS-based FAN events. It is required when connecting to Oracle 11g databases and optional when connecting to Oracle database releases 12c and higher.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_ons_node_list => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_ons_node_list']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### oracle_ons_wallet_file<a name='wls_datasource_oracle_ons_wallet_file'>

The location of the Oracle wallet file in which the SSL certificates are stored. Only required when the ONS client is configured to communicate with ONS daemons using SSL.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_ons_wallet_file => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_ons_wallet_file']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### oracle_ons_wallet_password<a name='wls_datasource_oracle_ons_wallet_password'>

The wallet password attribute that is included as part of the ONS client configuration string. This attribute is only required when ONS is configured to use the SSL protocol.  The value is stored in an encrypted form in the descriptor file and when displayed in an administration console.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_ons_wallet_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_ons_wallet_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### oracle_optimize_utf8_conversion<a name='wls_datasource_oracle_optimize_utf8_conversion'>

Enables the Oracle JDBC optimize UTF-8 conversion option.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_optimize_utf8_conversion => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_optimize_utf8_conversion']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### oracle_proxy_session<a name='wls_datasource_oracle_proxy_session'>

Enables Oracle JDBC Proxy Authentication.  <ul> <li>Only applicable for the Oracle driver.</li> <li>Requires WebLogic Server user IDs are mapped to database user IDs using credential mapping.</li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_proxy_session => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_proxy_session']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### oracle_replay_initiation_timeout<a name='wls_datasource_oracle_replay_initiation_timeout'>

The amount of time, in seconds, a data source allows for Application Continuity replay processing before timing out and ending a replay session context. <ul> <li>When set to zero (0) seconds, replay processing is disabled.</li> <li>The default value is 3600 seconds.</li> <li>See <code>oracle.ucp.jdbc.ConnectionInitializationCallback</code>.</ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_replay_initiation_timeout => '3600'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_replay_initiation_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### oracle_use_database_credentials<a name='wls_datasource_oracle_use_database_credentials'>

If enabled, Oracle database credentials are used in getConnection instead of application server credentials. The database credentials are used to get a proxy session without requiring any work in the credential mapper.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       oracle_use_database_credentials => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:oracle_use_database_credentials']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### password<a name='wls_datasource_password'>

The datasource password.

Usage :

    wls_datasource { ....:
      ...
      password => 'clear_text_password',
      ...
    }

The password string is passed to WebLogic for encryption and then stored in the domain.


[Back to overview of wls_datasource](#attributes)


### pool_capacity_increment<a name='wls_datasource_pool_capacity_increment'>

The increment by which this JDBC connection pool's capacity is expanded. In WebLogic Server 10.3.1 and higher releases, the <code>capacityIncrement</code> is no longer configurable and is set to a value of 1.  When there are no more available physical connections to service requests, the connection pool will create this number of additional physical database connections and add them to the connection pool. The connection pool will ensure that it does not exceed the maximum number of physical connections.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_capacity_increment => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_capacity_increment']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_connection_creation_retry_frequency_seconds<a name='wls_datasource_pool_connection_creation_retry_frequency_seconds'>

The number of seconds between attempts to establish connections to the database.  If you do not set this value, data source creation fails if the database is unavailable. If set and if the database is unavailable when the data source is created, WebLogic Server will attempt to create connections in the pool again after the number of seconds you specify, and will continue to attempt to create the connections until it succeeds.  When set to <code>0</code>, connection retry is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_connection_creation_retry_frequency_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_connection_creation_retry_frequency_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_connection_harvest_max_count<a name='wls_datasource_pool_connection_harvest_max_count'>

The maximum number of connections that may be harvested when the connection harvesting occurs. The range of valid values is 1 to MaxCapacity.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_connection_harvest_max_count => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_connection_harvest_max_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_connection_harvest_trigger_count<a name='wls_datasource_pool_connection_harvest_trigger_count'>

Specifies the number of available connections (trigger value) used to determine when connection harvesting occurs.

- Harvesting occurs when the number of available connections is below the trigger value for a connection pool.
- The range of valid values is -1 to `MaxCapacity`.
- Default value is `-1`.
- Setting the value to `-1` disables connection harvesting.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_connection_harvest_trigger_count => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_connection_harvest_trigger_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_connection_labeling_callback<a name='wls_datasource_pool_connection_labeling_callback'>

The class name of the connection labeling callback. This is automatically passed to registerConnectionLabelingCallback when the datasource is created. The class must implement <code>oracle.ucp.ConnectionLabelingCallback</code>.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_connection_labeling_callback => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_connection_labeling_callback']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_connection_reserve_timeout_seconds<a name='wls_datasource_pool_connection_reserve_timeout_seconds'>

The number of seconds after which a call to reserve a connection from the connection pool will timeout. When set to <code>0</code>, a call will never timeout. When set to <code>-1</code>, a call will timeout immediately.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_connection_reserve_timeout_seconds => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_connection_reserve_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_count_of_refresh_failures_till_disable<a name='wls_datasource_pool_count_of_refresh_failures_till_disable'>

Specifies the number of reconnect failures allowed before WebLogic Server disables a connection pool to minimize the delay in handling the connection request caused by a database failure.  Zero means it is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_count_of_refresh_failures_till_disable => '2'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_count_of_refresh_failures_till_disable']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_count_of_test_failures_till_flush<a name='wls_datasource_pool_count_of_test_failures_till_flush'>

Specifies the number of test failures allowed before WebLogic Server closes all unused connections in a connection pool to minimize the delay caused by further database testing.  Zero means it is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_count_of_test_failures_till_flush => '2'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_count_of_test_failures_till_flush']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_credential_mapping_enabled<a name='wls_datasource_pool_credential_mapping_enabled'>

Enables Set Client ID on connection for the data source. When an application requests a database connection, WebLogic Server sets a light-weight client ID on the database connection.  By default, it uses the credential mapping to map WebLogic Server user IDs to database user IDs. However, if use-database-credentials is set to true, then the credential mapping is not done and the ID is used directly as a database user ID.  It is currently supported for IBM DB2 driver and Oracle thin driver. Support for this feature will be dropped in a future Oracle thin driver release. Oracle recommends using proxy authentication instead of this feature.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_credential_mapping_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_credential_mapping_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_driver_interceptor<a name='wls_datasource_pool_driver_interceptor'>

Specifies the absolute name of the application class used to intercept method calls to the JDBC driver. The application specified must implement the weblogic.jdbc.extensions.DriverInterceptor interface.   Weblogic Server will invoke the preInvokeCallback(), postInvokeExceptionCallback(), and postInvokeCallback() methods of the registered application before and after invoking any method inside the JDBC driver. You can use this feature to profile JDBC driver usage and monitor:  <ul> <li>Methods being executed</li> <li>Any exceptions thrown</li> <li>Time spent inside the driver executing methods</li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_driver_interceptor => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_driver_interceptor']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_fatal_error_codes<a name='wls_datasource_pool_fatal_error_codes'>

Specifies a comma-separated list of error codes that are treated as fatal errors. These errors include deployment errors that cause a server to fail to boot and connection errors that prevent a connection from being put back in the connection pool.  This optional attribute is used to define fatal error codes, that when specified as the exception code within a <code>SQLException</code> (retrieved by <code>sqlException.getErrorCode()</code>), indicate that a fatal error has occurred and the connection is no longer usable. For Oracle databases the following fatal error codes are predefined within WLS and do not need to be placed in the configuration file:   <ul><li>3113: "end-of-file on communication channel" </li> <li>3114: "not connected to ORACLE" </li> <li>1033: "ORACLE initialization or shutdown in progress" </li> <li>1034: "ORACLE not available" </li> <li>1089: "immediate shutdown in progress - no operations are permitted"</li> <li>1090: "shutdown in progress - connection is not permitted" </li> <li>17002: "I/O exception" </li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_fatal_error_codes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_fatal_error_codes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_highest_num_waiters<a name='wls_datasource_pool_highest_num_waiters'>

The maximum number of connection requests that can concurrently block threads while waiting to reserve a connection from the data source's connection pool.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_highest_num_waiters => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_highest_num_waiters']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_identity_based_connection_pooling_enabled<a name='wls_datasource_pool_identity_based_connection_pooling_enabled'>

Enables identity-based-connection-pooling for the data source. When an application requests a database connection, WebLogic Server picks or creates a physical connection with requested DBMS identity based on a map of WebLogic user IDs and database IDs.  You must also specify the map of WebLogic Server user IDs to database user IDs (credential mapping).

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_identity_based_connection_pooling_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_identity_based_connection_pooling_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_ignore_in_use_connections_enabled<a name='wls_datasource_pool_ignore_in_use_connections_enabled'>

Enables the data source to be shutdown even if connections obtained from the pool are still in use.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_ignore_in_use_connections_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_ignore_in_use_connections_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_inactive_connection_timeout_seconds<a name='wls_datasource_pool_inactive_connection_timeout_seconds'>

The number of inactive seconds on a reserved connection before WebLogic Server reclaims the connection and releases it back into the connection pool.  You can use the Inactive Connection Timeout feature to reclaim leaked connections - connections that were not explicitly closed by the application. Note that this feature is not intended to be used in place of properly closing connections.  When set to <code>0</code>, the feature is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_inactive_connection_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_inactive_connection_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_init_sql<a name='wls_datasource_pool_init_sql'>

SQL statement to execute that will initialize newly created physical database connections. Start the statement with SQL followed by a space.  If the Init SQL value begins with <code>"SQL "</code>, then the rest of the string following that leading token will be taken as a literal SQL statement that will be used to initialize database connections. If the Init SQL value does not begin with "SQL ", the value will be treated as the name of a table and the following SQL statement will be used to initialize connections: <code><br clear="none" /> "select count(*) from InitSQL"</code>  The table <code>InitSQL</code> must exist and be accessible to the database user for the connection. Most database servers optimize this SQL to avoid a table scan, but it is still a good idea to set <code>InitSQL</code> to the name of a table that is known to have few rows, or even no rows.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_init_sql => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_init_sql']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_initial_capacity<a name='wls_datasource_pool_initial_capacity'>

The number of physical connections to create when creating the connection pool in the data source. If unable to create this number of connections, creation of the data source will fail.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_initial_capacity => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_initial_capacity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_jdbcxa_debug_level<a name='wls_datasource_pool_jdbcxa_debug_level'>

Specifies level of JDBC debugging for XA drivers, where larger values in the range provide more debugging information.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_jdbcxa_debug_level => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_jdbcxa_debug_level']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_login_delay_seconds<a name='wls_datasource_pool_login_delay_seconds'>

The number of seconds to delay before creating each physical database connection. This delay supports database servers that cannot handle multiple connection requests in rapid succession.  The delay takes place both during initial data source creation and during the lifetime of the data source whenever a physical database connection is created.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_login_delay_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_login_delay_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_max_capacity<a name='wls_datasource_pool_max_capacity'>

The maximum number of physical connections that this connection pool can contain.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_max_capacity => '15'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_max_capacity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_min_capacity<a name='wls_datasource_pool_min_capacity'>

The minimum number of physical connections that this connection pool can contain after it is initialized.

- Default: `InitialCapacity`
- Used only for connection pool shrinking calculations.
- For compatibility, `InitialCapacity` is used if `MinCapacity` is not configured.
- Once a data source has gone through a suspend/resume, the larger value of either `MinCapacity` or `InitialCapacity` is used.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_min_capacity => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_min_capacity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_pinned_to_thread<a name='wls_datasource_pool_pinned_to_thread'>

Enables an option to improve performance by enabling execute threads to keep a pooled database connection even after the application closes the logical connection.
When enabled:

- WebLogic Server pins a database connection from the connection pool to an execution thread the first time an application uses the thread to reserve a connection. When the application finishes using the connection and calls `connection.close()`, WebLogic Server keeps the connection with the execute thread and does not return it to the connection pool. When an application subsequently requests a connection using the same execute thread, WebLogic Server provides the connection already reserved by the thread.
- There is no locking contention on the connection pool that occurs when multiple threads attempt to reserve a connection at the same time. There is no contention for threads that attempt to reserve the same connection from a limited number of database connections.
- If an application concurrently reserves more than one connection from the connection pool using the same execute thread, WebLogic Server creates additional database connections and pins them to the thread.
- The maximum capacity of the connection pool (maximum number of database connections created in the connection pool) becomes the number of execute threads used to request a connection multiplied by the number of concurrent connections each thread reserves. This may exceed the `Maximum Capacity` specified for the connection pool. You may need to consider this larger number of connections in your system design and ensure that your database allows for additional associated resources. If your system cannot handle the additional resource requirements or if you see database resource errors after enabling `PinnedToThread`, Oracle recommends not using `PinnedToThread`. See [Using Pinned-To-Thread Property to Increase Performance.](http://www.oracle.com/pls/topic/lookup?ctx=fmw122100&id=JDBCA198)

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_pinned_to_thread => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_pinned_to_thread']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_profile_connection_leak_timeout_seconds<a name='wls_datasource_pool_profile_connection_leak_timeout_seconds'>

The number of seconds that a JDBC connection needs to be held by an application before triggering a connection leak diagnostic profiling record.  When set to <code>0</code>, the timeout is disabled.  This attribute only applies when the connection leak diagnostic profiling option is enabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_profile_connection_leak_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_profile_connection_leak_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_profile_harvest_frequency_seconds<a name='wls_datasource_pool_profile_harvest_frequency_seconds'>

The number of seconds between when WebLogic Server harvests profile data.  When set to <code>0</code>, harvesting of data is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_profile_harvest_frequency_seconds => '300'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_profile_harvest_frequency_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_profile_type<a name='wls_datasource_pool_profile_type'>

Specifies that type of profile data to be collected for the JDBC subsystem.  You can specify combinations of the following profile types:  <ul> <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_USAGE - Profile threads currently using connections from the pool of connections in the data source. </li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_RESV_WAIT - Profile threads currently waiting to reserve a connection from the data source.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_LEAK - Profile threads that have reserved a connection from the data source and the connection leaked (was not properly returned to the pool of connections).</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_RESV_FAIL - Profile threads that attempt to reserve a connection from the data source but fail.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_STMT_CACHE_ENTRY - Profile prepared and callable statements added to the statement cache, and profile the threads that originated the cached statements.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_STMT_USAGE - Profile threads currently executing SQL statements from the statement cache.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_LAST_USAGE - Profile the previous thread that last used the connection. This information is useful when debugging problems with connections infected with pending transactions that cause subsequent XA operations on the connections to fail.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_MT_USAGE - Profile threads that erroneously use a connection previously obtained by a different thread.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_NONE - Disable profiling for the data source.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_ALL - Enable all profile types for the data source.</li>  </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_profile_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_profile_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_remove_infected_connections<a name='wls_datasource_pool_remove_infected_connections'>

Specifies whether a connection will be removed from the connection pool after the application uses the underlying vendor connection object.  If you disable removing infected connections, you must make sure that the database connection is suitable for reuse by other applications.  When set to <code>true</code> (the default), the physical connection is not returned to the connection pool after the application closes the logical connection. Instead, the physical connection is closed and recreated.  When set to <code>false</code>, when the application closes the logical connection, the physical connection is returned to the connection pool and can be reused by the application or by another application.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_remove_infected_connections => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_remove_infected_connections']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_seconds_to_trust_an_idle_pool_connection<a name='wls_datasource_pool_seconds_to_trust_an_idle_pool_connection'>

The number of seconds within a connection use that WebLogic Server trusts that the connection is still viable and will skip the connection test, either before delivering it to an application or during the periodic connection testing process.  This option is an optimization that minimizes the performance impact of connection testing, especially during heavy traffic.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_seconds_to_trust_an_idle_pool_connection => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_seconds_to_trust_an_idle_pool_connection']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_shrink_frequency_seconds<a name='wls_datasource_pool_shrink_frequency_seconds'>

The number of seconds to wait before shrinking a connection pool that has incrementally increased to meet demand.  When set to <code>0</code>, shrinking is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_shrink_frequency_seconds => '900'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_shrink_frequency_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_statement_cache_size<a name='wls_datasource_pool_statement_cache_size'>

The number of prepared and callable statements stored in the cache. (This may increase server performance.)  WebLogic Server can reuse statements in the cache without reloading the statements, which can increase server performance. Each connection in the connection pool has its own cache of statements.  Setting the size of the statement cache to 0 turns off statement caching.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_statement_cache_size => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_statement_cache_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_statement_cache_type<a name='wls_datasource_pool_statement_cache_type'>

The algorithm used for maintaining the prepared statements stored in the statement cache.  Options are: <ul> <li>LRU - when a new prepared or callable statement is used, the least recently used statement is replaced in the cache.</li> <li>FIXED - the first fixed number of prepared and callable statements are cached.</li> </ul>

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_statement_cache_type => 'LRU'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_statement_cache_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_statement_timeout<a name='wls_datasource_pool_statement_timeout'>

The time after which a statement currently being executed will time out.  StatementTimeout relies on underlying JDBC driver support. WebLogic Server passes the time specified to the JDBC driver using the <code>java.sql.Statement.setQueryTimeout()</code> method. If your JDBC driver does not support this method, it may throw an exception and the timeout value is ignored.  A value of <code>-1</code> disables this feature. A value of <code>0</code> means that statements will not time out.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_statement_timeout => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_statement_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_test_connections_on_reserve<a name='wls_datasource_pool_test_connections_on_reserve'>

Enables WebLogic Server to test a connection before giving it to a client. (Requires that you specify a Test Table Name.)  The test adds a small delay in serving the client's request for a connection from the pool, but ensures that the client receives a viable connection.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_test_connections_on_reserve => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_test_connections_on_reserve']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_test_frequency_seconds<a name='wls_datasource_pool_test_frequency_seconds'>

The number of seconds a WebLogic Server instance waits between attempts when testing unused connections. (Requires that you specify a Test Table Name.) Connections that fail the test are closed and reopened to re-establish a valid physical connection. If the test fails again, the connection is closed.  In the context of multi data sources, this attribute controls the frequency at which WebLogic Server checks the health of data sources it had previously marked as unhealthy.  When set to <code>0</code>, the feature is disabled.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_test_frequency_seconds => '120'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_test_frequency_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_test_table_name<a name='wls_datasource_pool_test_table_name'>

The name of the database table to use when testing physical database connections. This name is required when you specify a Test Frequency and enable Test Reserved Connections.  The default SQL code used to test a connection is <code>select count(*) from TestTableName</code> Most database servers optimize this SQL to avoid a table scan, but it is still a good idea to set the Test Table Name to the name of a table that is known to have few rows, or even no rows.  If the Test Table Name begins with <code>SQL</code>, then the rest of the string following that leading token will be taken as a literal SQL statement that will be used to test connections instead of the standard query. For example: <code>SQL BEGIN; Null; END; </code>  For an Oracle database, you can reduce the overhead of connection testing by setting Test Table Name to <code>SQL PINGDATABASE</code> which uses the <code>pingDatabase()</code> method to test the Oracle connection. For any JDBC 4.0 database, it is possible to use "SQL ISVALID" to use the <code>isValid()</code> method on the connection.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_test_table_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_test_table_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### pool_wrap_jdbc<a name='wls_datasource_pool_wrap_jdbc'>

By default, SQL objects for <code>CallableStatement</code>, <code>PreparedStatement</code>, <code>ResultSet</code>, <code>Statement</code>, and <code>DatabaseMetaData</code> are wrapped with a WebLogic wrapper. Wrapping allows features like debugging and connection usage to be performed by the server.  When <code>false</code>, wrapping is disabled. This improves performance, in some cases significantly, and allows for the application to use the native driver objects directly. A value of <code>false</code> also disables data type wrapping.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_wrap_jdbc => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_wrap_jdbc']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### pool_wrap_types<a name='wls_datasource_pool_wrap_types'>

By default, data type objects for Array, Blob, Clob, NClob, Ref, SQLXML, and Struct, plus ParameterMetaData and ResultSetMetaData objects are wrapped with a WebLogic wrapper.  This allows for features like debugging and connection usage to be done by the server.  The wrapping can be turned off by setting this value to false. This improves performance, in some cases significantly, and allows for the application to use the native driver objects directly.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       pool_wrap_types => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:pool_wrap_types']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### provider<a name='wls_datasource_provider'>

The specific backend to use for this `wls_datasource`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a datasource in an WebLogic domain via regular WLST


[Back to overview of wls_datasource](#attributes)


### rowprefetchenabled<a name='wls_datasource_rowprefetchenabled'>

Enables the data source to prefetch rows.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_datasource](#attributes)


### rowprefetchsize<a name='wls_datasource_rowprefetchsize'>

The row prefetch size of the datasource.


[Back to overview of wls_datasource](#attributes)


### secondstotrustidlepoolconnection<a name='wls_datasource_secondstotrustidlepoolconnection'>

The number of seconds within a connection use that WebLogic Server trusts that the connection is still viable and will skip the connection test, either before delivering it to an application or during the periodic connection testing process.


[Back to overview of wls_datasource](#attributes)


### shrinkfrequencyseconds<a name='wls_datasource_shrinkfrequencyseconds'>

Shrink Frequency Seconds.


[Back to overview of wls_datasource](#attributes)


### source_path<a name='wls_datasource_source_path'>



An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       source_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:source_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### statementcachesize<a name='wls_datasource_statementcachesize'>

The statement cache size of the datasource.


[Back to overview of wls_datasource](#attributes)


### tags<a name='wls_datasource_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### target<a name='wls_datasource_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_datasource](#attributes)


### targettype<a name='wls_datasource_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_datasource](#attributes)


### testconnectionsonreserve<a name='wls_datasource_testconnectionsonreserve'>

the testconnectionsonreserve enabled on the jdbc driver

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_datasource](#attributes)


### testfrequency<a name='wls_datasource_testfrequency'>

The number of seconds a WebLogic Server instance waits between attempts when testing unused connections. (Requires that you specify a Test Table Name.) Connections that fail the test are closed and reopened to re-establish a valid physical connection.


[Back to overview of wls_datasource](#attributes)


### testtablename<a name='wls_datasource_testtablename'>

The test table statement for the datasource.


[Back to overview of wls_datasource](#attributes)


### timeout<a name='wls_datasource_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_datasource](#attributes)


### url<a name='wls_datasource_url'>

The jdbc url.


[Back to overview of wls_datasource](#attributes)


### user<a name='wls_datasource_user'>

The username to use when connection to the database.

This specfies the username to be used when connecting to the data

    wls_datasource { 'a_datasource':
      ...
      user   => 'a_username',
      ...
    }


The dataource user name is stored as a property in the connection pool. So if you have more properties,
it is recomended that you just use the ` extraproperties`  value. An example:

    wls_datasource { 'a_datasource':
      ...
      extraproperties                  => ['aaaa=1','bbbb=2', 'user=a_username'],
      ...
    }


[Back to overview of wls_datasource](#attributes)


### usexa<a name='wls_datasource_usexa'>

the UseXaDataSourceInterface enabled on the jdbc driver.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_datasource](#attributes)


### wrapdatatypes<a name='wls_datasource_wrapdatatypes'>

Should weblogic wrap data types.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_datasource](#attributes)


### xa_end_only_once<a name='wls_datasource_xa_end_only_once'>

Specifies that <code>XAResource.end()</code> is called only once for each pending <code>XAResource.start()</code>.  This option prevents the XA driver from calling <code>XAResource.end(TMSUSPEND)</code> and <code>XAResource.end(TMSUCCESS)</code> successively. Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_end_only_once => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_end_only_once']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_keep_logical_conn_open_on_release<a name='wls_datasource_xa_keep_logical_conn_open_on_release'>

Enables WebLogic Server to keep the logical JDBC connection open for a global transaction when the physical XA connection is returned to the connection pool.   Select this option if the XA driver used to create database connections or the DBMS requires that a logical JDBC connection be kept open while transaction processing continues (although the physical XA connection can be returned to the connection pool).  Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_keep_logical_conn_open_on_release => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_keep_logical_conn_open_on_release']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_keep_xa_conn_till_tx_complete<a name='wls_datasource_xa_keep_xa_conn_till_tx_complete'>

Enables WebLogic Server to associate the same XA database connection from the connection pool with a global transaction until the transaction completes.  Only applies to connection pools that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_keep_xa_conn_till_tx_complete => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_keep_xa_conn_till_tx_complete']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_need_tx_ctx_on_close<a name='wls_datasource_xa_need_tx_ctx_on_close'>

Specifies whether the XA driver requires a distributed transaction context when closing various JDBC objects (result sets, statements, connections, and so forth). Only applies to connection pools that use an XA driver.  When enabled, SQL exceptions that are thrown while closing the JDBC objects without a transaction context will be suppressed.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_need_tx_ctx_on_close => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_need_tx_ctx_on_close']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_new_xa_conn_for_commit<a name='wls_datasource_xa_new_xa_conn_for_commit'>

Specifies that a dedicated XA connection is used for commit and rollback processing for a global transaction.  Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_new_xa_conn_for_commit => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_new_xa_conn_for_commit']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_recover_only_once<a name='wls_datasource_xa_recover_only_once'>

Specifies that the transaction manager calls recover on the resource only once. Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_recover_only_once => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_recover_only_once']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_resource_health_monitoring<a name='wls_datasource_xa_resource_health_monitoring'>

Enables JTA resource health monitoring for an XA data source.  When enabled, if an XA resource fails to respond to an XA call within the period specified in MaxXACallMillis, WebLogic Server  marks the data source as unhealthy and blocks any further calls to the resource.   This property applies to XA data sources only, and is ignored for data sources that use a non-XA driver.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_resource_health_monitoring => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_resource_health_monitoring']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_retry_duration_seconds<a name='wls_datasource_xa_retry_duration_seconds'>

Determines the duration in seconds for which the transaction manager will perform recover operations on the resource.  A value of zero indicates that no retries will be performed.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_retry_duration_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_retry_duration_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### xa_retry_interval_seconds<a name='wls_datasource_xa_retry_interval_seconds'>

The number of seconds between XA retry operations if XARetryDurationSeconds is set to a positive value.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_retry_interval_seconds => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_retry_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### xa_rollback_local_tx_upon_conn_close<a name='wls_datasource_xa_rollback_local_tx_upon_conn_close'>

Enables WebLogic Server to call <code>rollback()</code> on the connection before returning the connection to the connection pool.  Enabling this attribute will have a performance impact as the rollback call requires communication with the database server.  This option is deprecated.  Its value is currently ignored.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_rollback_local_tx_upon_conn_close => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_rollback_local_tx_upon_conn_close']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_set_transaction_timeout<a name='wls_datasource_xa_set_transaction_timeout'>

Enables WebLogic Server to set a transaction branch timeout based on the value for XaTransactionTimeout.  When enabled, the WebLogic Server Transaction Manager calls <code>XAResource.setTransactionTimeout()</code> before calling <code>XAResource.start</code>, and passes either the XA Transaction Timeout value or the global transaction timeout.   You may want to set a transaction branch timeout if you have long-running transactions that exceed the default timeout value on the XA resource.  Note: To use this feature, the resource manager (typically, the JDBC driver) must support the <code>javax.transaction.xa.XAResource.setTransactionTimeout()</code> method.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_set_transaction_timeout => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_set_transaction_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_datasource](#attributes)


### xa_transaction_timeout<a name='wls_datasource_xa_transaction_timeout'>

The number of seconds to set as the transaction branch timeout.  If set, this value is passed as the transaction timeout value in the <code>XAResource.setTransactionTimeout()</code> call on the XA resource manager, typically the JDBC driver.   When this value is set to <code>0</code>, the WebLogic Server Transaction Manager passes the global WebLogic Server transaction timeout in seconds in the method.  If set, this value should be greater than or equal to the global WebLogic Server transaction timeout.  Note: You must enable XaSetTransactionTimeout to enable setting the transaction branch timeout.

An example on how to use this:

    wls_datasource {a_wls_datasource :
       ...
       xa_transaction_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_datasource:xa_transaction_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_datasource](#attributes)


### xaproperties<a name='wls_datasource_xaproperties'>

Datasource XA properties.

Here is an example that uses `xaproperties`:

    wls_datasource { 'jmsDS':
      ensure                     => 'present',
      drivername                 => 'com.mysql.jdbc.Driver',
      globaltransactionsprotocol => 'None',
      initialcapacity            => '1',
      jndinames                  => ['jmsDS'],
      maxcapacity                => '15',
      mincapacity                => '1',
      statementcachesize         => '10',
      testconnectionsonreserve   => '0',
      target                     => ['WebCluster'],
      targettype                 => ['Cluster'],
      testtablename              => 'SQL SELECT 1',
      url                        => 'jdbc:mysql://10.10.10.10:3306/jms',
      user                       => 'jms',
      password                   => 'pass',
      usexa                      => '1',
      xaproperties               => ['RollbackLocalTxUponConnClose=0', 'RecoverOnlyOnce=0', 'KeepLogicalConnOpenOnRelease=0', 'KeepXaConnTillTxComplete=1', 'XaTransactionTimeout=14400', 'XaRetryIntervalSeconds=60', 'XaRetryDurationSeconds=0', 'ResourceHealthMonitoring=1', 'NewXaConnForCommit=0', 'XaSetTransactionTimeout=1', 'XaEndOnlyOnce=0', 'NeedTxCtxOnClose=0'],
      # To Optionally Configure as Gridlink Datasource
      fanenabled                 => '1',
      onsnodelist                => '10.10.10.110:6200,10.10.10.111:6200',
    }

`xaproperties` are case sensitive and should be provided as an array containing **all** values. Use WLST
and run ls() in the JDBCXAParams component of your datasource to determine the valid XA properties which
can be set, or use puppet resource wls_datasource


[Back to overview of wls_datasource](#attributes)

