---
title: wls_deployment
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a cluster in an WebLogic domain.

Here is an example on how you should use this:

    # 'jersey-bundle' will use default as wls_setting identifier
    wls_deployment{'jersey-bundle':
      ensure            => 'present',
      deploymenttype    => 'Library',
      stagingmode       => 'nostage',
      remote            => "1",
      upload            => "1",
      target            => ['AdminServer', 'WebCluster'],
      targettype        => ['Server', 'Cluster'],
      versionidentifier => '1.18@1.18.0.0',
    }

In this example you are managing a deployment in the default domain. When you want to
manage a deployment in a specific domain, you can use:

    wls_deployment{'my_domain/webapp':
      ensure            => 'present',
      deploymenttype    => 'AppDeployment',
      stagingmode       => 'nostage',
      remote            => "1",
      upload            => "1",
      target            => ['WebCluster'],
      targettype        => ['Cluster'],
      versionidentifier => '1.1@1.1.0.0',
      require           => Wls_deployment['jersey-bundle']
    }

Check the [WebLogic documentation](https://docs.oracle.com/middleware/1212/wls/INTRO/deploying.htm#INTRO201) for more information
about application deployment.

## Attributes



Attribute Name                                         | Short Description                                                                                                           |
------------------------------------------------------ | --------------------------------------------------------------------------------------------------------------------------- |
[deployment_name](#wls_deployment_deployment_name)     | The deployment name
                                                                                                        |
[deployment_order](#wls_deployment_deployment_order)   | An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup. |
[deploymenttype](#wls_deployment_deploymenttype)       | The deployment type
                                                                                                        |
[domain](#wls_deployment_domain)                       | With this parameter, you identify the domain, where your objects is in.                                                     |
[ensure](#wls_deployment_ensure)                       | The basic property that the resource should be in.                                                                          |
[localpath](#wls_deployment_localpath)                 | The local path of the artifact
                                                                                             |
[name](#wls_deployment_name)                           | The name.                                                                                                                   |
[planpath](#wls_deployment_planpath)                   | The path of the deploymentplan
                                                                                             |
[provider](#wls_deployment_provider)                   | resource.                                                                                                                   |
[remote](#wls_deployment_remote)                       | remote option for deployment.                                                                                               |
[stagingmode](#wls_deployment_stagingmode)             | The staging type
                                                                                                           |
[target](#wls_deployment_target)                       | The target name
                                                                                                            |
[targettype](#wls_deployment_targettype)               | The type of the target
                                                                                                     |
[timeout](#wls_deployment_timeout)                     | Timeout for applying a resource.                                                                                            |
[upload](#wls_deployment_upload)                       | Upload option for deployment.                                                                                               |
[versionidentifier](#wls_deployment_versionidentifier) | The version identifier.                                                                                                     |




### deployment_name<a name='wls_deployment_deployment_name'>

The deployment name


[Back to overview of wls_deployment](#attributes)


### deployment_order<a name='wls_deployment_deployment_order'>

An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.
Units with lower values are deployed before those with higher values.


[Back to overview of wls_deployment](#attributes)


### deploymenttype<a name='wls_deployment_deploymenttype'>

The deployment type

Valid values are `Library`, `AppDeployment`. 
[Back to overview of wls_deployment](#attributes)


### domain<a name='wls_deployment_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_deployment](#attributes)


### ensure<a name='wls_deployment_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_deployment](#attributes)


### localpath<a name='wls_deployment_localpath'>

The local path of the artifact


[Back to overview of wls_deployment](#attributes)


### name<a name='wls_deployment_name'>

The name.


[Back to overview of wls_deployment](#attributes)


### planpath<a name='wls_deployment_planpath'>

The path of the deploymentplan


[Back to overview of wls_deployment](#attributes)


### provider<a name='wls_deployment_provider'>

The specific backend to use for this `wls_deployment`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a deployment in an WebLogic domain via regular WLST


[Back to overview of wls_deployment](#attributes)


### remote<a name='wls_deployment_remote'>

remote option for deployment.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_deployment](#attributes)


### stagingmode<a name='wls_deployment_stagingmode'>

The staging type

Valid values are `callback-polling`, `nostage`, `stage`, `external_stage`. 
[Back to overview of wls_deployment](#attributes)


### target<a name='wls_deployment_target'>

The target name


[Back to overview of wls_deployment](#attributes)


### targettype<a name='wls_deployment_targettype'>

The type of the target


[Back to overview of wls_deployment](#attributes)


### timeout<a name='wls_deployment_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_deployment](#attributes)


### upload<a name='wls_deployment_upload'>

Upload option for deployment.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_deployment](#attributes)


### versionidentifier<a name='wls_deployment_versionidentifier'>

The version identifier.


[Back to overview of wls_deployment](#attributes)

