---
title: wls_foreign_jndi_provider_link
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a datasource in an WebLogic domain.

Here is an example on how you should use this:

    wls_foreign_jndi_provider_link { 'LDAP:aaaaa':
      ensure           => 'present',
      local_jndi_name  => 'aaaaa',
      remote_jndi_name => 'bbbbb',
    }

In this example you are managing a foreign jndi provider link in the default domain. When you want to
manage a foreign jndi provider link in a specific domain, you can use:

    wls_foreign_jndi_provider_link { 'my_domain/LDAP:ccccc':
      ensure           => 'present',
      local_jndi_name  => 'ccccc',
      remote_jndi_name => 'ddddd',
    }

## Attributes



Attribute Name                                                       | Short Description                                                         |
-------------------------------------------------------------------- | ------------------------------------------------------------------------- |
[domain](#wls_foreign_jndi_provider_link_domain)                     | With this parameter, you identify the domain, where your objects is in.   |
[ensure](#wls_foreign_jndi_provider_link_ensure)                     | The basic property that the resource should be in.                        |
[link_name](#wls_foreign_jndi_provider_link_link_name)               | The link name
                                                            |
[local_jndi_name](#wls_foreign_jndi_provider_link_local_jndi_name)   | The local jndi name to use for the Foreign JNDI provider link
            |
[name](#wls_foreign_jndi_provider_link_name)                         | The name.                                                                 |
[notes](#wls_foreign_jndi_provider_link_notes)                       | Optional information that you can include to describe this configuration. |
[provider](#wls_foreign_jndi_provider_link_provider)                 | resource.                                                                 |
[provider_name](#wls_foreign_jndi_provider_link_provider_name)       | The provider name
                                                        |
[remote_jndi_name](#wls_foreign_jndi_provider_link_remote_jndi_name) | The remote jndi name to use for the Foreign JNDI provider link
           |
[tags](#wls_foreign_jndi_provider_link_tags)                         | Return all tags on this Configuration MBean
                              |




### domain<a name='wls_foreign_jndi_provider_link_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### ensure<a name='wls_foreign_jndi_provider_link_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### link_name<a name='wls_foreign_jndi_provider_link_link_name'>

The link name


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### local_jndi_name<a name='wls_foreign_jndi_provider_link_local_jndi_name'>

The local jndi name to use for the Foreign JNDI provider link


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### name<a name='wls_foreign_jndi_provider_link_name'>

The name.


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### notes<a name='wls_foreign_jndi_provider_link_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_foreign_jndi_provider_link {a_wls_foreign_jndi_provider_link :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_jndi_provider_link:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### provider<a name='wls_foreign_jndi_provider_link_provider'>

The specific backend to use for this `wls_foreign_jndi_provider_link`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage foreign JNDI provider links


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### provider_name<a name='wls_foreign_jndi_provider_link_provider_name'>

The provider name


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### remote_jndi_name<a name='wls_foreign_jndi_provider_link_remote_jndi_name'>

The remote jndi name to use for the Foreign JNDI provider link


[Back to overview of wls_foreign_jndi_provider_link](#attributes)


### tags<a name='wls_foreign_jndi_provider_link_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_foreign_jndi_provider_link {a_wls_foreign_jndi_provider_link :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_jndi_provider_link:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_jndi_provider_link](#attributes)

