---
title: wls_group
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage group in a WebLogic Security Realm.

Here is an example on how you should use this:

    wls_group { 'SuperUsers':
      ensure                 => 'present',
      authenticationprovider => 'DefaultAuthenticator',
      description            => 'SuperUsers',
      realm                  => 'myrealm',
      users                  => ['testuser2'],
    }

In this example you are managing a group in the default domain. When you want to
manage a group in a specific domain, you can use:

    wls_group { 'my_domain/TestGroup':
      ensure                 => 'present',
      authenticationprovider => 'DefaultAuthenticator',
      description            => 'TestGroup',
      realm                  => 'myrealm',
      users                  => ['testuser1','testuser2'],
    }

## Attributes



Attribute Name                                              | Short Description                                                       |
----------------------------------------------------------- | ----------------------------------------------------------------------- |
[authenticationprovider](#wls_group_authenticationprovider) | The security authentication providers of the domain.                    |
[description](#wls_group_description)                       | The group description
                                                  |
[domain](#wls_group_domain)                                 | With this parameter, you identify the domain, where your objects is in. |
[ensure](#wls_group_ensure)                                 | The basic property that the resource should be in.                      |
[group_name](#wls_group_group_name)                         | The group name
                                                         |
[name](#wls_group_name)                                     | The name.                                                               |
[provider](#wls_group_provider)                             | resource.                                                               |
[realm](#wls_group_realm)                                   | The security realm of the domain
                                       |
[timeout](#wls_group_timeout)                               | Timeout for applying a resource.                                        |
[users](#wls_group_users)                                   | The users of the group
                                                 |




### authenticationprovider<a name='wls_group_authenticationprovider'>

The security authentication providers of the domain.


[Back to overview of wls_group](#attributes)


### description<a name='wls_group_description'>

The group description


[Back to overview of wls_group](#attributes)


### domain<a name='wls_group_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_group](#attributes)


### ensure<a name='wls_group_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_group](#attributes)


### group_name<a name='wls_group_group_name'>

The group name


[Back to overview of wls_group](#attributes)


### name<a name='wls_group_name'>

The name.


[Back to overview of wls_group](#attributes)


### provider<a name='wls_group_provider'>

The specific backend to use for this `wls_group`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage groups of a WebLogic Security REALM


[Back to overview of wls_group](#attributes)


### realm<a name='wls_group_realm'>

The security realm of the domain


[Back to overview of wls_group](#attributes)


### timeout<a name='wls_group_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_group](#attributes)


### users<a name='wls_group_users'>

The users of the group


[Back to overview of wls_group](#attributes)

