---
title: wls_jms_queue
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a Queue in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_jms_queue { 'jmsClusterModule:ErrorQueue':
      ensure            => 'present',
      defaulttargeting  => '0',
      distributed       => '1',
      expirationpolicy  => 'Discard',
      jndiname          => 'jms/ErrorQueue',
      redeliverydelay   => '-1',
      redeliverylimit   => '-1',
      subdeployment     => 'jmsServers',
      timetodeliver     => '-1',
      timetolive        => '-1',
      templatename      => 'Template',
      messagelogging    => '1',
      consumptionpaused => '0',
      insertionpaused   => '0',
      productionpaused  => '0',
    }

    **WARNING** When you want to `absent` a queue. you must ensure that
    the `distributed` parameter is specified.

        wls_jms_queue { 'jmsClusterModule:ErrorQueue':
          ensure      => 'absent',
          distributed => '1',
        }

    Failure to specify the correct value for `distributed`, will result
    in an error on removal of the queue.

## Attributes



Attribute Name                                                                          | Short Description                                                                                                                                                                                                                          |
--------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[attach_sender](#wls_jms_queue_attach_sender)                                           | Specifies whether messages landing on this destination should attach the credential of the sending user.                                                                                                                                   |
[balancingpolicy](#wls_jms_queue_balancingpolicy)                                       | balancingpolicy of the distributed queue
                                                                                                                                                                                                  |
[consumption_paused_at_startup](#wls_jms_queue_consumption_paused_at_startup)           | Specifies whether consumption is paused on a destination at startup.                                                                                                                                                                       |
[consumptionpaused](#wls_jms_queue_consumptionpaused)                                   | Specifies whether consumption is paused on a destination at startup.                                                                                                                                                                       |
[default_targeting_enabled](#wls_jms_queue_default_targeting_enabled)                   | Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.                                                                                                               |
[default_unit_of_order](#wls_jms_queue_default_unit_of_order)                           | Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name.                                                                                                     |
[defaulttargeting](#wls_jms_queue_defaulttargeting)                                     | or uses the subdeployment targeting mechanism.                                                                                                                                                                                             |
[delivery_expiration_logging_policy](#wls_jms_queue_delivery_expiration_logging_policy) | The policy that defines what information about the message is logged when the Expiration Policy is set to Log.                                                                                                                             |
[delivery_expiration_policy](#wls_jms_queue_delivery_expiration_policy)                 | The message Expiration Policy to use when an expired message is encountered on a destination.                                                                                                                                              |
[delivery_redelivery_limit](#wls_jms_queue_delivery_redelivery_limit)                   | The number of redelivery tries a message can have before it is moved to the error destination.                                                                                                                                             |
[delivery_template_bean](#wls_jms_queue_delivery_template_bean)                         | This is used to find the template bean for this destination
                                                                                                                                                                               |
[deliverymode](#wls_jms_queue_deliverymode)                                             | deliverymode of the queue
                                                                                                                                                                                                                 |
[destination_keys](#wls_jms_queue_destination_keys)                                     | The destination keys the queue or topic.                                                                                                                                                                                                   |
[distributed](#wls_jms_queue_distributed)                                               | Distributed queue
                                                                                                                                                                                                                         |
[domain](#wls_jms_queue_domain)                                                         | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                                    |
[ensure](#wls_jms_queue_ensure)                                                         | The basic property that the resource should be in.                                                                                                                                                                                         |
[errordestination](#wls_jms_queue_errordestination)                                     | errordestination of the queue.                                                                                                                                                                                                             |
[errordestinationtype](#wls_jms_queue_errordestinationtype)                             | error destination jms type of the topic
                                                                                                                                                                                                   |
[expirationloggingpolicy](#wls_jms_queue_expirationloggingpolicy)                       | expirationloggingpolicy of the queue
                                                                                                                                                                                                      |
[expirationpolicy](#wls_jms_queue_expirationpolicy)                                     | expirationpolicy of the queue
                                                                                                                                                                                                             |
[forward_delay](#wls_jms_queue_forward_delay)                                           | The number of seconds after which a uniform distributed queue member with no consumers will wait before forwarding its messages to other uniform distributed queue members that do have consumers.                                         |
[forwarddelay](#wls_jms_queue_forwarddelay)                                             | The number of seconds after which a uniform distributed queue member with no consumers will wait before forwarding its messages to other uniform distributed queue members that do have consumers.                                         |
[incomplete_work_expiration_time](#wls_jms_queue_incomplete_work_expiration_time)       | Specifies the maximum length of time, in milliseconds, before undelivered messages in an incomplete UOW are expired.                                                                                                                       |
[insertion_paused_at_startup](#wls_jms_queue_insertion_paused_at_startup)               | Specifies whether new message insertion is paused on a destination at startup.                                                                                                                                                             |
[insertionpaused](#wls_jms_queue_insertionpaused)                                       | Insertion is paused at startup.                                                                                                                                                                                                            |
[jms_create_destination_identifier](#wls_jms_queue_jms_create_destination_identifier)   | A reference name for a destination or a member of a distributed destination that provides a way to lookup that destination without JNDI using <code>javax.jms.Session createQueue </code> or <code>createTopic</code>.                     |
[jmsmodule](#wls_jms_queue_jmsmodule)                                                   | The JMS module name.                                                                                                                                                                                                                       |
[jndi_name](#wls_jms_queue_jndi_name)                                                   | The global JNDI name used to look up the destination within the JNDI namespace.                                                                                                                                                            |
[jndiname](#wls_jms_queue_jndiname)                                                     | The jndi name.                                                                                                                                                                                                                             |
[load_balancing_policy](#wls_jms_queue_load_balancing_policy)                           | Determines how messages are distributed to the members of this destination.                                                                                                                                                                |
[local_jndi_name](#wls_jms_queue_local_jndi_name)                                       | The local JNDI name used to look up the destination within the JNDI namespace of the server where the destination resource is targeted.                                                                                                    |
[log_message_logging_enabled](#wls_jms_queue_log_message_logging_enabled)               | Specifies whether the module logs information about the message life cycle.                                                                                                                                                                |
[log_message_logging_format](#wls_jms_queue_log_message_logging_format)                 | Defines which information about the message is logged.                                                                                                                                                                                     |
[log_template_bean](#wls_jms_queue_log_template_bean)                                   | Finds the template bean for this destination.                                                                                                                                                                                              |
[maximum_message_size](#wls_jms_queue_maximum_message_size)                             | The maximum size of a message that is accepted from producers on this destination.                                                                                                                                                         |
[messagelogging](#wls_jms_queue_messagelogging)                                         | Message logging for JMS
                                                                                                                                                                                                                   |
[messaging_performance_preference](#wls_jms_queue_messaging_performance_preference)     | Controls how long destinations are willing to wait to create full batches of available messages (if at all) for delivery to consumers.                                                                                                     |
[name](#wls_jms_queue_name)                                                             | The name.                                                                                                                                                                                                                                  |
[notes](#wls_jms_queue_notes)                                                           | Optional information that you can include to describe this named JMS descriptor bean.                                                                                                                                                      |
[override_delivery_mode](#wls_jms_queue_override_delivery_mode)                         | The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.                                                                                                |
[override_priority](#wls_jms_queue_override_priority)                                   | The priority assigned to all messages that arrive at this destination, regardless of the Priority specified by the message producer.                                                                                                       |
[override_redelivery_delay](#wls_jms_queue_override_redelivery_delay)                   | The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory.                                                               |
[override_template_bean](#wls_jms_queue_override_template_bean)                         | This is used to find the template bean for this destination
                                                                                                                                                                               |
[override_time_to_deliver](#wls_jms_queue_override_time_to_deliver)                     | The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. |
[override_time_to_live](#wls_jms_queue_override_time_to_live)                           | The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer.                                                                                           |
[production_paused_at_startup](#wls_jms_queue_production_paused_at_startup)             | Specifies whether new message production is paused on a destination at startup.                                                                                                                                                            |
[productionpaused](#wls_jms_queue_productionpaused)                                     | 
                                                                                                                                                                                                                                          |
[provider](#wls_jms_queue_provider)                                                     | resource.                                                                                                                                                                                                                                  |
[queue_name](#wls_jms_queue_queue_name)                                                 | The queue name
                                                                                                                                                                                                                            |
[quota](#wls_jms_queue_quota)                                                           | The name of the quota for the jms object.                                                                                                                                                                                                  |
[redeliverydelay](#wls_jms_queue_redeliverydelay)                                       | redeliverydelay of the queue
                                                                                                                                                                                                              |
[redeliverylimit](#wls_jms_queue_redeliverylimit)                                       | redeliverylimit of the queue
                                                                                                                                                                                                              |
[reset_delivery_count_on_forward](#wls_jms_queue_reset_delivery_count_on_forward)       | Determines whether or not the delivery count is reset during message forwarding between distributed queue members.                                                                                                                         |
[saf_export_policy](#wls_jms_queue_saf_export_policy)                                   | Specifies whether a user can send messages to a destination using Store-and-Forward.                                                                                                                                                       |
[sub_deployment_name](#wls_jms_queue_sub_deployment_name)                               | Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.                                                                                                       |
[subdeployment](#wls_jms_queue_subdeployment)                                           | The subdeployment name.                                                                                                                                                                                                                    |
[template](#wls_jms_queue_template)                                                     | The JMS template from which the destination is derived.                                                                                                                                                                                    |
[templatename](#wls_jms_queue_templatename)                                             | The template name
                                                                                                                                                                                                                         |
[thresholds_bytes_high](#wls_jms_queue_thresholds_bytes_high)                           | The upper threshold (total number of bytes in this destination) that triggers logging or flow control events.                                                                                                                              |
[thresholds_bytes_low](#wls_jms_queue_thresholds_bytes_low)                             | The lower threshold (total number of bytes in this destination) that triggers logging or flow control events.                                                                                                                              |
[thresholds_messages_high](#wls_jms_queue_thresholds_messages_high)                     | The upper threshold (total number of messages in this destination) that triggers logging or flow control events.                                                                                                                           |
[thresholds_messages_low](#wls_jms_queue_thresholds_messages_low)                       | The lower threshold (total number of messages in this destination) that triggers logging or flow control events.                                                                                                                           |
[thresholds_template_bean](#wls_jms_queue_thresholds_template_bean)                     | Finds the template bean for this destination.                                                                                                                                                                                              |
[timeout](#wls_jms_queue_timeout)                                                       | Timeout for applying a resource.                                                                                                                                                                                                           |
[timetodeliver](#wls_jms_queue_timetodeliver)                                           | timetodeliver of the queue
                                                                                                                                                                                                                |
[timetolive](#wls_jms_queue_timetolive)                                                 | timetolive of the queue
                                                                                                                                                                                                                   |
[unit_of_order_routing](#wls_jms_queue_unit_of_order_routing)                           | Determines how a distributed destination member is selected as the destination for a message that is part of a unit-of-order.                                                                                                              |
[unit_of_work_handling_policy](#wls_jms_queue_unit_of_work_handling_policy)             | Specifies whether the Unit-of-Work (UOW) feature is enabled for this destination.                                                                                                                                                          |




### attach_sender<a name='wls_jms_queue_attach_sender'>

Specifies whether messages landing on this destination should attach the credential of the sending user. You should consult the JMSXUserID documentation in Programming WebLogic JMS before using this feature.  <ul> <li>Supports The JMSXUserID property is set with the security principal of the sending user if requested. The sender can request its identity to be attached to its messages by using a connection factory with the AttachJMSXUserID security property enabled.</li>  <li>Never The JMSXUserID property is never set with the security principal of the sending user no matter how the AttachJMSXUserID property is configured on connection factories.</li>  <li>Always The JMSXUserID property is always set with the security principal of the sending user no matter how the AttachJMSXUserID property is configured on connection factories.</li> </ul>  This attribute is dynamically configurable. A dynamic change of this attribute will affect only messages received after the update has been made.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       attach_sender => 'supports'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:attach_sender']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### balancingpolicy<a name='wls_jms_queue_balancingpolicy'>

balancingpolicy of the distributed queue

Valid values are `absent`, `Round-Robin`, `Random`. 
[Back to overview of wls_jms_queue](#attributes)


### consumption_paused_at_startup<a name='wls_jms_queue_consumption_paused_at_startup'>

Specifies whether consumption is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Consumption Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Consumption Paused is explicitly disabled for this destination. </li>  <li>true Consumption Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       consumption_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:consumption_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### consumptionpaused<a name='wls_jms_queue_consumptionpaused'>

Specifies whether consumption is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Consumption Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Consumption Paused is explicitly disabled for this destination. </li>  <li>true Consumption Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       consumptionpaused => '1'
       ...
    }

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_queue](#attributes)


### default_targeting_enabled<a name='wls_jms_queue_default_targeting_enabled'>

Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.  When set to true, this resource implicitly inherits the targeting of its parent module. When set to false, this resource gets targeted based its subdeployment's targets, if one is specified.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       default_targeting_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:default_targeting_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### default_unit_of_order<a name='wls_jms_queue_default_unit_of_order'>

Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name. Any message arriving at this destination that does not already belong to a unit-of-order is assigned this default name.  This field is recommended for advanced use. Generally, it is  recommended to set a message unit-of-order using application calls or connection factory configuration. When relying on a destination default unit order to enforce ordering with a distributed destination, the application must be aware that unit-of-order routing doesn't apply. Instead the application must specifically ensure that any particular set of messages that must be processed in order are all sent to the same specific member destination even in the event of process failures or service migration.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       default_unit_of_order => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:default_unit_of_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### defaulttargeting<a name='wls_jms_queue_defaulttargeting'>

Specifies whether this JMS resource defaults to the parent module's targeting
or uses the subdeployment targeting mechanism.  When set to true, this
resource implicitly inherits the targeting of its parent module. When set to
false, this resource gets targeted based its subdeployment's targets, if one
is specified.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_queue](#attributes)


### delivery_expiration_logging_policy<a name='wls_jms_queue_delivery_expiration_logging_policy'>

The policy that defines what information about the message is logged when the Expiration Policy is set to Log. The valid logging policy values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>  When specifying multiple values, enter them as a comma-separated list. The <code>%header%</code> and <code>%properties% </code> values are not case sensitive. For example, you could use <code>"%header%,%properties%"</code> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <code>"%header, name, address, city, state, zip"</code>.  Note: The <code>JMSMessageID</code> field is always logged and cannot be turned off. Therefore, if the Expiration Logging Policy is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <code>JMSMessageID</code> of the message.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       delivery_expiration_logging_policy => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:delivery_expiration_logging_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### delivery_expiration_policy<a name='wls_jms_queue_delivery_expiration_policy'>

The message Expiration Policy to use when an expired message is encountered on a destination. The valid expiration policies are:  None - Same as the Discard policy; expired messages are simply removed from the destination.  Discard - Removes expired messages from the messaging system. The removal is not logged and the message is not redirected to another location. If no value is defined for a given destination (i.e., None), then expired messages are discarded.  Log - Removes expired messages from the system and writes an entry to the server log file indicating that the messages have been removed from the system. The actual information that is logged is defined by the Expiration Logging Policy.  Redirect - Moves expired messages from their current location to the Error Destination defined for the destination. The message retains its body, and all of its properties. The message also retains all of its header fields, but with the following exceptions: <ul> <li> The destination for the message becomes the error destination. <li> All property overrides associated with the error destination are applied to the redirected message. <li> If there is no Time-To-Live Override value for the error destination, then the message receives a new Expiration Time of zero (indicating that it will not expire again). </ul>  It is illegal to use the Redirect policy when there is no valid error destination defined for the destination. Similarly, it is illegal to remove the error destination for a destination that is using the Redirect policy.  Note: The Maximum Message quota is only enforced for sending new messages. It is ignored when moving messages because of the Redirect policy.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       delivery_expiration_policy => 'Discard'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:delivery_expiration_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### delivery_redelivery_limit<a name='wls_jms_queue_delivery_redelivery_limit'>

The number of redelivery tries a message can have before it is moved to the error destination. This setting overrides any redelivery limit set by the message sender. If the redelivery limit is configured, but no error destination is configured, then persistent and non-persistent messages are simply dropped (deleted) when they reach their redelivery limit.  The default value (-1) specifies that the destination will not override the message sender's redelivery limit setting.   Note: WebLogic Server supports the JMSXDeliveryCount message property, which specifies the number of message delivery attempts, where the first attempt is 1, the next attempt is 2, and so on. WebLogic Server makes a best effort to persist the delivery count, so that the delivery count does not reset back to 1 after a server reboot.  This attribute is dynamically configurable, but only incoming messages are impacted; previously sent messages continue to use their original redelivery limit.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       delivery_redelivery_limit => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:delivery_redelivery_limit']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### delivery_template_bean<a name='wls_jms_queue_delivery_template_bean'>

This is used to find the template bean for this destination

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       delivery_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:delivery_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### deliverymode<a name='wls_jms_queue_deliverymode'>

deliverymode of the queue

Valid values are `absent`, `No-Delivery`, `Persistent`, `Non-Persistent`. 
[Back to overview of wls_jms_queue](#attributes)


### destination_keys<a name='wls_jms_queue_destination_keys'>

The destination keys the queue or topic.


[Back to overview of wls_jms_queue](#attributes)


### distributed<a name='wls_jms_queue_distributed'>

Distributed queue

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_queue](#attributes)


### domain<a name='wls_jms_queue_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jms_queue](#attributes)


### ensure<a name='wls_jms_queue_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jms_queue](#attributes)


### errordestination<a name='wls_jms_queue_errordestination'>

errordestination of the queue.


[Back to overview of wls_jms_queue](#attributes)


### errordestinationtype<a name='wls_jms_queue_errordestinationtype'>

error destination jms type of the topic

Valid values are `Queues`, `Topics`. 
[Back to overview of wls_jms_queue](#attributes)


### expirationloggingpolicy<a name='wls_jms_queue_expirationloggingpolicy'>

expirationloggingpolicy of the queue


[Back to overview of wls_jms_queue](#attributes)


### expirationpolicy<a name='wls_jms_queue_expirationpolicy'>

expirationpolicy of the queue

Valid values are `absent`, `Discard`, `Log`, `Redirect`. 
[Back to overview of wls_jms_queue](#attributes)


### forward_delay<a name='wls_jms_queue_forward_delay'>

The number of seconds after which a uniform distributed queue member with no consumers will wait before forwarding its messages to other uniform distributed queue members that do have consumers.  The default value of -1 disables this feature so that no messages are forwarded to other uniform distributed queue members.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       forward_delay => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:forward_delay']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### forwarddelay<a name='wls_jms_queue_forwarddelay'>

The number of seconds after which a uniform distributed queue member with no consumers will wait before forwarding its messages to other uniform distributed queue members that do have consumers.


[Back to overview of wls_jms_queue](#attributes)


### incomplete_work_expiration_time<a name='wls_jms_queue_incomplete_work_expiration_time'>

Specifies the maximum length of time, in milliseconds, before undelivered messages in an incomplete UOW are expired. Such messages will then follow the expiration policy defined for undeliverable messages.  Note: An error destination for UOW messages cannot be configured with a Unit-of-Work Handling Policy of Single Message Delivery value.  This attribute is effective only if the Unit-of-Work Handling Policy is set to Single Message Delivery value. A value of -1 means that UOW messages will never expire.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       incomplete_work_expiration_time => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:incomplete_work_expiration_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### insertion_paused_at_startup<a name='wls_jms_queue_insertion_paused_at_startup'>

Specifies whether new message insertion is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Insertion Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Insertion Paused is explicitly disabled for this destination.</li>  <li>true Insertion Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       insertion_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:insertion_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### insertionpaused<a name='wls_jms_queue_insertionpaused'>

Insertion is paused at startup.

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_queue](#attributes)


### jms_create_destination_identifier<a name='wls_jms_queue_jms_create_destination_identifier'>

A reference name for a destination or a member of a distributed destination that provides a way to lookup that destination without JNDI using <code>javax.jms.Session createQueue </code> or <code>createTopic</code>. See "How to Lookup a Destination" in  Programming JMS for more information on how to use this attribute.  This name must be unique within the scope of the JMS server to which this destination is targeted. However, it does not need to be unique within the scope of an entire JMS module or WebLogic Cluster. For example, two queues can have the same destination name as long as those queues are targeted to different JMS servers.  Note: Since this name must be unique within the scope of a JMS server, verify whether other JMS modules may contain destination names that conflict with this name. It is the responsibility of the deployer to resolve the destination names targeted to JMS servers.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       jms_create_destination_identifier => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:jms_create_destination_identifier']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### jmsmodule<a name='wls_jms_queue_jmsmodule'>

The JMS module name.


[Back to overview of wls_jms_queue](#attributes)


### jndi_name<a name='wls_jms_queue_jndi_name'>

The global JNDI name used to look up the destination within the JNDI namespace.  In a clustered environment, this name is propagated to the entire cluster. If you want the JNDI name to be bound only on the local server, and not propagated to the rest of the cluster, then use the <code>Local JNDI Name</code> parameter.  If not specified, the destination name will not be advertised through the global JNDI namespace.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### jndiname<a name='wls_jms_queue_jndiname'>

The jndi name.


[Back to overview of wls_jms_queue](#attributes)


### load_balancing_policy<a name='wls_jms_queue_load_balancing_policy'>

Determines how messages are distributed to the members of this destination.  Choose from the following distribution techniques: <ul> <li>Round-Robin The system maintains an ordering of physical topic members within the set by distributing the messaging load across the topic members one at a time in the order that they are defined in the configuration file. Each WebLogic Server instance maintains an identical ordering, but may be at a different point within the ordering. If weights are assigned to any of the topic members in the set, then those members appear multiple times in the ordering.  <li>Random The weight assigned to the topic members is used to compute a weighted distribution for the members of the set. The messaging load is distributed across the topic members by pseudo-randomly accessing the distribution. In the short run, the load will not be directly proportional to the weight. In the long run, the distribution will approach the limit of the distribution. A pure random distribution can be achieved by setting all the weights to the same value, which is typically set to 1. </ul>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       load_balancing_policy => 'Round-Robin'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:load_balancing_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### local_jndi_name<a name='wls_jms_queue_local_jndi_name'>

The local JNDI name used to look up the destination within the JNDI namespace of the server where the destination resource is targeted. In a clustered environment, this name is bound only on the local server instance and is not propagated to the rest of the cluster.  A destination can have both a local JNDI name and a (global) JNDI name.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       local_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:local_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### log_message_logging_enabled<a name='wls_jms_queue_log_message_logging_enabled'>

Specifies whether the module logs information about the message life cycle.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       log_message_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:log_message_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### log_message_logging_format<a name='wls_jms_queue_log_message_logging_format'>

Defines which information about the message is logged. Valid values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>   When specifying multiple values, enter them as a comma-separated list. The <tt>%header%</tt> and <tt>%properies% </tt> values are not case sensitive. For example, you could use <tt>"%header%,%properties%"</tt> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <tt>"%header, name, address, city, state, zip"</tt> .   Note: The <tt>JMSMessageID</tt> field is always logged and cannot be turned off. Therefore, if the Message Logging Format is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <tt>JMSMessageID</tt> of the message. Gets the "message-logging-format" element

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       log_message_logging_format => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:log_message_logging_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### log_template_bean<a name='wls_jms_queue_log_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       log_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:log_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### maximum_message_size<a name='wls_jms_queue_maximum_message_size'>

The maximum size of a message that is accepted from producers on this destination.  The message size includes the message body, any user-defined properties, and the user-defined JMS header fields: <tt>JMSCorrelationID</tt> and <tt>JMSType</tt> . Producers sending messages that exceed the configured maximum message size for the destination receive a <tt>ResourceAllocationException</tt> .  The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination.  This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       maximum_message_size => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:maximum_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### messagelogging<a name='wls_jms_queue_messagelogging'>

Message logging for JMS

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_queue](#attributes)


### messaging_performance_preference<a name='wls_jms_queue_messaging_performance_preference'>

Controls how long destinations are willing to wait to create full batches of available messages (if at all) for delivery to consumers. At the minimum value, batching is disabled; at the default value, less-than-full batches will not wait and are delivered immediately with currently available messages; tuning higher than the default value controls the maximum wait time for additional messages before less-than-full batches are delivered to consumers.  The maximum message count of a full batch is controlled by the JMS connection factory's Messages Maximum setting.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       messaging_performance_preference => '25'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:messaging_performance_preference']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### name<a name='wls_jms_queue_name'>

The name.


[Back to overview of wls_jms_queue](#attributes)


### notes<a name='wls_jms_queue_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### override_delivery_mode<a name='wls_jms_queue_override_delivery_mode'>

The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.  A value of <tt>No-Delivery</tt> specifies that the DeliveryMode will not be overridden.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       override_delivery_mode => 'No-Delivery'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:override_delivery_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### override_priority<a name='wls_jms_queue_override_priority'>

The priority assigned to all messages that arrive at this destination, regardless of the Priority specified by the message producer. The default value (-1) specifies that the destination will not override the Priority set by the message producer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       override_priority => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:override_priority']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### override_redelivery_delay<a name='wls_jms_queue_override_redelivery_delay'>

The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory. Redelivered queue messages are put back into their originating destination; redelivered topic messages are put back into their originating subscription. The default value (-1) specifies that the destination will not override the RedeliveryDelay setting specified by the consumer and/or connection factory.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.  Note: Changing the RedeliveryDelay override only affects future rollbacks and recovers, it does not affect rollbacks and recovers that have already occurred.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       override_redelivery_delay => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:override_redelivery_delay']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### override_template_bean<a name='wls_jms_queue_override_template_bean'>

This is used to find the template bean for this destination

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       override_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:override_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### override_time_to_deliver<a name='wls_jms_queue_override_time_to_deliver'>

The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. The default value (<tt>-1</tt>) specifies that the destination will not override the TimeToDeliver setting specified by the producer and/or connection factory. The TimeToDeliver override can be specified either as a long or as a schedule.  Note: Changing the TimeToDeliver override only affects future message delivery, it does not affect message delivery of already produced messages.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       override_time_to_deliver => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:override_time_to_deliver']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### override_time_to_live<a name='wls_jms_queue_override_time_to_live'>

The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer. The default value (<tt>-1</tt>) specifies that this setting will not override the TimeToLive setting specified by the message producer.  Range of Values: Between 0 and a positive 64-bit integer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       override_time_to_live => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:override_time_to_live']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### production_paused_at_startup<a name='wls_jms_queue_production_paused_at_startup'>

Specifies whether new message production is paused on a destination at startup.  <ul> <li>default If a JMS template is specified, then this value inherits the template's Production Paused At Startup value. If no JMS template is configured for the destination, then the Default value is equivalent to false.</li>  <li>false Production Paused is explicitly disabled for this destination.</li>  <li>true Production Paused is explicitly turned on for this destination.</li> </ul>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       production_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:production_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### productionpaused<a name='wls_jms_queue_productionpaused'>



Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_queue](#attributes)


### provider<a name='wls_jms_queue_provider'>

The specific backend to use for this `wls_jms_queue`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a queue in a JMS module of an WebLogic domain via regular WLST


[Back to overview of wls_jms_queue](#attributes)


### queue_name<a name='wls_jms_queue_queue_name'>

The queue name


[Back to overview of wls_jms_queue](#attributes)


### quota<a name='wls_jms_queue_quota'>

The name of the quota for the jms object.


[Back to overview of wls_jms_queue](#attributes)


### redeliverydelay<a name='wls_jms_queue_redeliverydelay'>

redeliverydelay of the queue


[Back to overview of wls_jms_queue](#attributes)


### redeliverylimit<a name='wls_jms_queue_redeliverylimit'>

redeliverylimit of the queue


[Back to overview of wls_jms_queue](#attributes)


### reset_delivery_count_on_forward<a name='wls_jms_queue_reset_delivery_count_on_forward'>

Determines whether or not the delivery count is reset during message forwarding between distributed queue members.  The default value of true resets the delivery counts on messages when they are forwarded to another distributed queue member.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       reset_delivery_count_on_forward => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:reset_delivery_count_on_forward']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_queue](#attributes)


### saf_export_policy<a name='wls_jms_queue_saf_export_policy'>

Specifies whether a user can send messages to a destination using Store-and-Forward.  <ul> <li>All All users can send messages to this destination using Store-and-Forward.</li>  <li>None Remote users can not send messages to a destination using Store-and-Forward.</li> </ul>  This attribute is dynamically configurable. A dynamic change of this attribute will affect only messages sent after the update has been made.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       saf_export_policy => 'All'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:saf_export_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### sub_deployment_name<a name='wls_jms_queue_sub_deployment_name'>

Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.  The targets of the sub-deployment will be the targets of this entity.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       sub_deployment_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:sub_deployment_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### subdeployment<a name='wls_jms_queue_subdeployment'>

The subdeployment name.


[Back to overview of wls_jms_queue](#attributes)


### template<a name='wls_jms_queue_template'>

The JMS template from which the destination is derived. A template provides an efficient means of defining multiple destinations with similar configuration values.  If a JMS template is specified, destination parameters that are set to their default values will instead inherit their values from the JMS template at run-time. However, if a JMS template is not defined, then the configuration values for the destination must be specified as part of the destination.  Although you can dynamically modify the configuration of a JMS template, the configuration values on a destination are static.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       template => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:template']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### templatename<a name='wls_jms_queue_templatename'>

The template name


[Back to overview of wls_jms_queue](#attributes)


### thresholds_bytes_high<a name='wls_jms_queue_thresholds_bytes_high'>

The upper threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes exceeds this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a high threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;BytesThresholdLow  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       thresholds_bytes_high => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:thresholds_bytes_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### thresholds_bytes_low<a name='wls_jms_queue_thresholds_bytes_low'>

The lower threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; BytesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected. <!--Gets the "bytes-low" element-->

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       thresholds_bytes_low => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:thresholds_bytes_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### thresholds_messages_high<a name='wls_jms_queue_thresholds_messages_high'>

The upper threshold (total number of messages in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of messages exceeds this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a high threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= MessagesMaximum; &gt;MessagesThresholdLow  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       thresholds_messages_high => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:thresholds_messages_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### thresholds_messages_low<a name='wls_jms_queue_thresholds_messages_low'>

The lower threshold (total number of messages in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of messages falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; MessagesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       thresholds_messages_low => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:thresholds_messages_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### thresholds_template_bean<a name='wls_jms_queue_thresholds_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       thresholds_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:thresholds_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### timeout<a name='wls_jms_queue_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_jms_queue](#attributes)


### timetodeliver<a name='wls_jms_queue_timetodeliver'>

timetodeliver of the queue


[Back to overview of wls_jms_queue](#attributes)


### timetolive<a name='wls_jms_queue_timetolive'>

timetolive of the queue


[Back to overview of wls_jms_queue](#attributes)


### unit_of_order_routing<a name='wls_jms_queue_unit_of_order_routing'>

Determines how a distributed destination member is selected as the destination for a message that is part of a unit-of-order. Hash, indicates that a message producer computes the member destination from the <code>hashCode</code> of the unit-of-order. PathService indicates that the configured Path Service determines the member destination.  Unit-of-Order Routing can be set programmatically with WLProducer, or administratively on the connection factory or destination.   Unit of Order Routing is not dynamically configurable.

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       unit_of_order_routing => 'Hash'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:unit_of_order_routing']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)


### unit_of_work_handling_policy<a name='wls_jms_queue_unit_of_work_handling_policy'>

Specifies whether the Unit-of-Work (UOW) feature is enabled for this destination. A UOW is a set of messages that are processed as a single unit. <ul> <li> Pass-Through By default, this destination does not treat messages as part of a UOW.</li> <li> Single Message Delivery This value should only be selected if UOW consumers are receiving messages on this destination. When selected, UOW messages are formed into a list and are consumed as an <code>ObjectMessage</code> containing the list.</li> </ul>

An example on how to use this:

    wls_jms_queue {a_wls_jms_queue :
       ...
       unit_of_work_handling_policy => 'PassThrough'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_queue:unit_of_work_handling_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_queue](#attributes)

