---
title: wls_jms_sort_destination_key
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage the sort destination key in a JMS module of a WebLogic domain.

Here is an example on how you should use this:

    wls_jms_sort_destination_key { 'jmsClusterModule:JMSPriority':
      ensure        => 'present',
      key_type      => 'Int',
      property_name => 'JMSPriority',
      sort_order    => 'Descending',
    }

In this example you are managing a JMS sort destination key in the default domain. When you want to
manage a JMS sort destination key in a specific domain, you can use:

    wls_jms_sort_destination_key { 'my_domain/jmsClusterModule:JMSRedelivered':
      ensure        => 'present',
      key_type      => 'Boolean',
      property_name => 'JMSRedelivered',
      sort_order    => 'Ascending',
    }

## Attributes



Attribute Name                                               | Short Description                                                                     |
------------------------------------------------------------ | ------------------------------------------------------------------------------------- |
[domain](#wls_jms_sort_destination_key_domain)               | With this parameter, you identify the domain, where your objects is in.               |
[ensure](#wls_jms_sort_destination_key_ensure)               | The basic property that the resource should be in.                                    |
[jmsmodule](#wls_jms_sort_destination_key_jmsmodule)         | The JMS module name.                                                                  |
[key_name](#wls_jms_sort_destination_key_key_name)           | The key name
                                                                         |
[key_type](#wls_jms_sort_destination_key_key_type)           | The key type
                                                                         |
[name](#wls_jms_sort_destination_key_name)                   | The name.                                                                             |
[notes](#wls_jms_sort_destination_key_notes)                 | Optional information that you can include to describe this named JMS descriptor bean. |
[property_name](#wls_jms_sort_destination_key_property_name) | The property
                                                                         |
[provider](#wls_jms_sort_destination_key_provider)           | resource.                                                                             |
[sort_order](#wls_jms_sort_destination_key_sort_order)       | The sort order
                                                                       |
[timeout](#wls_jms_sort_destination_key_timeout)             | Timeout for applying a resource.                                                      |




### domain<a name='wls_jms_sort_destination_key_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jms_sort_destination_key](#attributes)


### ensure<a name='wls_jms_sort_destination_key_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jms_sort_destination_key](#attributes)


### jmsmodule<a name='wls_jms_sort_destination_key_jmsmodule'>

The JMS module name.


[Back to overview of wls_jms_sort_destination_key](#attributes)


### key_name<a name='wls_jms_sort_destination_key_key_name'>

The key name


[Back to overview of wls_jms_sort_destination_key](#attributes)


### key_type<a name='wls_jms_sort_destination_key_key_type'>

The key type

Valid values are `absent`, `Boolean`, `Byte`, `Short`, `Int`, `Long`, `Float`, `Double`, `String`. 
[Back to overview of wls_jms_sort_destination_key](#attributes)


### name<a name='wls_jms_sort_destination_key_name'>

The name.


[Back to overview of wls_jms_sort_destination_key](#attributes)


### notes<a name='wls_jms_sort_destination_key_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_sort_destination_key {a_wls_jms_sort_destination_key :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_sort_destination_key:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_sort_destination_key](#attributes)


### property_name<a name='wls_jms_sort_destination_key_property_name'>

The property

Valid values are `absent`, `JMSMessageID`, `JMSTimestamp`, `JMSCorrelationID`, `JMSPriority`, `JMSExpiration`, `JMSType`, `JMSRedelivered`, `JMSDeliveryTime`, `JMS_BEA_Size`, `JMS_BEA_UnitOfOrder`. 
[Back to overview of wls_jms_sort_destination_key](#attributes)


### provider<a name='wls_jms_sort_destination_key_provider'>

The specific backend to use for this `wls_jms_sort_destination_key`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage the jms sort destination key object in  WebLogic domain via regular WLST


[Back to overview of wls_jms_sort_destination_key](#attributes)


### sort_order<a name='wls_jms_sort_destination_key_sort_order'>

The sort order

Valid values are `absent`, `Ascending`, `Descending`. 
[Back to overview of wls_jms_sort_destination_key](#attributes)


### timeout<a name='wls_jms_sort_destination_key_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_jms_sort_destination_key](#attributes)

