---
title: wls_jms_template
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a template in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_jms_template { 'jmsClusterModule:Template-0':
      ensure          => 'present',
      redeliverydelay => '-1',
      redeliverylimit => '-1',
    }

In this example you are managing a JMS template in the default domain. When you want to
manage a JMS template in a specific domain, you can use:

    wls_jms_template { 'my_domain/jmsClusterModule:Template-0':
      ensure          => 'present',
      redeliverydelay => '-1',
      redeliverylimit => '-1',
    }

## Attributes



Attribute Name                                                                             | Short Description                                                                                                                                                                                                                          |
------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[attach_sender](#wls_jms_template_attach_sender)                                           | Specifies whether messages landing on destinations that use this template should attach the credential of the sending user.                                                                                                                |
[consumption_paused_at_startup](#wls_jms_template_consumption_paused_at_startup)           | Specifies whether message consumption is paused on destinations that use this template at server startup.                                                                                                                                  |
[default_unit_of_order](#wls_jms_template_default_unit_of_order)                           | Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name.                                                                                                     |
[delivery_error_destination](#wls_jms_template_delivery_error_destination)                 | The name of the target error destination for messages that have expired or reached their redelivery limit.                                                                                                                                 |
[delivery_expiration_logging_policy](#wls_jms_template_delivery_expiration_logging_policy) | The policy that defines what information about the message is logged when the Expiration Policy is set to Log.                                                                                                                             |
[delivery_expiration_policy](#wls_jms_template_delivery_expiration_policy)                 | The message Expiration Policy to use when an expired message is encountered on a destination.                                                                                                                                              |
[delivery_redelivery_limit](#wls_jms_template_delivery_redelivery_limit)                   | The number of redelivery tries a message can have before it is moved to the error destination.                                                                                                                                             |
[delivery_template_bean](#wls_jms_template_delivery_template_bean)                         | This is used to find the template bean for this destination
                                                                                                                                                                               |
[destination_keys](#wls_jms_template_destination_keys)                                     | The list of potential destination keys for sorting messages that arrive on destinations that use this JMS template.                                                                                                                        |
[domain](#wls_jms_template_domain)                                                         | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                                    |
[ensure](#wls_jms_template_ensure)                                                         | The basic property that the resource should be in.                                                                                                                                                                                         |
[incomplete_work_expiration_time](#wls_jms_template_incomplete_work_expiration_time)       | Specifies the maximum amount of time, in milliseconds, before undelivered messages in an incomplete UOW are expired.                                                                                                                       |
[insertion_paused_at_startup](#wls_jms_template_insertion_paused_at_startup)               | Specifies whether new message insertion is paused on destinations that use this template at server startup.                                                                                                                                |
[jmsmodule](#wls_jms_template_jmsmodule)                                                   | The JMS module name.                                                                                                                                                                                                                       |
[log_message_logging_enabled](#wls_jms_template_log_message_logging_enabled)               | Specifies whether the module logs information about the message life cycle.                                                                                                                                                                |
[log_message_logging_format](#wls_jms_template_log_message_logging_format)                 | Defines which information about the message is logged.                                                                                                                                                                                     |
[log_template_bean](#wls_jms_template_log_template_bean)                                   | Finds the template bean for this destination.                                                                                                                                                                                              |
[maximum_message_size](#wls_jms_template_maximum_message_size)                             | The maximum size of a message that will be accepted from producers on this destination.                                                                                                                                                    |
[messaging_performance_preference](#wls_jms_template_messaging_performance_preference)     | Controls how long destinations that use this template are willing to wait to create full batches of available messages (if at all) for delivery to consumers.                                                                              |
[name](#wls_jms_template_name)                                                             | The name.                                                                                                                                                                                                                                  |
[notes](#wls_jms_template_notes)                                                           | Optional information that you can include to describe this named JMS descriptor bean.                                                                                                                                                      |
[override_delivery_mode](#wls_jms_template_override_delivery_mode)                         | The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.                                                                                                |
[override_priority](#wls_jms_template_override_priority)                                   | The priority assigned to all messages that arrive at this destination, regardless of the Priority specified by the message producer.                                                                                                       |
[override_redelivery_delay](#wls_jms_template_override_redelivery_delay)                   | The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory.                                                               |
[override_template_bean](#wls_jms_template_override_template_bean)                         | This is used to find the template bean for this destination
                                                                                                                                                                               |
[override_time_to_deliver](#wls_jms_template_override_time_to_deliver)                     | The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. |
[override_time_to_live](#wls_jms_template_override_time_to_live)                           | The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer.                                                                                           |
[production_paused_at_startup](#wls_jms_template_production_paused_at_startup)             | Specifies whether new message production on destinations that use this template is paused on at server startup.                                                                                                                            |
[provider](#wls_jms_template_provider)                                                     | resource.                                                                                                                                                                                                                                  |
[quota](#wls_jms_template_quota)                                                           | A Quota controls the allotment of system resources available to destinations.                                                                                                                                                              |
[redeliverydelay](#wls_jms_template_redeliverydelay)                                       | redelivery delay
                                                                                                                                                                                                                          |
[redeliverylimit](#wls_jms_template_redeliverylimit)                                       | redelivery limit
                                                                                                                                                                                                                          |
[saf_export_policy](#wls_jms_template_saf_export_policy)                                   | Specifies whether a user can send messages to destinations that use this template using Store-and-Forward.                                                                                                                                 |
[template_name](#wls_jms_template_template_name)                                           | The JMS Template name
                                                                                                                                                                                                                     |
[thresholds_bytes_high](#wls_jms_template_thresholds_bytes_high)                           | The upper threshold (total number of bytes in this destination) that triggers logging or flow control events.                                                                                                                              |
[thresholds_bytes_low](#wls_jms_template_thresholds_bytes_low)                             | The lower threshold (total number of bytes in this destination) that triggers logging or flow control events.                                                                                                                              |
[thresholds_messages_high](#wls_jms_template_thresholds_messages_high)                     | The upper threshold (total number of messages in this destination) that triggers logging or flow control events.                                                                                                                           |
[thresholds_messages_low](#wls_jms_template_thresholds_messages_low)                       | The lower threshold (total number of messages in this destination) that triggers logging or flow control events.                                                                                                                           |
[thresholds_template_bean](#wls_jms_template_thresholds_template_bean)                     | Finds the template bean for this destination.                                                                                                                                                                                              |
[timeout](#wls_jms_template_timeout)                                                       | Timeout for applying a resource.                                                                                                                                                                                                           |
[unit_of_work_handling_policy](#wls_jms_template_unit_of_work_handling_policy)             | Specifies whether the Unit-of-Work (UOW) feature is enabled for destinations that use this template.                                                                                                                                       |




### attach_sender<a name='wls_jms_template_attach_sender'>

Specifies whether messages landing on destinations that use this template should attach the credential of the sending user.  <ul> <li>Supports The JMSXUserID property is set with the security principal of the sending user if requested. The sender can request its identity to be attached to its messages by using a ConnectionFactory with <code>AttachJMSXUserID="true"</code>.</li>  <li>Never The JMSXUserID property is never be set with the security principal of the sending user.</li>  <li>Always The JMSXUserID property is always set with the security principal of the sending user.</li> </ul>  This property is dynamically configurable. A dynamic change will only affect messages received after the update has been made.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       attach_sender => 'supports'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:attach_sender']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### consumption_paused_at_startup<a name='wls_jms_template_consumption_paused_at_startup'>

Specifies whether message consumption is paused on destinations that use this template at server startup.  <ul> <li>false Paused message consumption at server startup is disabled on this template.</li>  <li>true Paused message consumption at server startup is enabled on this template.</li> </ul>

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       consumption_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:consumption_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_template](#attributes)


### default_unit_of_order<a name='wls_jms_template_default_unit_of_order'>

Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name. Any message arriving at this destination that does not already belong to a unit-of-order is assigned this default name.  This field is recommended for advanced use. Generally, it is  recommended to set a message unit-of-order using application calls or connection factory configuration. When relying on a destination default unit order to enforce ordering with adistributed destination, the application must be aware that unit-of-order routing doesn't apply. Instead the application must specifically ensure that any particular set of messages that must be processed in order are all sent to the same specific member destination even in the event of process failures or service migration.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       default_unit_of_order => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:default_unit_of_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_template](#attributes)


### delivery_error_destination<a name='wls_jms_template_delivery_error_destination'>

The name of the target error destination for messages that have expired or reached their redelivery limit. If no error destination is configured, then such messages are simply dropped. If a message has expired or reached its redelivery limit, and the Expiration Policy is set to Redirect, then the message is moved to the specified Error Destination.  For standalone destinations, an error destination must be another standalone destination that is targeted to the same JMS server as the destinations for which the error destination is defined. For uniform distributed destinations (UDDs), the error destination must be another UDD that shares the same subdeployment (i.e., targets) as the current UDD.  This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       delivery_error_destination => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:delivery_error_destination']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### delivery_expiration_logging_policy<a name='wls_jms_template_delivery_expiration_logging_policy'>

The policy that defines what information about the message is logged when the Expiration Policy is set to Log. The valid logging policy values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>  When specifying multiple values, enter them as a comma-separated list. The <code>%header%</code> and <code>%properties% </code> values are not case sensitive. For example, you could use <code>"%header%,%properties%"</code> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <code>"%header, name, address, city, state, zip"</code>.  Note: The <code>JMSMessageID</code> field is always logged and cannot be turned off. Therefore, if the Expiration Logging Policy is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <code>JMSMessageID</code> of the message.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       delivery_expiration_logging_policy => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:delivery_expiration_logging_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### delivery_expiration_policy<a name='wls_jms_template_delivery_expiration_policy'>

The message Expiration Policy to use when an expired message is encountered on a destination. The valid expiration policies are:  None - Same as the Discard policy; expired messages are simply removed from the destination.  Discard - Removes expired messages from the messaging system. The removal is not logged and the message is not redirected to another location. If no value is defined for a given destination (i.e., None), then expired messages are discarded.  Log - Removes expired messages from the system and writes an entry to the server log file indicating that the messages have been removed from the system. The actual information that is logged is defined by the Expiration Logging Policy.  Redirect - Moves expired messages from their current location to the Error Destination defined for the destination. The message retains its body, and all of its properties. The message also retains all of its header fields, but with the following exceptions: <ul> <li> The destination for the message becomes the error destination. <li> All property overrides associated with the error destination are applied to the redirected message. <li> If there is no Time-To-Live Override value for the error destination, then the message receives a new Expiration Time of zero (indicating that it will not expire again). </ul>  It is illegal to use the Redirect policy when there is no valid error destination defined for the destination. Similarly, it is illegal to remove the error destination for a destination that is using the Redirect policy.  Note: The Maximum Message quota is only enforced for sending new messages. It is ignored when moving messages because of the Redirect policy.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       delivery_expiration_policy => 'Discard'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:delivery_expiration_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### delivery_redelivery_limit<a name='wls_jms_template_delivery_redelivery_limit'>

The number of redelivery tries a message can have before it is moved to the error destination. This setting overrides any redelivery limit set by the message sender. If the redelivery limit is configured, but no error destination is configured, then persistent and non-persistent messages are simply dropped (deleted) when they reach their redelivery limit.  The default value (-1) specifies that the destination will not override the message sender's redelivery limit setting.   Note: WebLogic Server supports the JMSXDeliveryCount message property, which specifies the number of message delivery attempts, where the first attempt is 1, the next attempt is 2, and so on. WebLogic Server makes a best effort to persist the delivery count, so that the delivery count does not reset back to 1 after a server reboot.  This attribute is dynamically configurable, but only incoming messages are impacted; previously sent messages continue to use their original redelivery limit.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       delivery_redelivery_limit => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:delivery_redelivery_limit']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### delivery_template_bean<a name='wls_jms_template_delivery_template_bean'>

This is used to find the template bean for this destination

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       delivery_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:delivery_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### destination_keys<a name='wls_jms_template_destination_keys'>

The list of potential destination keys for sorting messages that arrive on destinations that use this JMS template.  The keys are ordered from most significant to least significant. If more than one key is specified, a key based on the JMSMessageID can only be the last key in the list.  Note: If JMSMessageID is not defined in the key, it is implicitly assumed to be the last key and is set as "Ascending" (FIFO) for the sort order.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       destination_keys => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:destination_keys']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### domain<a name='wls_jms_template_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jms_template](#attributes)


### ensure<a name='wls_jms_template_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jms_template](#attributes)


### incomplete_work_expiration_time<a name='wls_jms_template_incomplete_work_expiration_time'>

Specifies the maximum amount of time, in milliseconds, before undelivered messages in an incomplete UOW are expired. Such messages will then follow the template's expiration policy defined for undeliverable messages.  Note: A template's error destination for UOW messages cannot be configured to use the Single Message Delivery value.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       incomplete_work_expiration_time => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:incomplete_work_expiration_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### insertion_paused_at_startup<a name='wls_jms_template_insertion_paused_at_startup'>

Specifies whether new message insertion is paused on destinations that use this template at server startup.  <ul> <li>false Paused message insertion at server startup is disabled on this template.</li>  <li>true Paused message insertion at server startup is enabled on this template.</li> </ul>

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       insertion_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:insertion_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_template](#attributes)


### jmsmodule<a name='wls_jms_template_jmsmodule'>

The JMS module name.


[Back to overview of wls_jms_template](#attributes)


### log_message_logging_enabled<a name='wls_jms_template_log_message_logging_enabled'>

Specifies whether the module logs information about the message life cycle.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       log_message_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:log_message_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_template](#attributes)


### log_message_logging_format<a name='wls_jms_template_log_message_logging_format'>

Defines which information about the message is logged. Valid values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>   When specifying multiple values, enter them as a comma-separated list. The <tt>%header%</tt> and <tt>%properies% </tt> values are not case sensitive. For example, you could use <tt>"%header%,%properties%"</tt> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <tt>"%header, name, address, city, state, zip"</tt> .   Note: The <tt>JMSMessageID</tt> field is always logged and cannot be turned off. Therefore, if the Message Logging Format is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <tt>JMSMessageID</tt> of the message. Gets the "message-logging-format" element

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       log_message_logging_format => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:log_message_logging_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### log_template_bean<a name='wls_jms_template_log_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       log_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:log_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### maximum_message_size<a name='wls_jms_template_maximum_message_size'>

The maximum size of a message that will be accepted from producers on this destination. The message size includes the message body, any user-defined properties, and the user-defined JMS header fields: <tt>JMSCorrelationID</tt> and <tt>JMSType</tt>.  Producers sending messages that exceed the configured maximum message size for the destination receive a <tt>ResourceAllocationException</tt> .  The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination.  Maximum Message Size is dynamically configurable, but only incoming messages are affected; stored messages are not affected.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       maximum_message_size => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:maximum_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### messaging_performance_preference<a name='wls_jms_template_messaging_performance_preference'>

Controls how long destinations that use this template are willing to wait to create full batches of available messages (if at all) for delivery to consumers. At the minimum value, batching is disabled; at the default value, less-than-full batches will not wait and are delivered immediately with currently available messages; tuning higher than the default value controls the maximum wait time for additional messages before less-than-full batches are delivered to consumers.  The maximum message count of a full batch is controlled by the JMS connection factory's MessagesMaximum setting.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       messaging_performance_preference => '25'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:messaging_performance_preference']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### name<a name='wls_jms_template_name'>

The name.


[Back to overview of wls_jms_template](#attributes)


### notes<a name='wls_jms_template_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### override_delivery_mode<a name='wls_jms_template_override_delivery_mode'>

The delivery mode assigned to all messages that arrive at the destination regardless of the DeliveryMode specified by the message producer.  A value of <tt>No-Delivery</tt> specifies that the DeliveryMode will not be overridden.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       override_delivery_mode => 'No-Delivery'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:override_delivery_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### override_priority<a name='wls_jms_template_override_priority'>

The priority assigned to all messages that arrive at this destination, regardless of the Priority specified by the message producer. The default value (-1) specifies that the destination will not override the Priority set by the message producer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       override_priority => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:override_priority']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### override_redelivery_delay<a name='wls_jms_template_override_redelivery_delay'>

The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory. Redelivered queue messages are put back into their originating destination; redelivered topic messages are put back into their originating subscription. The default value (-1) specifies that the destination will not override the RedeliveryDelay setting specified by the consumer and/or connection factory.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.  Note: Changing the RedeliveryDelay override only affects future rollbacks and recovers, it does not affect rollbacks and recovers that have already occurred.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       override_redelivery_delay => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:override_redelivery_delay']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### override_template_bean<a name='wls_jms_template_override_template_bean'>

This is used to find the template bean for this destination

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       override_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:override_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### override_time_to_deliver<a name='wls_jms_template_override_time_to_deliver'>

The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. The default value (<tt>-1</tt>) specifies that the destination will not override the TimeToDeliver setting specified by the producer and/or connection factory. The TimeToDeliver override can be specified either as a long or as a schedule.  Note: Changing the TimeToDeliver override only affects future message delivery, it does not affect message delivery of already produced messages.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       override_time_to_deliver => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:override_time_to_deliver']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### override_time_to_live<a name='wls_jms_template_override_time_to_live'>

The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer. The default value (<tt>-1</tt>) specifies that this setting will not override the TimeToLive setting specified by the message producer.  Range of Values: Between 0 and a positive 64-bit integer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       override_time_to_live => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:override_time_to_live']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### production_paused_at_startup<a name='wls_jms_template_production_paused_at_startup'>

Specifies whether new message production on destinations that use this template is paused on at server startup.  <ul> <li>false Paused message production at server startup is disabled on this template.</li>  <li>true Paused message production at server startup is enabled on this template.</li> </ul>

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       production_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:production_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_jms_template](#attributes)


### provider<a name='wls_jms_template_provider'>

The specific backend to use for this `wls_jms_template`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage JMS connection templates


[Back to overview of wls_jms_template](#attributes)


### quota<a name='wls_jms_template_quota'>

A Quota controls the allotment of system resources available to destinations. For example the number of bytes a destination is allowed to store can be configured with a QuotaBean.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       quota => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:quota']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### redeliverydelay<a name='wls_jms_template_redeliverydelay'>

redelivery delay


[Back to overview of wls_jms_template](#attributes)


### redeliverylimit<a name='wls_jms_template_redeliverylimit'>

redelivery limit


[Back to overview of wls_jms_template](#attributes)


### saf_export_policy<a name='wls_jms_template_saf_export_policy'>

Specifies whether a user can send messages to destinations that use this template using Store-and-Forward.  <ul> <li>All All users can send messages to destinations using Store-and-Forward.</li>  <li>None Remote users cannot send messages to destinations using Store-and-Forward. </li> </ul>  This property is dynamically configurable. A dynamic change will only affect messages sent after the update has been made.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       saf_export_policy => 'All'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:saf_export_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### template_name<a name='wls_jms_template_template_name'>

The JMS Template name


[Back to overview of wls_jms_template](#attributes)


### thresholds_bytes_high<a name='wls_jms_template_thresholds_bytes_high'>

The upper threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes exceeds this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a high threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;BytesThresholdLow  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       thresholds_bytes_high => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:thresholds_bytes_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### thresholds_bytes_low<a name='wls_jms_template_thresholds_bytes_low'>

The lower threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; BytesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected. <!--Gets the "bytes-low" element-->

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       thresholds_bytes_low => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:thresholds_bytes_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### thresholds_messages_high<a name='wls_jms_template_thresholds_messages_high'>

The upper threshold (total number of messages in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of messages exceeds this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a high threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= MessagesMaximum; &gt;MessagesThresholdLow  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       thresholds_messages_high => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:thresholds_messages_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### thresholds_messages_low<a name='wls_jms_template_thresholds_messages_low'>

The lower threshold (total number of messages in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of messages falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; MessagesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       thresholds_messages_low => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:thresholds_messages_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### thresholds_template_bean<a name='wls_jms_template_thresholds_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       thresholds_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:thresholds_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)


### timeout<a name='wls_jms_template_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_jms_template](#attributes)


### unit_of_work_handling_policy<a name='wls_jms_template_unit_of_work_handling_policy'>

Specifies whether the Unit-of-Work (UOW) feature is enabled for destinations that use this template. A UOW is a set of messages that are processed as a single unit. <ul> <li> Pass-Through By default, destinations that use this template do not treat messages as part of a UOW.</li> <li> Single Message Delivery This value should only be selected if UOW consumers are receiving messages on destinations that use this template. When selected, UOW messages are formed into a list and are consumed as an <code>ObjectMessage</code> containing the list.</li> </ul>

An example on how to use this:

    wls_jms_template {a_wls_jms_template :
       ...
       unit_of_work_handling_policy => 'PassThrough'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_template:unit_of_work_handling_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_template](#attributes)

