---
title: wls_jndi_security_policy
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage jndi security authorization policies in an WebLogic Security Realm.

Here is an example on how you should use this:

    wls_jndi_security_policy { 'domain/managed_server:javax.jms.TopicConnectionFactory:modify':
      ensure           => 'present',
      policyexpression => 'Role(Admin) | Role(Deployer)',
    }

This puppet snippit set's the security policy for `modify` operation of the the JNDI object
`javax.jms.TopicConnectionFactory` on server `managed_server` in the domain `domain`
to: `Role(Admin) | Role(Deployer)`.

## Attributes



Attribute Name                                                           | Short Description                                                       |
------------------------------------------------------------------------ | ----------------------------------------------------------------------- |
[action](#wls_jndi_security_policy_action)                               | The kind of action you want to manage with this security policy.        |
[authorizationprovider](#wls_jndi_security_policy_authorizationprovider) | The security authorization providers of the domain
                     |
[domain](#wls_jndi_security_policy_domain)                               | With this parameter, you identify the domain, where your objects is in. |
[ensure](#wls_jndi_security_policy_ensure)                               | The basic property that the resource should be in.                      |
[jndi_name](#wls_jndi_security_policy_jndi_name)                         | The JNDI name of the resource
                                          |
[name](#wls_jndi_security_policy_name)                                   | The name.                                                               |
[policyexpression](#wls_jndi_security_policy_policyexpression)           | A string representation of an security authorization policy
            |
[provider](#wls_jndi_security_policy_provider)                           | resource.                                                               |
[server_name](#wls_jndi_security_policy_server_name)                     | The server name where the JNDI tree is hosted
                          |
[timeout](#wls_jndi_security_policy_timeout)                             | Timeout for applying a resource.                                        |




### action<a name='wls_jndi_security_policy_action'>

The kind of action you want to manage with this security policy.

This is the last part of the title of the resource. Here is an example:

    wls_jndi_security_policy{'domain/server:javax.erb.com:lookup'
      ...
    }

In this example `lookup` is the action. So this is a policy that says something
about the rights you need to do do a jndi lookup on `javax.erb.com`.

Valid values are `all`, `lookup`, `modify`, `list`. 
[Back to overview of wls_jndi_security_policy](#attributes)


### authorizationprovider<a name='wls_jndi_security_policy_authorizationprovider'>

The security authorization providers of the domain


[Back to overview of wls_jndi_security_policy](#attributes)


### domain<a name='wls_jndi_security_policy_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jndi_security_policy](#attributes)


### ensure<a name='wls_jndi_security_policy_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jndi_security_policy](#attributes)


### jndi_name<a name='wls_jndi_security_policy_jndi_name'>

The JNDI name of the resource


[Back to overview of wls_jndi_security_policy](#attributes)


### name<a name='wls_jndi_security_policy_name'>

The name.


[Back to overview of wls_jndi_security_policy](#attributes)


### policyexpression<a name='wls_jndi_security_policy_policyexpression'>

A string representation of an security authorization policy


[Back to overview of wls_jndi_security_policy](#attributes)


### provider<a name='wls_jndi_security_policy_provider'>

The specific backend to use for this `wls_jndi_security_policy`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: 


[Back to overview of wls_jndi_security_policy](#attributes)


### server_name<a name='wls_jndi_security_policy_server_name'>

The server name where the JNDI tree is hosted


[Back to overview of wls_jndi_security_policy](#attributes)


### timeout<a name='wls_jndi_security_policy_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_jndi_security_policy](#attributes)

