---
title: wls_mail_session
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a mail_session in an WebLogic domain.

Here is an example on how you should use this:

    wls_mail_session { 'myMailSession':
      ensure         => 'present',
      jndiname       => 'myMailSession',
      target         => ['ManagedServer1', 'WebCluster'],
      targettype     => ['Server', 'Cluster'],
      mailproperty   => ['mail.host=smtp.hostname.com', 'mail.user=smtpadmin'],
    }

In this example you are managing a mail session in the default domain. When you want to
manage a mail session in a specific domain, you can use:

    wls_mail_session { 'my_domain/myMailSession':
      ensure         => 'present',
      jndiname       => 'myMailSession',
      target         => ['ManagedServer1', 'WebCluster'],
      targettype     => ['Server', 'Cluster'],
      mailproperty   => ['mail.host=smtp.hostname.com', 'mail.user=smtpadmin'],
    }

## Attributes



Attribute Name                                               | Short Description                                                                                                                                                                                                       |
------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[deployment_order](#wls_mail_session_deployment_order)       | A priority that the server uses to determine when it deploys an item.                                                                                                                                                   |
[domain](#wls_mail_session_domain)                           | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                 |
[ensure](#wls_mail_session_ensure)                           | The basic property that the resource should be in.                                                                                                                                                                      |
[extra_properties](#wls_mail_session_extra_properties)       | The configuration options and user authentication data that this mail session uses to interact with a mail server.                                                                                                      |
[javamail_properties](#wls_mail_session_javamail_properties) | The configuration options and user authentication data that this mail session uses to interact with a mail server.                                                                                                      |
[jndi_name](#wls_mail_session_jndi_name)                     | The JNDI Name associated with this resource.                                                                                                                                                                            |
[jndiname](#wls_mail_session_jndiname)                       | The jndi name.                                                                                                                                                                                                          |
[mailproperty](#wls_mail_session_mailproperty)               | The mail properties
                                                                                                                                                                                                    |
[mailsession_name](#wls_mail_session_mailsession_name)       | The mail session name
                                                                                                                                                                                                  |
[name](#wls_mail_session_name)                               | The name.                                                                                                                                                                                                               |
[notes](#wls_mail_session_notes)                             | Optional information that you can include to describe this configuration.                                                                                                                                               |
[provider](#wls_mail_session_provider)                       | resource.                                                                                                                                                                                                               |
[session_password](#wls_mail_session_session_password)       | The decrypted JavaMail Session password attribute, for use only temporarily in-memory; the value returned by this attribute should not be held in memory long term.                                                     |
[session_username](#wls_mail_session_session_username)       |  Returns the username to be used to create an authenticated JavaMail Session, using a JavaMail <code>Authenticator</code> instance; if this is not set, it will be assumed that the Session is not to be authenticated. |
[tags](#wls_mail_session_tags)                               | Return all tags on this Configuration MBean
                                                                                                                                                                            |
[target](#wls_mail_session_target)                           | An array of target names.                                                                                                                                                                                               |
[targettype](#wls_mail_session_targettype)                   | An array of target types.                                                                                                                                                                                               |
[timeout](#wls_mail_session_timeout)                         | Timeout for applying a resource.                                                                                                                                                                                        |




### deployment_order<a name='wls_mail_session_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       deployment_order => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### domain<a name='wls_mail_session_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_mail_session](#attributes)


### ensure<a name='wls_mail_session_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_mail_session](#attributes)


### extra_properties<a name='wls_mail_session_extra_properties'>

The configuration options and user authentication data that this mail session uses to interact with a mail server. Each property that you specify overrides the default property value as defined by the JavaMail API Design Specification. Include only the properties defined by the JavaMail API Design Specification. If you do not specify any properties, this mail session will use the JavaMail default property values. Express each property as a <code>name=value</code> pair. Separate multiple properties with a semicolon (<code>;</code>).

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       properties => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:properties']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### javamail_properties<a name='wls_mail_session_javamail_properties'>

The configuration options and user authentication data that this mail session uses to interact with a mail server. Each property that you specify overrides the default property value as defined by the JavaMail API Design Specification. Include only the properties defined by the JavaMail API Design Specification. If you do not specify any properties, this mail session will use the JavaMail default property values. Express each property as a <code>name=value</code> pair. Separate multiple properties with a semicolon (<code>;</code>).

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       java_mailproperties => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:properties']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### jndi_name<a name='wls_mail_session_jndi_name'>

The JNDI Name associated with this resource.

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### jndiname<a name='wls_mail_session_jndiname'>

The jndi name.


[Back to overview of wls_mail_session](#attributes)


### mailproperty<a name='wls_mail_session_mailproperty'>

The mail properties


[Back to overview of wls_mail_session](#attributes)


### mailsession_name<a name='wls_mail_session_mailsession_name'>

The mail session name


[Back to overview of wls_mail_session](#attributes)


### name<a name='wls_mail_session_name'>

The name.


[Back to overview of wls_mail_session](#attributes)


### notes<a name='wls_mail_session_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### provider<a name='wls_mail_session_provider'>

The specific backend to use for this `wls_mail_session`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a mail session in an WebLogic domain via regular WLST


[Back to overview of wls_mail_session](#attributes)


### session_password<a name='wls_mail_session_session_password'>

The decrypted JavaMail Session password attribute, for use only temporarily in-memory; the value returned by this attribute should not be held in memory long term.  The value is stored in an encrypted form in the descriptor file and when displayed in an administration console.

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       session_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:session_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### session_username<a name='wls_mail_session_session_username'>

 Returns the username to be used to create an authenticated JavaMail Session, using a JavaMail <code>Authenticator</code> instance; if this is not set, it will be assumed that the Session is not to be authenticated.

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       session_username => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:session_username']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### tags<a name='wls_mail_session_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_mail_session {a_wls_mail_session :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_mail_session:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_mail_session](#attributes)


### target<a name='wls_mail_session_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_mail_session](#attributes)


### targettype<a name='wls_mail_session_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_mail_session](#attributes)


### timeout<a name='wls_mail_session_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_mail_session](#attributes)

