---
title: wls_saf_remote_context
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a SAF remote contexts in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_saf_remote_context { 'jmsClusterModule:RemoteSAFContext-0':
      ensure        => 'present',
      connect_url   => 't3://10.10.10.10:7001',
      weblogic_user => 'weblogic',
      weblogic_password => 'weblogic1',
    }

In this example you are managing a SAF remote contexts in the default domain. When you want to
manage a SAF remote contexts in a specific domain, you can use:

    wls_saf_remote_context { 'my_domain/jmsClusterModule:RemoteSAFContext-1':
      ensure      => 'present',
      connect_url => 't3://10.10.10.10:7001',
    }

## Attributes



Attribute Name                                                                               | Short Description                                                                                                                                                                                  |
-------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[compression_threshold](#wls_saf_remote_context_compression_threshold)                       | The number of bytes for a serialized message body so that any message that exceeds this limit triggers message compression when the message is about to be sent across a SAF agent's JVM boundary. |
[connect_url](#wls_saf_remote_context_connect_url)                                           | The url to connect to
                                                                                                                                                                             |
[domain](#wls_saf_remote_context_domain)                                                     | With this parameter, you identify the domain, where your objects is in.                                                                                                                            |
[ensure](#wls_saf_remote_context_ensure)                                                     | The basic property that the resource should be in.                                                                                                                                                 |
[jmsmodule](#wls_saf_remote_context_jmsmodule)                                               | The JMS module name.                                                                                                                                                                               |
[login_password](#wls_saf_remote_context_login_password)                                     | The password for the username used to log into the remote URL.                                                                                                                                     |
[login_url](#wls_saf_remote_context_login_url)                                               | Specifies the URL to connect to when using this SAF Login Context.                                                                                                                                 |
[login_username](#wls_saf_remote_context_login_username)                                     | The name used to log into the remote URL.                                                                                                                                                          |
[name](#wls_saf_remote_context_name)                                                         | The name.                                                                                                                                                                                          |
[notes](#wls_saf_remote_context_notes)                                                       | Optional information that you can include to describe this named JMS descriptor bean.                                                                                                              |
[provider](#wls_saf_remote_context_provider)                                                 | resource.                                                                                                                                                                                          |
[remote_context_name](#wls_saf_remote_context_remote_context_name)                           | SAF remote context name
                                                                                                                                                                           |
[reply_to_saf_remote_context_name](#wls_saf_remote_context_reply_to_saf_remote_context_name) | Specifies the SAF Remote Context Name used by the replyTo destination in the remote cluster or server.                                                                                             |
[timeout](#wls_saf_remote_context_timeout)                                                   | Timeout for applying a resource.                                                                                                                                                                   |
[weblogic_password](#wls_saf_remote_context_weblogic_password)                               | Remote WebLogic password
                                                                                                                                                                          |
[weblogic_user](#wls_saf_remote_context_weblogic_user)                                       | the weblogic user account
                                                                                                                                                                         |




### compression_threshold<a name='wls_saf_remote_context_compression_threshold'>

The number of bytes for a serialized message body so that any message that exceeds this limit triggers message compression when the message is about to be sent across a SAF agent's JVM boundary.  The compression will occur on the sending-side SAF agent's JVM if the message body size exceeds the threshold limit.

An example on how to use this:

    wls_saf_remote_context {a_wls_saf_remote_context :
       ...
       compression_threshold => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_remote_context:compression_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_remote_context](#attributes)


### connect_url<a name='wls_saf_remote_context_connect_url'>

The url to connect to


[Back to overview of wls_saf_remote_context](#attributes)


### domain<a name='wls_saf_remote_context_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_saf_remote_context](#attributes)


### ensure<a name='wls_saf_remote_context_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_saf_remote_context](#attributes)


### jmsmodule<a name='wls_saf_remote_context_jmsmodule'>

The JMS module name.


[Back to overview of wls_saf_remote_context](#attributes)


### login_password<a name='wls_saf_remote_context_login_password'>

The password for the username used to log into the remote URL.  When Password is specified for a SAFLoginContext, then SAFPrincipalName is not specified.

An example on how to use this:

    wls_saf_remote_context {a_wls_saf_remote_context :
       ...
       login_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_remote_context:login_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_remote_context](#attributes)


### login_url<a name='wls_saf_remote_context_login_url'>

Specifies the URL to connect to when using this SAF Login Context.  SAFImportedDestinations are associated with a SAFRemoteContext that has a SAFLoginContext. This SAFLoginContext defines the URL to connect to.

An example on how to use this:

    wls_saf_remote_context {a_wls_saf_remote_context :
       ...
       login_url => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_remote_context:login_url']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_remote_context](#attributes)


### login_username<a name='wls_saf_remote_context_login_username'>

The name used to log into the remote URL.  When Username is specified for a SAFLoginContext, then SAFPrincipalName is not specified.

An example on how to use this:

    wls_saf_remote_context {a_wls_saf_remote_context :
       ...
       login_username => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_remote_context:login_username']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_remote_context](#attributes)


### name<a name='wls_saf_remote_context_name'>

The name.


[Back to overview of wls_saf_remote_context](#attributes)


### notes<a name='wls_saf_remote_context_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_saf_remote_context {a_wls_saf_remote_context :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_remote_context:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_remote_context](#attributes)


### provider<a name='wls_saf_remote_context_provider'>

The specific backend to use for this `wls_saf_remote_context`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: saf remote context in a JMS module of an WebLogic domain via regular WLST


[Back to overview of wls_saf_remote_context](#attributes)


### remote_context_name<a name='wls_saf_remote_context_remote_context_name'>

SAF remote context name


[Back to overview of wls_saf_remote_context](#attributes)


### reply_to_saf_remote_context_name<a name='wls_saf_remote_context_reply_to_saf_remote_context_name'>

Specifies the SAF Remote Context Name used by the replyTo destination in the remote cluster or server.

An example on how to use this:

    wls_saf_remote_context {a_wls_saf_remote_context :
       ...
       reply_to_saf_remote_context_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_remote_context:reply_to_saf_remote_context_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_remote_context](#attributes)


### timeout<a name='wls_saf_remote_context_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_saf_remote_context](#attributes)


### weblogic_password<a name='wls_saf_remote_context_weblogic_password'>

Remote WebLogic password


[Back to overview of wls_saf_remote_context](#attributes)


### weblogic_user<a name='wls_saf_remote_context_weblogic_user'>

the weblogic user account


[Back to overview of wls_saf_remote_context](#attributes)

