---
title: wls_singleton_service
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to managed singleton services in a WebLogic domain.

Here is an example on how you should use this:

    wls_singleton_service { 'SingletonService':
        ensure                           => 'present',
        cluster                          => 'ClusterName',
        user_preferred_server            => 'PreferredServerName',
        class_name                       => 'com.example.package.SingletonServiceImpl',
        constrained_candidate_servers    => ['PreferredServerName', 'OtherServerName'],
        additional_migration_attempts    => 2,
        millis_to_sleep_between_attempts => 300000,
        notes                            => 'This is a singleton service that prefers to run on PreferredServerName, but can be migrated to OtherServerName.',
    }

In this example you are managing a singleton service in the default domain. When you want to
manage a singleton service in a specific domain, you can use:

      wls_singleton_service { 'my_domain/SingletonService':
        ensure                           => 'present',
        cluster                          => 'ClusterName',
        user_preferred_server            => 'PreferredServerName',
        class_name                       => 'com.example.package.SingletonServiceImpl',
        constrained_candidate_servers    => ['PreferredServerName', 'OtherServerName'],
        additional_migration_attempts    => 2,
        millis_to_sleep_between_attempts => 300000,
        notes                            => 'This is a singleton service that prefers to run on PreferredServerName, but can be migrated to OtherServerName.',
    }

## Attributes



Attribute Name                                                                              | Short Description                                                                      |
------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- |
[additional_migration_attempts](#wls_singleton_service_additional_migration_attempts)       | additional migration attempts
                                                         |
[class_name](#wls_singleton_service_class_name)                                             | The fully qualified classname of the singleton service.                                |
[cluster](#wls_singleton_service_cluster)                                                   | The cluster this singleton service should be targetted to.                             |
[constrained_candidate_servers](#wls_singleton_service_constrained_candidate_servers)       | The list of servers this migratable target should be constrained to
                   |
[domain](#wls_singleton_service_domain)                                                     | With this parameter, you identify the domain, where your objects is in.                |
[ensure](#wls_singleton_service_ensure)                                                     | The basic property that the resource should be in.                                     |
[hosting_server](#wls_singleton_service_hosting_server)                                     | Returns the name of the server that currently hosts the singleton service.             |
[millis_to_sleep_between_attempts](#wls_singleton_service_millis_to_sleep_between_attempts) | The amount of milliseconds to wait between attempts to migrate this singleton service
 |
[name](#wls_singleton_service_name)                                                         | The name.                                                                              |
[notes](#wls_singleton_service_notes)                                                       | Optional notes to attach to this singleton service for documentation purposes.         |
[provider](#wls_singleton_service_provider)                                                 | resource.                                                                              |
[singleton_service_name](#wls_singleton_service_singleton_service_name)                     | The name of this singleton service.                                                    |
[tags](#wls_singleton_service_tags)                                                         | Return all tags on this Configuration MBean
                                           |
[user_preferred_server](#wls_singleton_service_user_preferred_server)                       | The preferred server to run this singleton service on.                                 |




### additional_migration_attempts<a name='wls_singleton_service_additional_migration_attempts'>

additional migration attempts


[Back to overview of wls_singleton_service](#attributes)


### class_name<a name='wls_singleton_service_class_name'>

The fully qualified classname of the singleton service.


[Back to overview of wls_singleton_service](#attributes)


### cluster<a name='wls_singleton_service_cluster'>

The cluster this singleton service should be targetted to.


[Back to overview of wls_singleton_service](#attributes)


### constrained_candidate_servers<a name='wls_singleton_service_constrained_candidate_servers'>

The list of servers this migratable target should be constrained to


[Back to overview of wls_singleton_service](#attributes)


### domain<a name='wls_singleton_service_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_singleton_service](#attributes)


### ensure<a name='wls_singleton_service_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_singleton_service](#attributes)


### hosting_server<a name='wls_singleton_service_hosting_server'>

Returns the name of the server that currently hosts the singleton service.

An example on how to use this:

    wls_singleton_service {a_wls_singleton_service :
       ...
       hosting_server => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_singleton_service:hosting_server']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_singleton_service](#attributes)


### millis_to_sleep_between_attempts<a name='wls_singleton_service_millis_to_sleep_between_attempts'>

The amount of milliseconds to wait between attempts to migrate this singleton service


[Back to overview of wls_singleton_service](#attributes)


### name<a name='wls_singleton_service_name'>

The name.


[Back to overview of wls_singleton_service](#attributes)


### notes<a name='wls_singleton_service_notes'>

Optional notes to attach to this singleton service for documentation purposes.


[Back to overview of wls_singleton_service](#attributes)


### provider<a name='wls_singleton_service_provider'>

The specific backend to use for this `wls_singleton_service`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a singleton service of a WebLogic domain via regular WLST


[Back to overview of wls_singleton_service](#attributes)


### singleton_service_name<a name='wls_singleton_service_singleton_service_name'>

The name of this singleton service.


[Back to overview of wls_singleton_service](#attributes)


### tags<a name='wls_singleton_service_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_singleton_service {a_wls_singleton_service :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_singleton_service:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_singleton_service](#attributes)


### user_preferred_server<a name='wls_singleton_service_user_preferred_server'>

The preferred server to run this singleton service on.


[Back to overview of wls_singleton_service](#attributes)

