---
title: wls_virtual_host
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage virtual host in an WebLogic domain.

Here is an example on how you should use this:

    wls_virtual_host { 'WS':
      ensure             => 'present',
      channel            => 'HTTP',
      target             => ['WebCluster'],
      targettype         => ['Cluster'],
      virtual_host_names => ['admin.example.com','10.10.10.10'],
    }

In this example you are managing a virtual host in the default domain. When you want to
manage a virtual host in a specific domain, you can use:

    wls_virtual_host { 'my_domain/WS':
      ensure             => 'present',
      channel            => 'HTTP',
      target             => ['WebCluster'],
      targettype         => ['Cluster'],
      virtual_host_names => ['admin.example.com','10.10.10.10'],
    }

## Attributes



Attribute Name                                                                                 | Short Description                                                                                                                                            |
---------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[accept_context_path_in_get_real_path](#wls_virtual_host_accept_context_path_in_get_real_path) | Indicates whether this server allows the inclusion of the context path in the virtual path to <tt>context.getRealPath()</tt>.                                |
[auth_cookie_enabled](#wls_virtual_host_auth_cookie_enabled)                                   | Whether authcookie feature is enabled or not.                                                                                                                |
[channel](#wls_virtual_host_channel)                                                           | Server channel name
                                                                                                                                         |
[charsets](#wls_virtual_host_charsets)                                                         | Provides user defined mapping between internet and Java charset names.                                                                                       |
[chunked_transfer_disabled](#wls_virtual_host_chunked_transfer_disabled)                       | Indicates whether the use of Chunk Transfer-Encoding in HTTP/1.1 is enabled.                                                                                 |
[client_ip_header](#wls_virtual_host_client_ip_header)                                         | Get the Client IP Header from WebSerevrMBean.                                                                                                                |
[default_web_app_context_root](#wls_virtual_host_default_web_app_context_root)                 | Returns the original context-root for the default Web application for this Web server.                                                                       |
[deployment_order](#wls_virtual_host_deployment_order)                                         | A priority that the server uses to determine when it deploys an item.                                                                                        |
[domain](#wls_virtual_host_domain)                                                             | With this parameter, you identify the domain, where your objects is in.                                                                                      |
[ensure](#wls_virtual_host_ensure)                                                             | The basic property that the resource should be in.                                                                                                           |
[frontend_host](#wls_virtual_host_frontend_host)                                               | The name of the host to which all redirected URLs will be sent.                                                                                              |
[frontend_http_port](#wls_virtual_host_frontend_http_port)                                     | The name of the HTTP port to which all redirected URLs will be sent.                                                                                         |
[frontend_https_port](#wls_virtual_host_frontend_https_port)                                   | The name of the secure HTTP port to which all redirected URLs will be sent.                                                                                  |
[https_keep_alive_secs](#wls_virtual_host_https_keep_alive_secs)                               | The amount of time this server waits before closing an inactive HTTPS connection.                                                                            |
[keep_alive_enabled](#wls_virtual_host_keep_alive_enabled)                                     | Indicates whether there should be a persistent connection to this server.                                                                                    |
[keep_alive_secs](#wls_virtual_host_keep_alive_secs)                                           | The amount of time this server waits before closing an inactive HTTP connection.                                                                             |
[log_buffer_size_kb](#wls_virtual_host_log_buffer_size_kb)                                     | Gets the underlying log buffer size in kilobytes
                                                                                                            |
[log_date_format_pattern](#wls_virtual_host_log_date_format_pattern)                           | The date format pattern used for rendering dates in the  log.                                                                                                |
[log_elf_fields](#wls_virtual_host_log_elf_fields)                                             | Returns the list of fields specified for the <code>extended</code> logging format for access.log.                                                            |
[log_file_count](#wls_virtual_host_log_file_count)                                             | The maximum number of log files that the server creates when it rotates the log.                                                                             |
[log_file_format](#wls_virtual_host_log_file_format)                                           | The format of the HTTP log file.                                                                                                                             |
[log_file_min_size](#wls_virtual_host_log_file_min_size)                                       | The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file.                                                           |
[log_file_name](#wls_virtual_host_log_file_name)                                               | The name of the log file.                                                                                                                                    |
[log_file_rotation_dir](#wls_virtual_host_log_file_rotation_dir)                               | The directory where the rotated log files will be stored.                                                                                                    |
[log_file_time_span](#wls_virtual_host_log_file_time_span)                                     | The interval (in hours) at which the server saves old log messages to another file.                                                                          |
[log_logging_enabled](#wls_virtual_host_log_logging_enabled)                                   | Indicates whether this server logs HTTP requests.                                                                                                            |
[log_notes](#wls_virtual_host_log_notes)                                                       | Optional information that you can include to describe this configuration.                                                                                    |
[log_number_of_files_limited](#wls_virtual_host_log_number_of_files_limited)                   | Indicates whether to limit the number of log files that this server instance creates to store old messages.                                                  |
[log_rotate_log_on_startup](#wls_virtual_host_log_rotate_log_on_startup)                       | Specifies whether a server rotates its log file during its startup cycle.                                                                                    |
[log_rotation_time](#wls_virtual_host_log_rotation_time)                                       | Determines the start time (hour and minute) for a time-based rotation sequence.                                                                              |
[log_rotation_type](#wls_virtual_host_log_rotation_type)                                       | Criteria for moving old log messages to a separate file.                                                                                                     |
[log_tags](#wls_virtual_host_log_tags)                                                         | Return all tags on this Configuration MBean
                                                                                                                 |
[log_time_in_gmt](#wls_virtual_host_log_time_in_gmt)                                           | Specifies whether the time stamps for HTTP log messages are in Greenwich Mean Time (GMT) regardless of the local time zone that the host computer specifies. |
[max_post_size](#wls_virtual_host_max_post_size)                                               | The maximum post size this server allows for reading HTTP POST data in a servlet request, excluding chunked HTTP requests (Transfer-Encoding: chunked).      |
[max_post_time_secs](#wls_virtual_host_max_post_time_secs)                                     | Max Post Time (in seconds) for reading HTTP POST data in a servlet request.                                                                                  |
[max_request_parameter_count](#wls_virtual_host_max_request_parameter_count)                   | Max Request Parameter Count this server allows for reading maximum HTTP POST Parameters count in a servlet request.                                          |
[name](#wls_virtual_host_name)                                                                 | The name.                                                                                                                                                    |
[network_access_point](#wls_virtual_host_network_access_point)                                 | The dedicated server channel name (NetworkAccessPoint) for which this virtual host will serve http request.                                                  |
[notes](#wls_virtual_host_notes)                                                               | Optional information that you can include to describe this configuration.                                                                                    |
[overload_response_code](#wls_virtual_host_overload_response_code)                             | Get the response code to be used when an application is overloaded.                                                                                          |
[post_timeout_secs](#wls_virtual_host_post_timeout_secs)                                       | Timeout (in seconds) for reading HTTP POST data in a servlet request.                                                                                        |
[provider](#wls_virtual_host_provider)                                                         | resource.                                                                                                                                                    |
[send_server_header_enabled](#wls_virtual_host_send_server_header_enabled)                     | Indicates whether this server name is sent with the HTTP response.                                                                                           |
[single_signon_disabled](#wls_virtual_host_single_signon_disabled)                             | Indicates whether the singleSignonDisabled attribute is enabled
                                                                                             |
[tags](#wls_virtual_host_tags)                                                                 | Return all tags on this Configuration MBean
                                                                                                                 |
[target](#wls_virtual_host_target)                                                             | An array of target names.                                                                                                                                    |
[targettype](#wls_virtual_host_targettype)                                                     | An array of target types.                                                                                                                                    |
[timeout](#wls_virtual_host_timeout)                                                           | Timeout for applying a resource.                                                                                                                             |
[url_resource](#wls_virtual_host_url_resource)                                                 | Adds a URL connection factory resource into JNDI.                                                                                                            |
[use_header_encoding](#wls_virtual_host_use_header_encoding)                                   | 
                                                                                                                                                            |
[use_highest_compatible_http_version](#wls_virtual_host_use_highest_compatible_http_version)   | Enables use of the highest compatible HTTP protocol version-string in the response.                                                                          |
[virtual_host_name](#wls_virtual_host_virtual_host_name)                                       | The virtual host name
                                                                                                                                       |
[virtual_host_names](#wls_virtual_host_virtual_host_names)                                     | virtual host names
                                                                                                                                          |
[wap_enabled](#wls_virtual_host_wap_enabled)                                                   | Indicates whether the session ID should include JVM information.                                                                                             |
[write_chunk_bytes](#wls_virtual_host_write_chunk_bytes)                                       | The default size of the blocks to be written to the network layer.                                                                                           |




### accept_context_path_in_get_real_path<a name='wls_virtual_host_accept_context_path_in_get_real_path'>

Indicates whether this server allows the inclusion of the context path in the virtual path to <tt>context.getRealPath()</tt>. (If checked, you cannot use sub directories with the same name as <tt>contextPath</tt>). This is a compatibility switch that will be deprecated 9.0.0.0 in future releases.  Gets the acceptContextPathInGetRealPath attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       accept_context_path_in_get_real_path => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:accept_context_path_in_get_real_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### auth_cookie_enabled<a name='wls_virtual_host_auth_cookie_enabled'>

Whether authcookie feature is enabled or not.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       auth_cookie_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:auth_cookie_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### channel<a name='wls_virtual_host_channel'>

Server channel name


[Back to overview of wls_virtual_host](#attributes)


### charsets<a name='wls_virtual_host_charsets'>

Provides user defined mapping between internet and Java charset names.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       charsets => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:charsets']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### chunked_transfer_disabled<a name='wls_virtual_host_chunked_transfer_disabled'>

Indicates whether the use of Chunk Transfer-Encoding in HTTP/1.1 is enabled.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       chunked_transfer_disabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:chunked_transfer_disabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### client_ip_header<a name='wls_virtual_host_client_ip_header'>

Get the Client IP Header from WebSerevrMBean.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       client_ip_header => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:client_ip_header']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### default_web_app_context_root<a name='wls_virtual_host_default_web_app_context_root'>

Returns the original context-root for the default Web application for this Web server. Alternatively, you can use the context-root attributes in application.xml or weblogic.xml to set a default Web application. The context-root for a default Web application is /. If "" (empty string) is specified, the Web server defaults to /.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       default_web_app_context_root => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:default_web_app_context_root']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### deployment_order<a name='wls_virtual_host_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       deployment_order => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### domain<a name='wls_virtual_host_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_virtual_host](#attributes)


### ensure<a name='wls_virtual_host_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_virtual_host](#attributes)


### frontend_host<a name='wls_virtual_host_frontend_host'>

The name of the host to which all redirected URLs will be sent. If specified, WebLogic Server will use this value rather than the one in the HOST header.  Sets the HTTP frontendHost Provides a method to ensure that the webapp will always have the correct HOST information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       frontend_host => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:frontend_host']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### frontend_http_port<a name='wls_virtual_host_frontend_http_port'>

The name of the HTTP port to which all redirected URLs will be sent. If specified, WebLogic Server will use this value rather than the one in the HOST header.  Sets the frontendHTTPPort Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       frontend_http_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:frontend_http_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### frontend_https_port<a name='wls_virtual_host_frontend_https_port'>

The name of the secure HTTP port to which all redirected URLs will be sent. If specified, WebLogic Server will use this value rather than the one in the HOST header.  Sets the frontendHTTPSPort Provides a method to ensure that the webapp will always have the correct PORT information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       frontend_https_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:frontend_https_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### https_keep_alive_secs<a name='wls_virtual_host_https_keep_alive_secs'>

The amount of time this server waits before closing an inactive HTTPS connection.  Number of seconds to maintain HTTPS keep-alive before timing out the request.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       https_keep_alive_secs => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:https_keep_alive_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### keep_alive_enabled<a name='wls_virtual_host_keep_alive_enabled'>

Indicates whether there should be a persistent connection to this server. (This may improve the performance of your Web applications.)  Gets the keepAliveEnabled attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       keep_alive_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:keep_alive_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### keep_alive_secs<a name='wls_virtual_host_keep_alive_secs'>

The amount of time this server waits before closing an inactive HTTP connection.  Number of seconds to maintain HTTP keep-alive before timing out the request.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       keep_alive_secs => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:keep_alive_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_buffer_size_kb<a name='wls_virtual_host_log_buffer_size_kb'>

Gets the underlying log buffer size in kilobytes

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_buffer_size_kb => '8'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_buffer_size_kb']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_date_format_pattern<a name='wls_virtual_host_log_date_format_pattern'>

The date format pattern used for rendering dates in the  log. The DateFormatPattern string conforms to the specification of the <code>java.text.SimpleDateFormat</code> class.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_date_format_pattern => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_date_format_pattern']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_elf_fields<a name='wls_virtual_host_log_elf_fields'>

Returns the list of fields specified for the <code>extended</code> logging format for access.log.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_elf_fields => 'date time cs-method cs-uri sc-status'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_elf_fields']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_file_count<a name='wls_virtual_host_log_file_count'>

The maximum number of log files that the server creates when it rotates the log. This number does not include the file that the server uses to store current messages. (Requires that you enable Number of Files Limited.)

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_file_count => '7'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_file_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_file_format<a name='wls_virtual_host_log_file_format'>

The format of the HTTP log file. Both formats are defined by the W3C. With the extended log format, you use server directives in the log file to customize the information that the server records.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_file_format => 'common'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_file_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_file_min_size<a name='wls_virtual_host_log_file_min_size'>

The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file. The default is 500 kilobytes. After the log file reaches the specified minimum size, the next time the server checks the file size, it will rename the current log file as <code>SERVER_NAME.lognnnnn</code> and create a new one to store subsequent messages. (Requires that you specify a file rotation type of <code>Size</code>.)

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_file_min_size => '500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_file_min_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_file_name<a name='wls_virtual_host_log_file_name'>

The name of the log file.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_file_rotation_dir<a name='wls_virtual_host_log_file_rotation_dir'>

The directory where the rotated log files will be stored. By default the rotated files are stored in the same directory where the log file is stored.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_file_rotation_dir => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_file_rotation_dir']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_file_time_span<a name='wls_virtual_host_log_file_time_span'>

The interval (in hours) at which the server saves old log messages to another file. (Requires that you specify a file rotation type of <code>TIME</code>.)

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_file_time_span => '24'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_file_time_span']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_logging_enabled<a name='wls_virtual_host_log_logging_enabled'>

Indicates whether this server logs HTTP requests. (The remaining fields on this page are relevant only if you select this check box.)  Gets the loggingEnabled attribute of the WebServerMBean object.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### log_notes<a name='wls_virtual_host_log_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_number_of_files_limited<a name='wls_virtual_host_log_number_of_files_limited'>

Indicates whether to limit the number of log files that this server instance creates to store old messages. (Requires that you specify a file rotation type of <code>SIZE</code> or <code>TIME</code>.)  After the server reaches this limit, it deletes the oldest log file and creates a new log file with the latest suffix.  If you do not enable this option, the server creates new files indefinitely and you must clean up these files as you require.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_number_of_files_limited => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_number_of_files_limited']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### log_rotate_log_on_startup<a name='wls_virtual_host_log_rotate_log_on_startup'>

Specifies whether a server rotates its log file during its startup cycle. The default value in production mode is false.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_rotate_log_on_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_rotate_log_on_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### log_rotation_time<a name='wls_virtual_host_log_rotation_time'>

Determines the start time (hour and minute) for a time-based rotation sequence.  At the time that this value specifies, the server renames the current log file. Thereafter, the server renames the log file at an interval that you specify in File Time Span.  Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.   Use the following format: <code>H:mm</code>, where <ul><li><code>H</code> is Hour in day (0-23). <li><code>mm</code> is the minute in hour </ul>

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_rotation_time => '00:00'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_rotation_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_rotation_type<a name='wls_virtual_host_log_rotation_type'>

Criteria for moving old log messages to a separate file. <ul> <li><code>NONE</code> Messages accumulate in a single file. You must erase the contents of the file when the size is too large. Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.  <li><code>SIZE</code> When the log file reaches the size that you specify in <code>FileMinSize</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>.  <li><code>TIME</code> At each time interval that you specify in <code>TimeSpan</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>. </ul>  After the server renames a file, subsequent messages accumulate in a new file with the name that you specified as the log file name.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_rotation_type => 'bySize'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_rotation_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_tags<a name='wls_virtual_host_log_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### log_time_in_gmt<a name='wls_virtual_host_log_time_in_gmt'>

Specifies whether the time stamps for HTTP log messages are in Greenwich Mean Time (GMT) regardless of the local time zone that the host computer specifies.  Use this method to comply with the W3C specification for Extended Format log files. The specification states that all time stamps for Extended Format log entries be in GMT.  This method applies only if you have specified the <code>extended</code> message format.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       log_time_in_gmt => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:log_time_in_gmt']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### max_post_size<a name='wls_virtual_host_max_post_size'>

The maximum post size this server allows for reading HTTP POST data in a servlet request, excluding chunked HTTP requests (Transfer-Encoding: chunked).  A value less than 0 indicates an unlimited size.  Gets the maxPostSize attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       max_post_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:max_post_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### max_post_time_secs<a name='wls_virtual_host_max_post_time_secs'>

Max Post Time (in seconds) for reading HTTP POST data in a servlet request. MaxPostTime &lt; 0 means unlimited  Gets the maxPostTimeSecs attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       max_post_time_secs => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:max_post_time_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### max_request_parameter_count<a name='wls_virtual_host_max_request_parameter_count'>

Max Request Parameter Count this server allows for reading maximum HTTP POST Parameters count in a servlet request.  Gets the maxRequestParameterCount attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       max_request_parameter_count => '10000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:max_request_parameter_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### name<a name='wls_virtual_host_name'>

The name.


[Back to overview of wls_virtual_host](#attributes)


### network_access_point<a name='wls_virtual_host_network_access_point'>

The dedicated server channel name (NetworkAccessPoint) for which this virtual host will serve http request. If the NetworkAccessPoint for a given http request doesn't match any virtual host's NetworkAccessPoint, incoming HOST header will be matched with the VirtualHostNames in order to resolve the right virtual host.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       network_access_point => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:network_access_point']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### notes<a name='wls_virtual_host_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### overload_response_code<a name='wls_virtual_host_overload_response_code'>

Get the response code to be used when an application is overloaded. An application can get overloaded when the number of pending requests has reached the max capacity specified in the WorkManager or when the server is low on memory. The low memory condition is determined using {@link OverloadProtectionMBean#getFreeMemoryPercentLowThreshold()}.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       overload_response_code => '503'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:overload_response_code']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### post_timeout_secs<a name='wls_virtual_host_post_timeout_secs'>

Timeout (in seconds) for reading HTTP POST data in a servlet request. If the POST data is chunked, the amount of time the server waits between the end of receiving the last chunk of data and the end of receiving the next chunk of data in an HTTP POST before it times out. (This is used to prevent denial-of-service attacks that attempt to overload the server with POST data.)  Gets the postTimeoutSecs attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       post_timeout_secs => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:post_timeout_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### provider<a name='wls_virtual_host_provider'>

The specific backend to use for this `wls_virtual_host`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage virtual hosts of a WebLogic domain


[Back to overview of wls_virtual_host](#attributes)


### send_server_header_enabled<a name='wls_virtual_host_send_server_header_enabled'>

Indicates whether this server name is sent with the HTTP response. (This is useful for wireless applications where there is limited space for headers.)  Indicates whether this server instance includes its name and WebLogic Server version number in HTTP response headers.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       send_server_header_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:send_server_header_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### single_signon_disabled<a name='wls_virtual_host_single_signon_disabled'>

Indicates whether the singleSignonDisabled attribute is enabled

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       single_signon_disabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:single_signon_disabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### tags<a name='wls_virtual_host_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### target<a name='wls_virtual_host_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_virtual_host](#attributes)


### targettype<a name='wls_virtual_host_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_virtual_host](#attributes)


### timeout<a name='wls_virtual_host_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_virtual_host](#attributes)


### url_resource<a name='wls_virtual_host_url_resource'>

Adds a URL connection factory resource into JNDI.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       url_resource => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:url_resource']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)


### use_header_encoding<a name='wls_virtual_host_use_header_encoding'>



An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       use_header_encoding => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:use_header_encoding']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### use_highest_compatible_http_version<a name='wls_virtual_host_use_highest_compatible_http_version'>

Enables use of the highest compatible HTTP protocol version-string in the response. E.g. HTTP spec suggests that HTTP/1.1 version-string should be used in response to a request using HTTP/1.0. This does not necessarily affect the response format.

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       use_highest_compatible_http_version => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:use_highest_compatible_http_version']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### virtual_host_name<a name='wls_virtual_host_virtual_host_name'>

The virtual host name


[Back to overview of wls_virtual_host](#attributes)


### virtual_host_names<a name='wls_virtual_host_virtual_host_names'>

virtual host names


[Back to overview of wls_virtual_host](#attributes)


### wap_enabled<a name='wls_virtual_host_wap_enabled'>

Indicates whether the session ID should include JVM information. (Checking this box may be necessary when using URL rewriting with WAP devices that limit the size of the URL to 128 characters, and may also affect the use of replicated sessions in a cluster.) When this box is selected, the default size of the URL will be set at 52 characters, and it will not contain any special characters.  Gets the WAPEnabled attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       wap_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:wap_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_virtual_host](#attributes)


### write_chunk_bytes<a name='wls_virtual_host_write_chunk_bytes'>

The default size of the blocks to be written to the network layer.  Gets the writeChunkBytes attribute of the WebServerMBean object

An example on how to use this:

    wls_virtual_host {a_wls_virtual_host :
       ...
       write_chunk_bytes => '512'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_virtual_host:write_chunk_bytes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_virtual_host](#attributes)

