#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:domain) do
  include EasyType
  include EasyType::Validators::Name

  isnamevar

  validate do |name|
    fail "#{name} is not a registered domain name." unless registered_domain?(name)
  end

  desc <<-EOD
  With this parameter, you identify the domain, where your objects is in.

  The domain name is part of the full qualified name of any WebLogic object on a system. Let's
  say we want to describe a WebLogic server. The full qualified name is:

      wls_server{'domain_name/server_name':
        ensure => present,
        ...
      }

  When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
  you want to manage, you'll have to put a `wls_settings` in your manifest.

  EOD

  defaultto do
    resource[:name] = "default/#{resource.name}"
    'default'
  end

  to_translate_to_resource do |raw_resource|
    raw_resource['domain']
  end

  private

  def registered_domain?(name)
    if resource.catalog && resource.catalog.resource('wls_setting', name)
      #
      # Look in the catalog and check if there is already a wls_setting for this resource. If
      # it exists, we are running a normal(full) catalog with wls_settings done.
      #
      true
    else
      #
      # If it doesn't exist. We are either running puppet resource or a mini manifest
      # expecting WLS to run. In order to run the wls_settings has to be saved and available
      #
      resource.class.configuration.keys.include?(name)
    end
  end
end

autorequire(:wls_domain)  { domain }
autorequire(:wls_setting) { domain }
child_of(:wls_domain) {domain}
