#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_tightly_coupled_transactions_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Indicates tight coupling of transaction branches that span different transaction manager systems.   When enabled, WebLogic uses the transaction identifier of a transaction imported by the InterposedTransactionManager for XA calls rather than an internally mapped Xid. This applies to inter-domain WebLogic transactions and transactions imported from Tuxedo. This allows for tight coupling of transaction branches for transactions that span across different transaction manager systems.  If a transaction between WebLogic and Tuxedo resources uses a GridLink Data Source with GridLink Affinity enabled, the XA Affinity context is automatically used for the transaction. 

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_tightly_coupled_transactions_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_tightly_coupled_transactions_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('JTACluster/%{cluster_name}/TightlyCoupledTransactionsEnabled')
end
