#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Specifies the maximum amount of time, in seconds, an active transaction is allowed to be in the first phase of a two-phase commit transaction. If the specified amount of time expires, the transaction is automatically rolled back. 

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_timeout_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JTACluster/%{cluster_name}/TimeoutSeconds')
end
