#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_two_phase_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Indicates that the two-phase commit protocol is used to coordinate transactions across two or more resource managers.  If not selected: <ul> <li> Two-phase commit is disabled and any attempt to use two-phase commit results in a RollbackException being thrown.</li> <li> All transaction logging is disabled, including checkpoint records.</li> </ul> 

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_two_phase_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_two_phase_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('JTACluster/%{cluster_name}/TwoPhaseEnabled')
end
