#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:time_to_live, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Sets the time-to-live (TTL) setting for the multicast message. The TTL setting designates how far multicast UDP/IP packets can travel on a network. The TTL is expressed in terms of how many hops a packet survives; each network interface, router, and managed switch is considered one hop. The TTL value should be set to the lowest integer value that works. Setting the value too high can use unnecessary bandwidth on other LAN segments and can even cause the operating system or network devices to disable multicast traffic. Typically, setting the TTL value to 1 works on a simple switched backbone. A value of 2 or more may be required on an advanced backbone with intelligent switching. A value of 0 is used for single server clusters that are used for development and testing. 

  An example on how to use this:

      wls_coherence_cluster {a_wls_coherence_cluster :
         ...
         time_to_live => '4'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_cluster:time_to_live']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('CoherenceClusterResource/%{coherence_cluster_name}/CoherenceClusterParams/%{coherence_cluster_name}/TimeToLive')
end
