#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_replay_initiation_timeout, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The amount of time, in seconds, a data source allows for Application Continuity replay processing before timing out and ending a replay session context. <ul> <li>When set to zero (0) seconds, replay processing is disabled.</li> <li>The default value is 3600 seconds.</li> <li>See <code>oracle.ucp.jdbc.ConnectionInitializationCallback</code>.</ul> 

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         oracle_replay_initiation_timeout => '3600'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:oracle_replay_initiation_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{datasource_name}/JDBCOracleParams/%{datasource_name}/ReplayInitiationTimeout')
end
