#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_keep_logical_conn_open_on_release, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Enables WebLogic Server to keep the logical JDBC connection open for a global transaction when the physical XA connection is returned to the connection pool.   Select this option if the XA driver used to create database connections or the DBMS requires that a logical JDBC connection be kept open while transaction processing continues (although the physical XA connection can be returned to the connection pool).  Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers. 

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_keep_logical_conn_open_on_release => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_keep_logical_conn_open_on_release']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/KeepLogicalConnOpenOnRelease')
end
