#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_set_transaction_timeout, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Enables WebLogic Server to set a transaction branch timeout based on the value for XaTransactionTimeout.  When enabled, the WebLogic Server Transaction Manager calls <code>XAResource.setTransactionTimeout()</code> before calling <code>XAResource.start</code>, and passes either the XA Transaction Timeout value or the global transaction timeout.   You may want to set a transaction branch timeout if you have long-running transactions that exceed the default timeout value on the XA resource.  Note: To use this feature, the resource manager (typically, the JDBC driver) must support the <code>javax.transaction.xa.XAResource.setTransactionTimeout()</code> method.  

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_set_transaction_timeout => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_set_transaction_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/XaSetTransactionTimeout')
end
