#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:administration_port_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Specifies whether the domain-wide administration port should be enabled for this WebLogic Server domain. Because the administration port uses SSL, enabling the administration port requires that SSL must be configured for all servers in the domain.  The domain-wide administration port enables you to start a WebLogic Server instance in <code>STANDBY</code> state. It also allows you to separate administration traffic from application traffic in your domain. Because all servers in the domain must enable or disable the administration port at once, you configure the default administration port settings at the domain level.  If you enable the administration port:  <ul> <li> The administration port accepts only connections that specify administrator credentials. </li>  <li> Connections that specify administrator credentials can use only the administration port. </li>  <li> The command that starts managed servers must specify a secure protocol and the administration port: <code>-Dweblogic.management.server=https://admin_server:administration_port</code> </li> </ul> 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         administration_port_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:administration_port_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('AdministrationPortEnabled')
end
