#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jmx_invocation_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of seconds that internal WebLogic Server processes wait to connect to an MBean server, invoke an MBean server method, and return the results of the invocation. If the MBean server method does not complete (return) within the timeout period, WebLogic Server abandons its invocation attempt. Some internal management processes within WebLogic Server require a server instance to connect to MBean servers in other WebLogic Server instances and invoke an MBean server method. The timeout period prevents the internal process from locking up if an MBean server cannot successfully return a method invocation. A value of <code>0</code> (zero) prevents the method invocation from timing out. With such a value, the internal process will wait indefinitely until the MBean server's method returns.  

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jmx_invocation_timeout_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jmx_invocation_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JMX/%{domain_name}/InvocationTimeoutSeconds')
end
