#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_before_completion_iteration_limit, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum number of cycles that the transaction manager performs the <tt>beforeCompletion</tt> synchronization callback for this WebLogic Server domain.  Nothing prevents a Synchronization object from registering another during <code>beforeCompletion</code>, even those whose <code>beforeCompletions</code> have already been called. For example, an EJB can call another in its <code>ejbStore()</code> method. To accommodate this, the transaction manager calls all Synchronization objects, then repeats the cycle if new ones have been registered. This count sets a limit to the number of cycles that synchronization occurs. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_before_completion_iteration_limit => '10'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_before_completion_iteration_limit']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JTA/%{domain_name}/BeforeCompletionIterationLimit')
end
