#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_parallel_xa_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Indicates that XA calls are executed in parallel if there are available threads. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_parallel_xa_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_parallel_xa_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('JTA/%{domain_name}/ParallelXAEnabled')
end
