#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_clear_text_credential_access_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Returns true if allow access to credential in clear text. This can be overridden by the system property <code>-Dweblogic.management.clearTextCredentialAccessEnabled</code> 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_clear_text_credential_access_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_clear_text_credential_access_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityConfiguration/%{domain_name}/ClearTextCredentialAccessEnabled')
end
