#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_downgrade_untrusted_principals, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Whether or not to downgrade to anonymous principals that cannot be verified. This is useful for server-server communication between untrusted domains. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_downgrade_untrusted_principals => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_downgrade_untrusted_principals']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityConfiguration/%{domain_name}/DowngradeUntrustedPrincipals')
end
