#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_enforce_valid_basic_auth_credentials, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Whether or not the system should allow requests with invalid Basic Authentication credentials to access unsecure resources. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_enforce_valid_basic_auth_credentials => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_enforce_valid_basic_auth_credentials']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityConfiguration/%{domain_name}/EnforceValidBasicAuthCredentials')
end
