#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_identity_domain_aware_providers_required, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Returns true if all role mapping, authorization, credential mapping, and audit providers configured in the domain must support the IdentityDomainAwareProviderMBean interface's administrative identity domain. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_identity_domain_aware_providers_required => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_identity_domain_aware_providers_required']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityConfiguration/%{domain_name}/IdentityDomainAwareProvidersRequired')
end
