#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_principal_equals_compare_dn_and_guid, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Specifies whether the GUID and DN data in a WebLogic Server principal object are used when the equals method of that object is invoked.   If enabled, the GUID and DN data (if included among the attributes in a WebLogic Server principal object) and the principal name are compared when this method is invoked. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_principal_equals_compare_dn_and_guid => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_principal_equals_compare_dn_and_guid']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityConfiguration/%{domain_name}/PrincipalEqualsCompareDnAndGuid')
end
