#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_use_kss_for_demo, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Determines whether the Demo Identity and Demo Trust key stores should be obtained from the Oracle Key Store Service (KSS).  If enabled, Weblogic Server will request the Demo Identity and Domain Trust key stores from KSS. Subsequent to installation however, the KSS Demo key stores may have been manipulated such that appropriate Demo certificates or keys are not available.  Please verify the following KSS Demo Identity keystore has an X.509 private key and corresponding public identity certificate signed by the Demo Certificate Authority (CA): <dl> <dt>KSS Stripe <dd>system <dt>KSS Key Store <dd>demoidentity <dt>KSS Private Key Alias <dd>DemoIdentity </dl>  Please verify the following KSS Domain Trust keystore has a trusted Demo Certificate Authority X.509 certificate: <dl> <dt>KSS Stripe <dd>system <dt>KSS Key Store <dd>trust </dl>  

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_use_kss_for_demo => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_use_kss_for_demo']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityConfiguration/%{domain_name}/UseKSSForDemo')
end
