#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:graceful_shutdown_timeout, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of seconds a graceful shutdown operation waits before forcing a shut down. A graceful shutdown gives WebLogic Server subsystems time to complete certain application processing currently in progress. If subsystems are unable to complete processing within the number of seconds that you specify here, the partition will force shutdown automatically. <p/> A value of <code>0</code> means that the partition will wait indefinitely for a graceful shutdown to complete. <p/> The graceful shutdown timeout applies only to graceful shutdown operations. 

  An example on how to use this:

      wls_domain_partition {a_wls_domain_partition :
         ...
         graceful_shutdown_timeout => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain_partition:graceful_shutdown_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('GracefulShutdownTimeout')
end
