#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_domain_partition_resource_group_deployment) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage deployments in a resource group of a domain partition in an WebLogic 12.2.1 domain.
    EOD

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name} "
      environment = { 'action' => 'index', 'type' => 'wls_domain_partition_resource_group_deployment' }
      wlst template('wls_config/wls_domain_partition_resource_group_deployment/index.py.erb', binding), environment
    end

    on_create do
      wlst_action = 'create'
      Puppet.info "create #{name} "
      wlst template('wls_config/wls_domain_partition_resource_group_deployment/create_modify.py.erb', binding)
      nil
    end

    on_modify do
      wlst_action = 'modify'
      Puppet.info "modify #{name} "
      wlst template('wls_config/wls_domain_partition_resource_group_deployment/create_modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wlst template('wls_config/wls_domain_partition_resource_group_deployment/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :domain_partition_name
    parameter :resource_group_name
    parameter :deployment_name
    parameter :localpath
    parameter :planpath
    parameter :timeout
    parameter :remote
    parameter :upload

    property :deploymenttype
    property :versionidentifier
    property :stagingmode

    add_title_attributes(:domain_partition_name, :resource_group_name, :deployment_name) do
      /(.+):(.+):(.+)$/
    end
  end
end
