#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:synchronous_write_policy, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The disk write policy that determines how the file store writes data to disk.  This policy also affects the JMS file store's performance, scalability, and reliability. Oracle recommends `Direct-Write-With-Cache` which tends to have the highest performance. The default value is `Direct-Write`. The valid policy options are:

  - `Direct-Write` Direct I/O is supported on all platforms. When available, file stores in direct I/O mode automatically load the native I/O `wlfileio` driver. This option tends to out-perform `Cache-Flush` and tend to be slower than `Direct-Write-With-Cache`. This mode does not require a native store `wlfileio` driver, but performs faster when they are available.
  - `Direct-Write-With-Cache` Store records are written synchronously to primary files in the directory specified by the `Directory` attribute and asynchronously to a corresponding cache file in the `Cache Directory`. The `Cache Directory` provides information about disk space, locking, security, and performance implications. This mode requires a native store `wlfileiocode` driver. If the native driver cannot be loaded, then the write mode automatically switches to `Direct-Write`. See <a href='#getCacheDirectory'>Cache Directory</a>.
  - `Cache-Flush` Transactions cannot complete until all of their writes have been flushed down to disk. This policy is reliable and scales well as the number of simultaneous users increases.Transactionally safe but tends to be a lower performer than direct-write policies.
  - `Disabled` Transactions are complete as soon as their writes are cached in memory, instead of waiting for the writes to successfully reach the disk. This is the fastest policy because write requests do not block waiting to be synchronized to disk, but, unlike other policies, is not transactionally safe in the event of operating system or hardware failures. Such failures can lead to duplicate or lost data/messages. This option does not require native store `wlfileio` drivers, but may run faster when they are available. Some non-WebLogic JMS vendors default to a policy that is equivalent to `Disabled`.

 Notes:

  - When available, file stores load WebLogic `wlfileio` native drivers, which can improve performance. These drivers are included with Windows, Solaris, Linux, and AIX WebLogic installations.
  - Certain older versions of Microsoft Windows may incorrectly report storage device synchronous write completion if the Windows default `Write Cache Enabled` setting is used. This violates the transactional semantics of transactional products (not specific to Oracle), including file stores configured with a `Direct-Write` (default) or `Direct-Write-With-Cache` policy, as a system crash or power failure can lead to a loss or a duplication of records/messages. One of the visible symptoms is that this problem may manifest itself in high persistent message/transaction throughput exceeding the physical capabilities of your storage device. You can address the problem by applying a Microsoft supplied patch, disabling the Windows `Write Cache Enabled` setting, or by using a power-protected storage device. See <a href='http://support.microsoft.com/kb/281672/'>http://support.microsoft.com/kb/281672</a> and <a href='http://support.microsoft.com/kb/332023'>http://support.microsoft.com/kb/332023</a>.
  - NFS storage note:  On some operating systems, native driver memory-mapping is incompatible with NFS when files are locked. Stores with synchronous write policies `Direct-Write-With-Cache` or Disabled, and WebLogic JMS paging stores enhance performance by using the native `wlfileio` driver to perform memory-map operating system calls. When a store detects an incompatibility between NFS, file locking, and memory mapping, it automatically downgrades to conventional read/write system calls instead of memory mapping. For best performance, Oracle recommends investigating alternative NFS client drivers, configuring a non-NFS storage location, or in controlled environments and at your own risk, disabling the file locks (See <a href='#isFileLockingEnabled'>Enable File Locking)</a>. For more information, see "Tuning the WebLogic Persistent Store" in Tuning Performance of Oracle WebLogic Server.

  An example on how to use this:

        wls_file_persistence_store {a_wls_file_persistence_store :
           ...
           synchronous_write_policy => 'Direct-Write'
           ...
        }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

        wls_setting{'domain':
           ...
          extra_properties => ['wls_file_persistence_store:synchronous_write_policy']
           ...
        }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('SynchronousWritePolicy')
end
