#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_identity_asserter) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage Identity Asserters in an WebLogic domain.

    Here is an example on how you should use this:

        wls_authentication_provider { 'DefaultIdentityAsserter':
          ensure            => 'present',
          providerclassname => 'weblogic.security.providers.authentication.DefaultIdentityAsserter',
          attributes:       => 'DigestReplayDetectionEnabled;UseDefaultUserNameMapper',
          attributesvalues  => '1;1;',
          activetypes       => 'AuthenticatedUser::X.509',
          defaultmappertype => 'CN',
        }


    In this example you are managing a identity asserter in the default domain. When you want to
    manage a identity asserter in a specific domain, you can use:

        wls_authentication_provider { 'my_domain/DefaultIdentityAsserter':
          ensure            => 'present',
          providerclassname => 'weblogic.security.providers.authentication.DefaultIdentityAsserter',
          attributes:       => 'DigestReplayDetectionEnabled;UseDefaultUserNameMapper',
          attributesvalues  => '1;1;',
          activetypes       => 'AuthenticatedUser::X.509',
          defaultmappertype => 'CN',
        }


    EOD

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name} "
      environment = { 'action' => 'index', 'type' => 'wls_identity_asserter' }
      wlst template('wls_config/wls_identity_asserter/index.py.erb', binding), environment
    end

    on_create do
      Puppet.info "create #{name} "
      wlst template('wls_config/wls_identity_asserter/create.py.erb', binding)
      nil
    end

    on_modify do
      Puppet.info "modify #{name} "
      wlst template('wls_config/wls_identity_asserter/modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wlst template('wls_config/wls_identity_asserter/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :timeout
    parameter :order
    parameter :providerclassname
    parameter :attributes
    parameter :attributesvalues
    parameter :authentication_provider_name

    property :activetypes
    property :defaultmappertype

    add_title_attributes(:authentication_provider_name)
  end
end
