#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_messages_maximum, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum number of messages that can exist for an asynchronous session and that have not yet been passed to the message listener. When the Synchronous Prefetch Mode is enabled, this value also affects synchronous sessions with a message consumer that will prefetch messages in one server access.  A value of -1 indicates that there is no limit on the number of messages. In this case, however, the limit is set to the amount of remaining virtual memory.  When the number of messages reaches the MessagesMaximum value: <ul> <li>For multicast sessions, new messages are discarded according the policy specified by the <code>OverrunPolicy</code> parameter and a DataOverrunException is thrown.</li>  <li>For non-multicast sessions, new messages are flow-controlled, or retained on the server until the application can accommodate the messages.</li> </ul>  For multicast sessions, when a connection is stopped, messages will continue to be delivered, but only until the MessagesMaximum value is reached. Once this value is reached, messages will be discarded based on the Overrun policy. This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_messages_maximum => '10'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_messages_maximum']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ClientParams/%{connection_factory_name}/MessagesMaximum')
end
