#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_total_reconnect_period_millis, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum length of time, in milliseconds, that JMS clients (particularly asynchronous consumers) will continue to try to reconnect to the server after either the initial network disconnect or the last synchronous call attempt, whichever occurred most recently, before giving up retrying.   This attribute is effective only if the ReconnectPolicy attribute is set to either Producers or All. The default value of -1 means that that it will keep trying to reconnect indefinitely; a value of 0 means that there would be exactly one retry attempt.  This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_total_reconnect_period_millis => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_total_reconnect_period_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ClientParams/%{connection_factory_name}/TotalReconnectPeriodMillis')
end
