#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_default_compression_threshold, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of bytes for the serialized message body so any message exceeds this limit will trigger message compression when the message is sent or received by the JMS message producer or consumer.  The compression will occur either: <ul> <li> On the JMS message producer's JVM if the JMS message producer's JVM is not collocated with the JMS provider's JVM and the message body size exceeds the threshold limit. </li> <li> On the JMS provider's JVM when the JMS message consumer's JVM is not collocated with the JMS provider's JVM and the message body size exceeds the threshold limit. </li> </ul> 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         delivery_default_compression_threshold => '2147483647'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:delivery_default_compression_threshold']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DefaultDeliveryParams/%{connection_factory_name}/DefaultCompressionThreshold')
end
