#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_default_time_to_deliver, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The delay time, in milliseconds, between when a message is produced and when it is made visible on its destination.  All messages produced by a producer created with this factory that have a DefaultTimeToDeliver of -1 will use this value. Message producers can get the Time-to-Deliver explicitly by calling the <code> weblogic.jms.extensions.WLMessageProducer.getTimeToDeliver()</code> method.  This attribute is dynamic. It can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         delivery_default_time_to_deliver => '0'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:delivery_default_time_to_deliver']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DefaultDeliveryParams/%{connection_factory_name}/DefaultTimeToDeliver')
end
