#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:flow_interval, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
   The adjustment period of time, in seconds, when a producer adjusts its flow from the FlowMaximum number of messages to the FlowMinimum amount, or vice versa.  When a producer is flow controlled, it is slowed down from its FlowMaximum to its FlowMinimum over the specified FlowInterval amount of seconds. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         flow_interval => '60'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:flow_interval']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('FlowControlParams/%{connection_factory_name}/FlowInterval')
end
