#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:flow_one_way_send_window_size, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
   Specifies the maximum number of sent messages per window when <code>One-Way Send Mode</code> is set to allow queue senders and/or topic publishers to make one-way sends. The window size determines when a two-way message is required to regulate the producer before it can continue making additional one-way sends.  To benefit from one-way performance, the default <code>One-Way Send Window Size</code> value must be configured higher in addition to enabling one-way sends. After every <code>OneWaySendWindowSize - 1</code> number of messages, a two-way is used instead of a one-way, so all messages are actually two-way when the <code>OneWaySendWindowSize = 1</code>. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         flow_one_way_send_window_size => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:flow_one_way_send_window_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('FlowControlParams/%{connection_factory_name}/OneWaySendWindowSize')
end
