#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_attach_jmsx_user_id, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether WebLogic Server attaches the authenticated user name to sent messages.  If enabled, the system will attach the authenticated username onto sent messages if the destination supports this behavior. The username is placed in the JMSXUserID user property. You should consult the JMSXUserID documentation in Programming WebLogic JMS before using this feature.  When dynamically changed this will affect all connections made using this connection factory after the change was made. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         security_attach_jmsx_user_id => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:security_attach_jmsx_user_id']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SecurityParams/%{connection_factory_name}/AttachJMSXUserId')
end
