#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:transaction_timeout, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The timeout value (in seconds) for all transactions on connections created with this connection factory.  If a transacted session is still active after the timeout has elapsed, the transaction is rolled back. A value of 0 indicates that the default value will be used. If you have long-running transactions, you might want to adjust the value of this attribute to allow transactions to complete. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         transaction_timeout => '3600'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:transaction_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('TransactionParams/%{connection_factory_name}/TransactionTimeout')
end
