#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:untargeted, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Only relevant for deployments in resource group templates. Sub-deployments cannot have arbitrary targets if they are part of a deployment from resource group template. The sub-deployments, in such cases, may only be targeted to the virtual host of referring partition or stay untargeted. This flag, when specified with true, indicates that the sub-deployment must not be deployed in the referring partition 

  An example on how to use this:

      wls_jms_subdeployment {a_wls_jms_subdeployment :
         ...
         untargeted => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_subdeployment:untargeted']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('Untargeted')
end
