#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:override_redelivery_delay, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The delay, in milliseconds, before rolled back or recovered messages are redelivered, regardless of the RedeliveryDelay specified by the consumer and/or connection factory. Redelivered queue messages are put back into their originating destination; redelivered topic messages are put back into their originating subscription. The default value (-1) specifies that the destination will not override the RedeliveryDelay setting specified by the consumer and/or connection factory.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.  Note: Changing the RedeliveryDelay override only affects future rollbacks and recovers, it does not affect rollbacks and recovers that have already occurred.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         override_redelivery_delay => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:override_redelivery_delay']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DeliveryParamsOverrides/%{topic_name}/RedeliveryDelay')
end
