#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:override_time_to_live, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The time-to-live assigned to all messages that arrive at this destination, regardless of the TimeToLive value specified by the message producer. The default value (<tt>-1</tt>) specifies that this setting will not override the TimeToLive setting specified by the message producer.  Range of Values: Between 0 and a positive 64-bit integer.  Note: This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         override_time_to_live => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:override_time_to_live']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DeliveryParamsOverrides/%{topic_name}/TimeToLive')
end
