#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:thresholds_bytes_low, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The lower threshold (total number of bytes in this destination) that triggers logging or flow control events. The value of java.lang.Long.MAX_VALUE disables logging and flow control events for the destination.  If the number of bytes falls below this threshold, the triggered events are:  <ul> <li> Log Messages  A message is logged on the server indicating a low threshold condition. </li>  <li> Flow Control  If flow control is enabled, the destination becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt; BytesThresholdHigh  Any change to this threshold affects only incoming messages; stored messages are not affected. <!--Gets the "bytes-low" element-->

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         thresholds_bytes_low => '9223372036854775807'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:thresholds_bytes_low']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('Thresholds/%{topic_name}/BytesLow')
end
