#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:bytes_threshold_high, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The upper threshold (number of bytes stored in this JMS server) that triggers flow control and logging events. A value of <code>-1</code> disables the events for this JMS server.  The triggered events are: <ul> <li> <code>Log Messages</code> - A message is logged on the server indicating a high threshold condition. </li> <li> <code>Flow Control</code> - If flow control is enabled, the JMS server becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;= BytesThresholdLow 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         bytes_threshold_high => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:bytes_threshold_high']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('BytesThresholdHigh')
end
