#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:expiration_scan_interval, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of seconds between this JMS server's cycles of scanning local destinations for expired messages. A value of <code>0</code> disables active scanning. A very large scan interval effectively disables active scanning.  With scanning disabled, users still do not receive expired messages and any expired messages that are discovered by other system activities are removed. However, expired messages sitting in idle destinations (such as an inactive queue or disconnected durable subscriber) are not removed and continue to consume system resources.  The scanning cycle for expired messages occurs as follows: <ul> <li> After the specified waiting period, the JMS server devotes a separate thread to scan all of its local destinations for expired messages. </li> <li> After the scanning is completed, all located expired messages are processed according to the specified Expiration Policy on the destination (Discard, Log, or Redirect). </li> <li> The entire process repeats after another specified waiting period. </li> </ul>  Note: Because a new scan does not start until the current one is finished and until the specified waiting period ends, an expired message could still remain in the system for the maximum scan waiting period plus the amount of time it takes to perform the scan. 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         expiration_scan_interval => '30'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:expiration_scan_interval']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ExpirationScanInterval')
end
