#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_file_min_size, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file. The default is 500 kilobytes. After the log file reaches the specified minimum size, the next time the server checks the file size, it will rename the current log file as <code>SERVER_NAME.lognnnnn</code> and create a new one to store subsequent messages. (Requires that you specify a file rotation type of <code>Size</code>.) 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         log_file_min_size => '500'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:log_file_min_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JMSMessageLogFile/%{jmsserver_name}/FileMinSize')
end
