#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:paging_block_size, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The smallest addressable block, in bytes, of a file. When a native <code>wlfileio</code> driver is available and the paging block size has not been configured by the user, the store selects the minimum OS specific value for unbuffered (direct) I/O, if it is within the range [512, 8192]. A paging store's block size does not change once the paging store creates its files. Changes to block size only take effect for new paging stores or after the current files have been deleted. See "Tuning the Persistent Store" in Performance and Tuning for Oracle WebLogic Server. 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         paging_block_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:paging_block_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('PagingBlockSize')
end
