#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_messaging_bridge) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a messaging bridge in an WebLogic domain.

    Here is an example on how you should use this:

        wls_messaging_bridge { 'myBrigde':
          ensure                 => 'present',
          asyncenabled           => '1',
          batchinterval          => '-1',
          batchsize              => '10',
          durabilityenabled      => '1',
          idletimemax            => '60',
          qos                    => 'Exactly-once',
          reconnectdelayincrease => '5',
          reconnectdelaymax      => '60',
          reconnectdelaymin      => '15',
          selector               => 'sel',
          transactiontimeout     => '30',
          sourcedestination      => 'mySourceBrigdeDest',
          targetdestination      => 'MyDestBridgeDest',
          target                 => ['ManagedServer1', 'WebCluster'],
          targettype             => ['Server', 'Cluster'],
        }

    In this example you are managing a message bridge in the default domain. When you want to
    manage a message bridge in a specific domain, you can use:

        wls_messaging_bridge { 'my_domain/myBrigde':
          ensure                 => 'present',
          asyncenabled           => '1',
          batchinterval          => '-1',
          batchsize              => '10',
          durabilityenabled      => '1',
          idletimemax            => '60',
          qos                    => 'Exactly-once',
          reconnectdelayincrease => '5',
          reconnectdelaymax      => '60',
          reconnectdelaymin      => '15',
          selector               => 'sel',
          transactiontimeout     => '30',
          sourcedestination      => 'mySourceBrigdeDest',
          targetdestination      => 'MyDestBridgeDest',
          target                 => ['ManagedServer1', 'WebCluster'],
          targettype             => ['Server', 'Cluster'],
        }

    Check [the documentation](https://javamail.java.net/nonav/docs/api/) for valid messaging bridge properties.

    EOD

    bean_type('MessagingBridge')

    ensurable
    parameter :domain
    parameter :name
    parameter :bridge_name

    property :asyncenabled
    property :batchinterval
    property :batchsize
    property :durabilityenabled
    property :idletimemax
    property :preservemsgproperty
    property :qosdegradationallowed
    property :qos
    property :reconnectdelayincrease
    property :reconnectdelaymax
    property :reconnectdelaymin
    property :selector
    property :started
    property :transactiontimeout
    property :sourcedestination
    property :targetdestination
    property :target
    property :targettype
    extraproperties do
      property :batch_size
      property :deployment_order
      property :durability_enabled
      property :idle_time_maximum
      property :notes
      property :preserve_msg_property
      property :qos_degradation_allowed
      property :quality_of_service
      property :reconnect_delay_increase
      property :reconnect_delay_maximum
      property :reconnect_delay_minimum
      property :async_enabled
      property :batch_interval
      property :transaction_timeout
      #
      # Weblogic 12.2.1 new properties
      #
      property :distribution_policy
      property :failback_delay_seconds
      property :initial_boot_delay_seconds
      property :migration_policy
      property :number_of_restart_attempts
      property :partial_cluster_stability_delay_seconds
      property :restart_in_place
      property :seconds_between_restarts
      property :source_destination
      property :tags
      property :target_destination
    end

    add_title_attributes(:bridge_name)
  end
end
