#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:async_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies if a messaging bridge instance forwards in asynchronous messaging mode.  AsyncEnabled only applies to messaging bridge instances whose source destination supports asynchronous receiving. Messaging bridges instances that forward in asynchronous mode are driven by the source destination. A messaging bridge instance listens for messages and forwards them as they arrive. When <code>AsyncEnabled</code> is not selected, a bridge instance is forced to work in synchronous mode, even if the source supports asynchronous receiving.  Note: For a messaging bridge instance with a QOS of Exactly-once to work in asynchronous mode, the source destination has to support the <tt>MDBTransaction</tt> interface. Otherwise, the bridge automatically switches to synchronous mode if it detects that <tt>MDBTransaction</tt> is not supported by the source destination. 

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         async_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:async_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('AsyncEnabled')
end
