#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:batch_interval, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum amount of time, in milliseconds, that a messaging bridge instance waits before sending a batch of messages in one transaction, regardless of whether the <code>Batch Size</code> has been reached or not.  <ul> <li> Only applies to a messaging bridge instance forwarding messages in synchronous mode and has a QOS (quality of service) that requires two-phase transactions. </li>  <li> The default value of <tt>-1</tt> indicates that the bridge instance waits until the number of messages reaches the <code>Batch Size</code> before it completes a transaction. </li> </ul> 

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         batch_interval => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:batch_interval']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('BatchInterval')
end
