#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:reconnect_delay_minimum, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The minimum amount of time, in seconds, that a messaging bridge instance waits before it tries to reconnect to the source or target destination after a failure.

  <ul> <li> Use with <tt>ReconnectDelayMaximum</tt> and <tt>ReconnectDelayIncrease</tt>. After the first failure to connect to a destination, the bridge instance waits for the number of seconds defined by <tt>ReconnectDelayMinimum</tt>. Each time a reconnect attempt fails, the bridge instance increases its waiting time by the number of seconds defined by <tt>ReconnectDelayIncrease</tt>. The maximum delay time is defined by <tt>ReconnectDelayMaximum</tt>. Once the waiting time is increased to the maximum value, the bridge instance stops increase its waiting time. Once the bridge instance successfully connects to the destination, the bridge instance resets its waiting time to the initial value defined by <tt>ReconnectDelayMinimum</tt>. </li></ul> 

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         reconnect_delay_minimum => '15'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:reconnect_delay_minimum']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ReconnectDelayMinimum')
end
