#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:migration_policy, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Defines the type of migration policy to use for the services hosted by this migratable target. Valid options are: <ul> <li><code>Manual Service Migration Only</code> Indicates that no automatic migration of services hosted by this migratable target will occur.</li> <li><code>Auto-Migrate Exactly-Once Services</code> Indicates that if at least one Managed Server in the candidate server list is running, the services hosted by this migratable target will be active somewhere in the cluster if servers should fail or are administratively shut down (either gracefully or forcibly). For example, it is a recommended best practice to use this policy when a migratable target hosts a path service, so if its preferred server fails or is shut down, the path service will automatically migrate to another candidate server, and so will always be active in the cluster. Note This value can lead to target grouping on a server member. For example, if you have five exactly-once migratable targets and only one Managed Server is started in the cluster, then all five targets will be activated on that server.</li> <li><code>Auto-Migrate Failure-Recovery Services</code> Indicates that the services hosted by this migratable target will only start if the migratable target's User Preferred Server (UPS) is started. If an administrator manually shuts down the UPS, either gracefully or forcibly, then a failure-recovery service will not migrate. However, if the UPS fails due to an internal error, then the service will be migrated to another candidate server. If such a candidate server is unavailable (due to either a manual shutdown or an internal failure), then the migration framework will first attempt to reactivate the service on its UPS server. If the UPS server is not available at that time, then the service will be migrated to another candidate server.</li> </ul> 

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         migration_policy => 'manual'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:migration_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MigrationPolicy')
end
