#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:millis_to_sleep_between_attempts, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Controls how long of a pause there should be between the migration attempts described in getAdditionalMigrationAttempts(). Note that this delay only happens when the service has failed to come up on every server. It does not cause any sort of delay between attempts to migrate otherwise. 

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         millis_to_sleep_between_attempts => '300000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:millis_to_sleep_between_attempts']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MillisToSleepBetweenAttempts')
end
