#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_use_database_credentials, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  If enabled, Oracle database credentials are used in getConnection instead of application server credentials. The database credentials are used to get a proxy session without requiring any work in the credential mapper. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         oracle_use_database_credentials => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:oracle_use_database_credentials']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCOracleParams/%{multi_datasource_name}/UseDatabaseCredentials')
end
