#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_connection_creation_retry_frequency_seconds, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of seconds between attempts to establish connections to the database.  If you do not set this value, data source creation fails if the database is unavailable. If set and if the database is unavailable when the data source is created, WebLogic Server will attempt to create connections in the pool again after the number of seconds you specify, and will continue to attempt to create the connections until it succeeds.  When set to <code>0</code>, connection retry is disabled. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_connection_creation_retry_frequency_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_connection_creation_retry_frequency_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/ConnectionCreationRetryFrequencySeconds')
end
