#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_connection_harvest_trigger_count, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Specifies the number of available connections (trigger value) used to determine when connection harvesting occurs.

  - Harvesting occurs when the number of available connections is below the trigger value for a connection pool.
  - The range of valid values is -1 to `MaxCapacity`.
  - Default value is `-1`.
  - Setting the value to `-1` disables connection harvesting.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_connection_harvest_trigger_count => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_connection_harvest_trigger_count']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/ConnectionHarvestTriggerCount')
end
