#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_login_delay_seconds, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of seconds to delay before creating each physical database connection. This delay supports database servers that cannot handle multiple connection requests in rapid succession.  The delay takes place both during initial data source creation and during the lifetime of the data source whenever a physical database connection is created. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_login_delay_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_login_delay_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/LoginDelaySeconds')
end
