#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_statement_timeout, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The time after which a statement currently being executed will time out.  StatementTimeout relies on underlying JDBC driver support. WebLogic Server passes the time specified to the JDBC driver using the <code>java.sql.Statement.setQueryTimeout()</code> method. If your JDBC driver does not support this method, it may throw an exception and the timeout value is ignored.  A value of <code>-1</code> disables this feature. A value of <code>0</code> means that statements will not time out. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_statement_timeout => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_statement_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/StatementTimeout')
end
