#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:time_to_live_default, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Specifies the default Time-to-Live value (expiration time), in milliseconds, for imported JMS messages. The expiration time set on JMS messages will override this value unless the <code>SAF Default Time-to-Live Enabled</code> field is switched on, which then overrides the expiration time in JMS messages on imported destinations.  Any change to this value affects only incoming messages; stored messages are not affected. 

  An example on how to use this:

      wls_saf_imported_destination {a_wls_saf_imported_destination :
         ...
         time_to_live_default => '3600000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_imported_destination:time_to_live_default']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('TimeToLiveDefault')
end
