#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:bytes_maximum, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum bytes quota (total amount of bytes) that can be stored in this SAF agent.  <ul> <li> The default value of <code>-1</code> specifies that there is no WebLogic-imposed limit on the number of bytes that can be stored. However, excessive bytes volume can cause memory saturation, so this value should correspond to the total amount of available system memory relative to the rest of your application load. </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>BytesMaximum</code> affects only new requests. </li> </ul>  Range of Values: &gt;= BytesThresholdHigh 

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         bytes_maximum => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:bytes_maximum']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('BytesMaximum')
end
