#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:maximum_message_size, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum number of bytes allowed in individual messages on this SAF agent.  <ul> <li> The message size includes the message body, any user-defined properties, and the user-defined JMS header fields: <code>JMSCorrelationID</code> and <code>JMSType</code>. </li>  <li> Producers sending messages that exceed the configured maximum message size for the SAF agent will receive a <code>ResourceAllocationException</code>. </li>  <li> The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination. </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>MaximumMessageSize</code> affects only incoming messages; stored messages are not affected. </li> </ul> 

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         maximum_message_size => '2147483647'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:maximum_message_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MaximumMessageSize')
end
