#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:low_memory_gc_threshold, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The threshold level (in percent) that this server uses for logging low memory conditions and changing the server health state to <tt>Warning</tt>.  For example, if you specify 5, the server logs a low memory warning in the log file and changes the server health state to <tt>Warning</tt> after the average free memory reaches 5% of the initial free memory measured at the server's boot time. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         low_memory_gc_threshold => '5'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:low_memory_gc_threshold']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('LowMemoryGCThreshold')
end
