#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_export_key_lifespan, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Indicates the number of times WebLogic Server can use an exportable key between a domestic server and an exportable client before generating a new key. The more secure you want WebLogic Server to be, the fewer times the key should be used before generating a new key. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_export_key_lifespan => '500'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_export_key_lifespan']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('SSL/%{server_name}/ExportKeyLifespan')
end
