#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_two_way_ssl_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The form of SSL that should be used.  By default, WebLogic Server is configured to use one-way SSL (implied by the <code>Client Certs Not Requested</code> value). Selecting <code>Client Certs Requested But Not Enforced</code> enables two-way SSL. With this option, the server requests a certificate from the client, but the connection continues if the client does not present a certificate. Selecting <code>Client Certs Requested And Enforced</code> also enables two-way SSL and requires a client to present a certificate. However, if a certificate is not presented, the SSL connection is terminated. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_two_way_ssl_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_two_way_ssl_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('SSL/%{server_name}/TwoWaySSLEnabled')
end
