#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_message_size, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum message size allowable in a message header.  This maximum attempts to prevent a denial of service attack whereby a caller attempts to force the server to allocate more memory than is available thereby keeping the server from responding quickly to other requests. A client can set this value using the <code>-Dweblogic.MaxMessageSize</code> property. 

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         max_message_size => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:max_message_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MaxMessageSize')
end
