#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:outbound_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether new server-to-server connections may consider this network channel when initiating a connection. This is only relevant if the connection needs to be bound to the network channel's listen address. This will only work for binary protocols that support both outbound and inbound traffic.   When this feature is not enabled, connections are initiated using a local address selected by the underlying hardware.  The default is false.  Outbound channels are selected at runtime either by virtue of the fact of being the only outbound-enabled channel for the required protocol, or by name in <code>weblogic.jndi.Environment#setProviderChannel</code>.  The HTTP protocol is implicitly enabled for all the outbound channels, but you need to use the WLS client library (HTTP client) and set the channel on the connection.  

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         outbound_enabled => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:outbound_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('OutboundEnabled')
end
