#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_server_template) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage server templates in an WebLogic domain.

    Here is an example on how you should use this:

        wls_server_template { 'ServerTemplateWeb':
          ensure        => 'present',
          arguments     => ['-XX:PermSize=256m','-XX:MaxPermSize=256m'],
          listenport    => '9101',
          sslenabled    => '1',
          ssllistenport => '9102',
        }

    In this example you are managing a server template in the default domain. When you want to
    manage a server template in a specific domain, you can use:

        wls_server_template { 'my_domain/ServerTemplateWeb':
          ensure        => 'present',
          arguments     => ['-XX:PermSize=256m','-XX:MaxPermSize=256m'],
          listenport    => '9101',
          sslenabled    => '1',
          ssllistenport => '9102',
        }

    EOD

    bean_type('ServerTemplate')

    ensurable
    parameter :domain
    parameter :name
    parameter :template_name
    parameter :timeout

    property :ssllistenport
    property :sslenabled
    property :listenaddress
    property :listenport
    property :classpath
    property :arguments
    extraproperties do
      property :ssl_cert_authenticator
      property :ssl_ciphersuites
      property :ssl_client_certificate_enforced
      property :ssl_identity_and_trust_locations
      property :ssl_login_timeout_millis
      property :log_domain_log_broadcaster_buffer_size
      property :log_domain_log_broadcast_severity
      property :log_file_count
      property :log_file_filter
      property :log_file_min_size
      property :log_file_name
      property :log_file_rotation_dir
      property :log_file_severity
      property :log_file_time_span
      property :log_log4j_logging_enabled
      property :log_logger_severity_properties
      property :log_memory_buffer_filter
      property :log_memory_buffer_severity
      property :log_notes
      property :log_number_of_files_limited
      property :log_platform_logger_levels
      property :log_redirect_stdout_to_server_log_enabled
      property :log_rotation_type
      property :log_stdout_filter
      property :log_stdout_log_stack
      property :ssl_accept_kss_demo_certs_enabled
      property :ssl_allow_unencrypted_null_cipher
      property :ssl_client_cert_alias
      property :ssl_client_cert_private_key_pass_phrase
      property :ssl_enabled
      property :ssl_export_key_lifespan
      property :ssl_hostname_verification_ignored
      property :ssl_hostname_verifier
      property :ssl_inbound_certificate_validation
      property :ssl_jsse_enabled
      property :ssl_listen_port
      property :ssl_notes
      property :ssl_outbound_certificate_validation
      property :ssl_outbound_private_key_alias
      # property :ssl_outbound_private_key_pass_phrase
      # property :ssl_peer_validation_enforced
      property :ssl_rejection_logging_enabled
      property :ssl_server_certificate_chain_file_name
      property :ssl_server_certificate_file_name
      property :ssl_server_key_file_name
      property :ssl_server_private_key_alias
      property :ssl_server_private_key_pass_phrase
      property :ssl_trusted_ca_file_name
      property :ssl_two_way_ssl_enabled
      property :ssl_use_client_cert_for_outbound
      property :ssl_use_server_certs
      property :accept_backlog
      property :client_cert_proxy_enabled
      property :com_enabled
      property :complete_com_message_timeout
      property :extra_ejbc_options
      property :iiop_enabled
      property :jdbc_login_timeout_seconds
      property :key_stores
      property :listen_thread_start_delay_secs
      property :log_buffer_size_kb
      property :log_domain_log_broadcast_filter
      property :log_logger_severity
      property :log_memory_buffer_size
      property :log_redirect_stderr_to_server_log_enabled
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_server_logging_bridge_use_parent_loggers_enabled
      property :log_stdout_format
      property :log_stdout_severity
      property :max_message_size
      property :message_id_prefix_enabled
      property :outbound_enabled
      property :outbound_private_key_enabled
      property :administration_port
      property :administration_protocol
      property :auto_restart
      property :classpath_servlet_disabled
      property :complete_t3_message_timeout
      property :connect_timeout
      property :custom_identity_key_store_type
      property :default_iiop_user
      property :default_tgiop_password
      property :default_tgiop_user
      property :extra_rmic_options
      property :health_check_timeout_seconds
      property :java_compiler_pre_class_path
      property :jdbcllr_table_name
      property :jdbc_logging_enabled
      property :jndi_transportable_object_factory_list
      property :listeners_bind_early
      property :low_memory_gc_threshold
      property :machine
      property :max_http_message_size
      property :max_open_sock_count
      property :max_t3_message_size
      property :msi_file_replication_enabled
      property :muxer_class
      property :nm_socket_create_timeout_in_millis
      property :notes
      property :print_stack_trace_in_production
      property :reliable_delivery_policy
      property :replication_group
      property :replication_ports
      property :restart_interval_seconds
      property :socket_readers
      property :startup_timeout
      property :stuck_thread_max_time
      property :stuck_thread_timer_interval
      property :thread_pool_percent_socket_readers
      property :tunneling_client_timeout_secs
      property :use_fusion_for_llr
      property :verbose_ejb_deployment_enabled
      property :xml_entity_cache
      property :coherence_cluster_system_resource
      property :complete_write_timeout
      property :custom_trust_key_store_type
      property :java_compiler_post_class_path
      property :jta_migratable_target
      property :listen_address
      property :max_iiop_message_size
      property :restart_max
      property :scattered_reads_enabled
      property :startup_mode
      property :transaction_log_file_prefix
      property :tunneling_enabled
      property :use_concurrent_queue_for_request_manager
      property :use_enhanced_priority_queue_for_request_manager
      property :virtual_machine_name
      property :weblogic_plugin_enabled
      property :add_work_manager_threads_by_cpu_count
      property :allow_shrinking_priority_request_queue
      property :auto_migration_enabled
      property :cluster_weight
      property :custom_trust_key_store_file_name
      property :default_iiop_password
      property :default_internal_servlets_disabled
      property :default_protocol
      property :dgc_idle_periods_until_timeout
      property :graceful_shutdown_timeout
      property :health_check_interval_seconds
      property :hosts_migratable_services
      property :httpd_enabled
      property :idle_connection_timeout
      property :idle_periods_until_timeout
      property :iiop_tx_mechanism
      property :interface_address
      property :listen_port_enabled
      property :login_timeout_millis
      property :low_memory_granularity_level
      property :low_memory_sample_size
      property :managed_server_independence_enabled
      property :messaging_bridge_thread_pool_size
      property :resolve_dns_name
      property :server_version
      property :socket_buffer_size_as_chunk_size
      property :staging_directory_name
      property :tgiop_enabled
      property :use_detailed_thread_name
      property :use_enhanced_increment_advisor
      property :complete_http_message_timeout
      property :complete_iiop_message_timeout
      property :external_dns_name
      property :idle_iiop_connection_timeout
      property :instrument_stack_trace_enabled
      property :max_com_message_size
      property :period_length
      property :reverse_dns_allowed
      property :staging_mode
      property :transaction_log_file_write_policy
      property :tunneling_client_ping_secs
      property :upload_directory_name
      property :use81_style_execute_queues
      property :admin_reconnect_interval_seconds
      property :auto_kill_if_failed
      property :complete_message_timeout
      property :custom_identity_key_store_file_name
      property :custom_identity_key_store_pass_phrase
      property :custom_trust_key_store_pass_phrase
      property :default_secure_protocol
      property :health_check_start_delay_seconds
      property :http_trace_support_enabled
      property :ignore_sessions_during_shutdown
      property :java_compiler
      property :java_standard_trust_key_store_pass_phrase
      property :jms_default_connection_factories_enabled
      property :listen_delay_secs
      property :listen_port
      property :log_remote_exceptions_enabled
      property :low_memory_time_interval
      property :preferred_secondary_group
      property :restart_delay_seconds
      property :server_life_cycle_timeout_val
      property :xml_registry
      property :gathered_writes_enabled
      property :native_io_enabled
      #
      # Weblogic 12.2.1 new properties
      #
      property :buzz_address
      property :buzz_enabled
      property :buzz_port
      property :eager_thread_local_cleanup
      property :jms_connection_factory_unmapped_res_ref_mode
      property :log_date_format_pattern
      property :log_monitoring_enabled
      property :log_monitoring_interval_secs
      property :log_monitoring_throttle_message_length
      property :log_monitoring_throttle_threshold
      property :log_tags
      property :max_concurrent_long_running_requests
      property :max_concurrent_new_threads
      property :num_of_retries_before_msi_mode
      property :retry_interval_before_msi_mode
      property :ssl_minimum_tls_protocol_version
      property :ssl_ss_lv2_hello_enabled
      property :ssl_tags
      property :tags
    end

    add_title_attributes(:template_name)
  end
end
