#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:idle_iiop_connection_timeout, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The maximum number of seconds an IIOP connection is allowed to be idle before it is closed by the server. This timeout helps guard against server deadlock through too many open connections. 

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         idle_iiop_connection_timeout => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:idle_iiop_connection_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('IdleIIOPConnectionTimeout')
end
