#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:restart_delay_seconds, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  The number of seconds the Node Manager should wait before restarting this server.  After killing a server process, the system might need several seconds to release the TCP port(s) the server was using. If Node Manager attempts to restart the Managed Server while its ports are still active, the startup attempt fails.  If AutoMigration is enabled and RestartDelaySeconds is 0, the RestartDelaySeconds is automatically set to the lease time. This prevents the server from failing to restart after migration when the previous lease is still valid. 

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         restart_delay_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:restart_delay_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('RestartDelaySeconds')
end
