#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:server_life_cycle_timeout_val, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Number of seconds a force shutdown operation waits before timing out and killing itself. If the operation does not complete within the configured timeout seconds, the server will shutdown automatically if the state of the server at that time was <code>SHUTTING_DOWN</code>.  A value of <code>0</code> means that the server will wait indefinitely for life cycle operation to complete. 

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         server_life_cycle_timeout_val => '30'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:server_life_cycle_timeout_val']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ServerLifeCycleTimeoutVal')
end
