#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_server_tlog) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage server tlog in an WebLogic domain.

    Here is an example on how you should use this:

        wls_server_tlog { 'JmsWlsServer1':
          ensure                 => 'present',
          tlog_datasource        => 'tlogDS',
          tlog_datasource_prefix => 'TLOG_JmsWlsServer1_',
          tlog_enabled           => 'true',
        }

    In this example you are managing a server tlog in the default domain. When you want to
    manage a server tlog in a specific domain, you can use:

        wls_server_tlog { 'my_domain/WebServer1':
          ensure                 => 'present',
          tlog_datasource        => 'tlogDS',
          tlog_datasource_prefix => 'TLOG_WebServer1_',
          tlog_enabled           => 'true',
        }

    EOD

    bean_path('/Servers/%{server_name}/TransactionLogJDBCStore')

    ensurable
    parameter :server_name
    parameter :domain
    parameter :name

    property :tlog_enabled
    property :tlog_datasource
    property :tlog_datasource_prefix
    extraproperties do
      property :deployment_order
      property :inserts_per_batch_maximum
      property :max_retry_seconds_before_tx_exception
      property :prefix_name
      property :three_step_threshold
      property :worker_count
      property :create_table_ddl_file
      property :data_source
      property :deletes_per_batch_maximum
      property :deletes_per_statement_maximum
      property :logical_name
      property :max_retry_seconds_before_tlog_fail
      property :notes
      property :oracle_piggyback_commit_enabled
      property :retry_interval_seconds
      property :worker_preferred_batch_size
      property :enabled
      property :xa_resource_name
      #
      # Weblogic 12.2.1 new properties
      #
      property :distribution_policy
      property :failback_delay_seconds
      property :initial_boot_delay_seconds
      property :migration_policy
      property :number_of_restart_attempts
      property :partial_cluster_stability_delay_seconds
      property :reconnect_retry_interval_millis
      property :reconnect_retry_period_millis
      property :restart_in_place
      property :seconds_between_restarts
      property :tags
    end

    add_title_attributes(:server_name)
  end
end
