#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:number_of_restart_attempts, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Specifies the number of restart attempts before migrating a failed JMS artifact instance to another server in the WebLogic cluster.  <ul> <li>A value > <code>0</code> specifies the number of restart attempts before migrating a failed service instance.</li> <li>A value of <code>0</code> specifies the same behavior as setting {@link #getRestartInPlace} to <code>false</code>.</li> <li>A value of <code>-1</code> specifies the service is  never migrated. Instead, it continues to attempt to restart until it either starts or the server instance shuts down.</li> </ul> 

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         number_of_restart_attempts => '6'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:number_of_restart_attempts']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('NumberOfRestartAttempts')
end
