#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:three_step_threshold, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-EOD
  Specifies the threshold, in bytes, when the JDBC store uses 3 steps (insert, select, populate) instead of 1 step (insert) to populate an Oracle Blob data type.  Applies only to Oracle databases where a Blob data type is used instead of the default Long Raw data type for record data.  The default value is 200000. 

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         three_step_threshold => '200000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:three_step_threshold']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ThreeStepThreshold')
end
