#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_virtual_host) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
      This resource allows you to manage virtual host in an WebLogic domain.

      Here is an example on how you should use this:

          wls_virtual_host { 'WS':
            ensure             => 'present',
            channel            => 'HTTP',
            target             => ['WebCluster'],
            targettype         => ['Cluster'],
            virtual_host_names => ['admin.example.com','10.10.10.10'],
          }

      In this example you are managing a virtual host in the default domain. When you want to
      manage a virtual host in a specific domain, you can use:

          wls_virtual_host { 'my_domain/WS':
            ensure             => 'present',
            channel            => 'HTTP',
            target             => ['WebCluster'],
            targettype         => ['Cluster'],
            virtual_host_names => ['admin.example.com','10.10.10.10'],
          }

    EOD

    bean_type('VirtualHost')

    ensurable
    parameter :domain
    parameter :name
    parameter :virtual_host_name
    parameter :timeout
    property :channel
    property :target
    property :targettype
    property :virtual_host_names
    extraproperties do
      property :log_buffer_size_kb
      property :log_file_count
      property :log_file_format
      property :log_file_min_size
      property :log_file_name
      property :log_logging_enabled
      property :log_notes
      property :log_number_of_files_limited
      property :log_rotation_time
      property :log_rotation_type
      property :log_time_in_gmt
      property :accept_context_path_in_get_real_path
      property :auth_cookie_enabled
      property :charsets
      property :client_ip_header
      property :default_web_app_context_root
      property :deployment_order
      property :frontend_host
      property :frontend_https_port
      property :https_keep_alive_secs
      property :log_file_rotation_dir
      property :log_file_time_span
      property :log_rotate_log_on_startup
      property :max_post_size
      property :max_post_time_secs
      property :max_request_parameter_count
      property :network_access_point
      property :notes
      property :overload_response_code
      property :post_timeout_secs
      property :send_server_header_enabled
      property :url_resource
      property :use_header_encoding
      property :wap_enabled
      property :write_chunk_bytes
      property :chunked_transfer_disabled
      property :frontend_http_port
      property :keep_alive_enabled
      property :keep_alive_secs
      property :single_signon_disabled
      property :use_highest_compatible_http_version
      #
      # Weblogic 12.2.1 new properties
      #
      property :log_date_format_pattern
      property :log_elf_fields
      property :log_tags
      property :tags
   end

    add_title_attributes(:virtual_host_name)
  end
end
