#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:use_highest_compatible_http_version, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Enables use of the highest compatible HTTP protocol version-string in the response. E.g. HTTP spec suggests that HTTP/1.1 version-string should be used in response to a request using HTTP/1.0. This does not necessarily affect the response format. 

  An example on how to use this:

      wls_virtual_host {a_wls_virtual_host :
         ...
         use_highest_compatible_http_version => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_virtual_host:use_highest_compatible_http_version']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('UseHighestCompatibleHTTPVersion')
end
