#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ignore_stuck_threads, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether this Work Manager ignores "stuck" threads. Typically, stuck threads will cause the associated Work Manager to take some action: either switching the application to Admin mode, shutting down the server, or shutting down the Work Manager. If this flag is set, then no thread in this Work Manager is ever considered stuck.  If you do not explicitly specify IGNORE_STUCK_THREADS=TRUE, the default behavior is that upon encountering stuck threads, the server will take one of the aforementioned actions.  

  An example on how to use this:

      wls_workmanager {a_wls_workmanager :
         ...
         ignore_stuck_threads => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_workmanager:ignore_stuck_threads']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  newvalues('absent', '0', '1')

  maps_to('IgnoreStuckThreads')
end
