---
title: wls_server_template
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage server templates in an WebLogic domain.

Here is an example on how you should use this:

    wls_server_template { 'ServerTemplateWeb':
      ensure        => 'present',
      arguments     => ['-XX:PermSize=256m','-XX:MaxPermSize=256m'],
      listenport    => '9101',
      sslenabled    => '1',
      ssllistenport => '9102',
    }

In this example you are managing a server template in the default domain. When you want to
manage a server template in a specific domain, you can use:

    wls_server_template { 'my_domain/ServerTemplateWeb':
      ensure        => 'present',
      arguments     => ['-XX:PermSize=256m','-XX:MaxPermSize=256m'],
      listenport    => '9101',
      sslenabled    => '1',
      ssllistenport => '9102',
    }

## Attributes



Attribute Name                                                                                                                    | Short Description                                                                                                                                                                                                                                                                   |
--------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[accept_backlog](#wls_server_template_accept_backlog)                                                                             | The number of backlogged, new TCP connection requests that should be allowed for this server's regular and SSL ports.                                                                                                                                                               |
[add_work_manager_threads_by_cpu_count](#wls_server_template_add_work_manager_threads_by_cpu_count)                               | Enables increased efficiency of the self-tuning thread pool by aligning it with the Exalogic processor architecture threading capabilities.                                                                                                                                         |
[admin_reconnect_interval_seconds](#wls_server_template_admin_reconnect_interval_seconds)                                         | The number of seconds between reconnection attempts to the admin server.                                                                                                                                                                                                            |
[administration_port](#wls_server_template_administration_port)                                                                   | The secure administration port for the server.                                                                                                                                                                                                                                      |
[administration_protocol](#wls_server_template_administration_protocol)                                                           | Returns the protocol to be used for administrative connections when none is specified.                                                                                                                                                                                              |
[allow_shrinking_priority_request_queue](#wls_server_template_allow_shrinking_priority_request_queue)                             | Whether the self-tuning should allow shrinking of its priority based queue for pending requests after it has grown in size due to busy workload.                                                                                                                                    |
[arguments](#wls_server_template_arguments)                                                                                       | The server arguments of the server
                                                                                                                                                                                                                                                 |
[auto_kill_if_failed](#wls_server_template_auto_kill_if_failed)                                                                   | This is the equivalent of setting the OverloadProtectionMBean failureAction to "force-shutdown" and the panicAction to "system-exit".                                                                                                                                               |
[auto_migration_enabled](#wls_server_template_auto_migration_enabled)                                                             | Specifies whether Node Manager can automatically restart this server and its services on another machine if the server fails.                                                                                                                                                       |
[auto_restart](#wls_server_template_auto_restart)                                                                                 | Specifies whether the Node Manager can automatically restart this server if it crashes or otherwise goes down unexpectedly.                                                                                                                                                         |
[buzz_address](#wls_server_template_buzz_address)                                                                                 | Buzz endpoint address.                                                                                                                                                                                                                                                              |
[buzz_enabled](#wls_server_template_buzz_enabled)                                                                                 | Enables Buzz for sending/receiving messages with peers.                                                                                                                                                                                                                             |
[buzz_port](#wls_server_template_buzz_port)                                                                                       | Buzz endpoint port.                                                                                                                                                                                                                                                                 |
[classpath](#wls_server_template_classpath)                                                                                       | The classpath (path on the machine running Node Manager) to use when starting this server.                                                                                                                                                                                          |
[classpath_servlet_disabled](#wls_server_template_classpath_servlet_disabled)                                                     | The ClasspathServlet will serve any class file in the classpath and is registered by default in every Web application (including management).                                                                                                                                       |
[client_cert_proxy_enabled](#wls_server_template_client_cert_proxy_enabled)                                                       | Specifies whether the <tt>HttpClusterServlet</tt> proxies the client certificate in a special header.                                                                                                                                                                               |
[cluster_weight](#wls_server_template_cluster_weight)                                                                             | The proportion of the load that this server will bear, relative to other servers in a cluster.                                                                                                                                                                                      |
[coherence_cluster_system_resource](#wls_server_template_coherence_cluster_system_resource)                                       | The system-level Coherence cluster resource associated with this server.                                                                                                                                                                                                            |
[com_enabled](#wls_server_template_com_enabled)                                                                                   | Specifies whether COM support is enabled on the regular (non-SSL) port.                                                                                                                                                                                                             |
[complete_com_message_timeout](#wls_server_template_complete_com_message_timeout)                                                 | The maximum number of seconds spent waiting for a complete COM message to be received.                                                                                                                                                                                              |
[complete_http_message_timeout](#wls_server_template_complete_http_message_timeout)                                               | The maximum number of seconds spent waiting for a complete HTTP message to be received.                                                                                                                                                                                             |
[complete_iiop_message_timeout](#wls_server_template_complete_iiop_message_timeout)                                               | The maximum number of seconds spent waiting for a complete IIOP message to be received.                                                                                                                                                                                             |
[complete_message_timeout](#wls_server_template_complete_message_timeout)                                                         | The maximum number of seconds that this server waits for a complete message to be received.                                                                                                                                                                                         |
[complete_t3_message_timeout](#wls_server_template_complete_t3_message_timeout)                                                   | The maximum number of seconds spent waiting for a complete T3 message to be received.                                                                                                                                                                                               |
[complete_write_timeout](#wls_server_template_complete_write_timeout)                                                             | The maximum number of seconds that this server waits for a complete HTTP response to be sent.                                                                                                                                                                                       |
[connect_timeout](#wls_server_template_connect_timeout)                                                                           | The amount of time that this server should wait to establish an outbound socket connection before timing out.                                                                                                                                                                       |
[custom_identity_key_store_file_name](#wls_server_template_custom_identity_key_store_file_name)                                   | The source of the identity keystore.                                                                                                                                                                                                                                                |
[custom_identity_key_store_pass_phrase](#wls_server_template_custom_identity_key_store_pass_phrase)                               | The encrypted custom identity keystore's passphrase.                                                                                                                                                                                                                                |
[custom_identity_key_store_type](#wls_server_template_custom_identity_key_store_type)                                             | The type of the keystore.                                                                                                                                                                                                                                                           |
[custom_trust_key_store_file_name](#wls_server_template_custom_trust_key_store_file_name)                                         | The source of the custom trust keystore.                                                                                                                                                                                                                                            |
[custom_trust_key_store_pass_phrase](#wls_server_template_custom_trust_key_store_pass_phrase)                                     | The custom trust keystore's passphrase.                                                                                                                                                                                                                                             |
[custom_trust_key_store_type](#wls_server_template_custom_trust_key_store_type)                                                   | The type of the keystore.                                                                                                                                                                                                                                                           |
[default_iiop_password](#wls_server_template_default_iiop_password)                                                               | The password for the default IIOP user.                                                                                                                                                                                                                                             |
[default_iiop_user](#wls_server_template_default_iiop_user)                                                                       | The user name of the default IIOP user.                                                                                                                                                                                                                                             |
[default_internal_servlets_disabled](#wls_server_template_default_internal_servlets_disabled)                                     | Specifies whether all default servlets in the servlet engine are disabled.                                                                                                                                                                                                          |
[default_protocol](#wls_server_template_default_protocol)                                                                         | The protocol to use for connections when none is specified.                                                                                                                                                                                                                         |
[default_secure_protocol](#wls_server_template_default_secure_protocol)                                                           | The protocol to use for secure connections when none is specified.                                                                                                                                                                                                                  |
[default_tgiop_password](#wls_server_template_default_tgiop_password)                                                             | The password for the default user associated with the Tuxedo GIOP (TGIOP) protocol.                                                                                                                                                                                                 |
[default_tgiop_user](#wls_server_template_default_tgiop_user)                                                                     | The default user associated with the Tuxedo GIOP (TGIOP) protocol.                                                                                                                                                                                                                  |
[dgc_idle_periods_until_timeout](#wls_server_template_dgc_idle_periods_until_timeout)                                             | The number of idle periods allowed before object is collected.                                                                                                                                                                                                                      |
[domain](#wls_server_template_domain)                                                                                             | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                                                                             |
[eager_thread_local_cleanup](#wls_server_template_eager_thread_local_cleanup)                                                     | Specifies whether to clean up all ThreadLocals storage from self-tuning thread pool threads after they have finished processing each work request.                                                                                                                                  |
[ensure](#wls_server_template_ensure)                                                                                             | The basic property that the resource should be in.                                                                                                                                                                                                                                  |
[external_dns_name](#wls_server_template_external_dns_name)                                                                       | The external IP address or DNS name for this server.                                                                                                                                                                                                                                |
[extra_ejbc_options](#wls_server_template_extra_ejbc_options)                                                                     | The options passed to the EJB compiler during server-side generation.                                                                                                                                                                                                               |
[extra_rmic_options](#wls_server_template_extra_rmic_options)                                                                     | The options passed to the RMIC compiler during server-side generation.                                                                                                                                                                                                              |
[gathered_writes_enabled](#wls_server_template_gathered_writes_enabled)                                                           | Enables gathered writes over NIO socket channels.                                                                                                                                                                                                                                   |
[graceful_shutdown_timeout](#wls_server_template_graceful_shutdown_timeout)                                                       | Number of seconds a graceful shutdown operation waits before forcing a shut down.                                                                                                                                                                                                   |
[health_check_interval_seconds](#wls_server_template_health_check_interval_seconds)                                               | The number of seconds that defines the frequency of this server's self-health monitoring.                                                                                                                                                                                           |
[health_check_start_delay_seconds](#wls_server_template_health_check_start_delay_seconds)                                         | The number of seconds the Node Manager should wait before starting to monitor the server.                                                                                                                                                                                           |
[health_check_timeout_seconds](#wls_server_template_health_check_timeout_seconds)                                                 | The number of seconds the Node Manager should wait before timing out its health query to this server.                                                                                                                                                                               |
[hosts_migratable_services](#wls_server_template_hosts_migratable_services)                                                       | Gets the hostsMigratableServices attribute of the ServerMBean object
                                                                                                                                                                                                               |
[http_trace_support_enabled](#wls_server_template_http_trace_support_enabled)                                                     | Returns the HttpTraceSupportEnabled value
                                                                                                                                                                                                                                          |
[httpd_enabled](#wls_server_template_httpd_enabled)                                                                               | Whether or not HTTP support is enabled on the regular port or SSL port.                                                                                                                                                                                                             |
[idle_connection_timeout](#wls_server_template_idle_connection_timeout)                                                           | The maximum number of seconds that a connection is allowed to be idle before it is closed by the server.                                                                                                                                                                            |
[idle_iiop_connection_timeout](#wls_server_template_idle_iiop_connection_timeout)                                                 | The maximum number of seconds an IIOP connection is allowed to be idle before it is closed by the server.                                                                                                                                                                           |
[idle_periods_until_timeout](#wls_server_template_idle_periods_until_timeout)                                                     | The number of idle periods until peer is considered unreachable
                                                                                                                                                                                                                    |
[ignore_sessions_during_shutdown](#wls_server_template_ignore_sessions_during_shutdown)                                           | Indicates whether a graceful shutdown operation drops all HTTP sessions immediately.                                                                                                                                                                                                |
[iiop_enabled](#wls_server_template_iiop_enabled)                                                                                 | Specifies whether this server has IIOP support enabled for both the regular (non-SSL) and SSL ports.                                                                                                                                                                                |
[iiop_tx_mechanism](#wls_server_template_iiop_tx_mechanism)                                                                       | Configures IIOP propagate transactions using either WebLogic-specific JTA or the OMG-specified OTS.                                                                                                                                                                                 |
[instrument_stack_trace_enabled](#wls_server_template_instrument_stack_trace_enabled)                                             | Specifies whether the server returns stack traces for RMI calls that generate exceptions.                                                                                                                                                                                           |
[interface_address](#wls_server_template_interface_address)                                                                       | The IP address of the NIC that this server should use for multicast traffic.                                                                                                                                                                                                        |
[java_compiler](#wls_server_template_java_compiler)                                                                               | The Java compiler to use for all applications hosted on this server that need to compile Java code.                                                                                                                                                                                 |
[java_compiler_post_class_path](#wls_server_template_java_compiler_post_class_path)                                               | The options to append to the Java compiler classpath when compiling Java code.                                                                                                                                                                                                      |
[java_compiler_pre_class_path](#wls_server_template_java_compiler_pre_class_path)                                                 | The options to prepend to the Java compiler classpath when compiling Java code.                                                                                                                                                                                                     |
[java_standard_trust_key_store_pass_phrase](#wls_server_template_java_standard_trust_key_store_pass_phrase)                       | The password for the Java Standard Trust keystore.                                                                                                                                                                                                                                  |
[jdbc_logging_enabled](#wls_server_template_jdbc_logging_enabled)                                                                 | Specifies whether this server maintains a JDBC log file.                                                                                                                                                                                                                            |
[jdbc_login_timeout_seconds](#wls_server_template_jdbc_login_timeout_seconds)                                                     | The JDBC Login Timeout value.                                                                                                                                                                                                                                                       |
[jdbcllr_table_name](#wls_server_template_jdbcllr_table_name)                                                                     | The table name for this server's Logging Last Resource (LLR) database table(s).                                                                                                                                                                                                     |
[jms_connection_factory_unmapped_res_ref_mode](#wls_server_template_jms_connection_factory_unmapped_res_ref_mode)                 |  Use this unmapped resource reference mode to specify the behavior of any resource reference to a Connection Factory when the resource reference does not directly specify a JNDI name by a lookup attribute, or by a mappedName attribute, or by a jndi-name in a descriptor file. |
[jms_default_connection_factories_enabled](#wls_server_template_jms_default_connection_factories_enabled)                         | Specifies whether this server uses JMS default connection factories.                                                                                                                                                                                                                |
[jndi_transportable_object_factory_list](#wls_server_template_jndi_transportable_object_factory_list)                             | List of factories that create transportable objects.                                                                                                                                                                                                                                |
[jta_migratable_target](#wls_server_template_jta_migratable_target)                                                               | Returns the JTAMigratableTargetMBean that is used to deploy the JTA Recovery Service to (is the server's cluster is not null).                                                                                                                                                      |
[key_stores](#wls_server_template_key_stores)                                                                                     | Which configuration rules should be used for finding the server's identity and trust keystores?
                                                                                                                                                                                    |
[listen_address](#wls_server_template_listen_address)                                                                             | The IP address or DNS name this server uses to listen for incoming connections.                                                                                                                                                                                                     |
[listen_delay_secs](#wls_server_template_listen_delay_secs)                                                                       | Perpetuated for compatibility with 6.1 only.                                                                                                                                                                                                                                        |
[listen_port](#wls_server_template_listen_port)                                                                                   | The default TCP port that this server uses to listen for regular (non-SSL) incoming connections.                                                                                                                                                                                    |
[listen_port_enabled](#wls_server_template_listen_port_enabled)                                                                   | Specifies whether this server can be reached through the default plain-text (non-SSL) listen port.                                                                                                                                                                                  |
[listen_thread_start_delay_secs](#wls_server_template_listen_thread_start_delay_secs)                                             | Returns the maximum time that the server will wait for server sockets to bind before starting a listen thread.                                                                                                                                                                      |
[listenaddress](#wls_server_template_listenaddress)                                                                               | The listenaddress of the server
                                                                                                                                                                                                                                                    |
[listeners_bind_early](#wls_server_template_listeners_bind_early)                                                                 | Determines whether the server should bind server sockets early.                                                                                                                                                                                                                     |
[listenport](#wls_server_template_listenport)                                                                                     | The listenport of the server
                                                                                                                                                                                                                                                       |
[log_buffer_size_kb](#wls_server_template_log_buffer_size_kb)                                                                     | Gets the underlying log buffer size in kilobytes
                                                                                                                                                                                                                                   |
[log_date_format_pattern](#wls_server_template_log_date_format_pattern)                                                           | The date format pattern used for rendering dates in the  log.                                                                                                                                                                                                                       |
[log_domain_log_broadcast_filter](#wls_server_template_log_domain_log_broadcast_filter)                                           | The filter configuration for log events being sent to the domain log.                                                                                                                                                                                                               |
[log_domain_log_broadcast_severity](#wls_server_template_log_domain_log_broadcast_severity)                                       | The minimum severity of log messages going to the domain log from this server's log broadcaster.                                                                                                                                                                                    |
[log_domain_log_broadcaster_buffer_size](#wls_server_template_log_domain_log_broadcaster_buffer_size)                             | Broadcasts log messages to the domain log in batch mode.                                                                                                                                                                                                                            |
[log_file_count](#wls_server_template_log_file_count)                                                                             | The maximum number of log files that the server creates when it rotates the log.                                                                                                                                                                                                    |
[log_file_filter](#wls_server_template_log_file_filter)                                                                           | The filter configuration for the server log file.                                                                                                                                                                                                                                   |
[log_file_min_size](#wls_server_template_log_file_min_size)                                                                       | The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file.                                                                                                                                                                                  |
[log_file_name](#wls_server_template_log_file_name)                                                                               | The name of the file that stores current log messages.                                                                                                                                                                                                                              |
[log_file_rotation_dir](#wls_server_template_log_file_rotation_dir)                                                               | The directory where the rotated log files will be stored.                                                                                                                                                                                                                           |
[log_file_severity](#wls_server_template_log_file_severity)                                                                       | The minimum severity of log messages going to the server log file.                                                                                                                                                                                                                  |
[log_file_time_span](#wls_server_template_log_file_time_span)                                                                     | The interval (in hours) at which the server saves old log messages to another file.                                                                                                                                                                                                 |
[log_log4j_logging_enabled](#wls_server_template_log_log4j_logging_enabled)                                                       | Specifies whether the server logging is based on a Log4j implementation.                                                                                                                                                                                                            |
[log_logger_severity](#wls_server_template_log_logger_severity)                                                                   | The minimum severity of log messages going to all log destinations.                                                                                                                                                                                                                 |
[log_logger_severity_properties](#wls_server_template_log_logger_severity_properties)                                             | The configuration of the different logger severities keyed by name.                                                                                                                                                                                                                 |
[log_memory_buffer_filter](#wls_server_template_log_memory_buffer_filter)                                                         | The filter configuration for messages that are stored in the log memory buffer.                                                                                                                                                                                                     |
[log_memory_buffer_severity](#wls_server_template_log_memory_buffer_severity)                                                     | The minimum severity of log messages going to the memory buffer of recent log events.                                                                                                                                                                                               |
[log_memory_buffer_size](#wls_server_template_log_memory_buffer_size)                                                             | The size of the memory buffer that holds the last n log records.                                                                                                                                                                                                                    |
[log_monitoring_enabled](#wls_server_template_log_monitoring_enabled)                                                             | Enable or disable log monitoring.                                                                                                                                                                                                                                                   |
[log_monitoring_interval_secs](#wls_server_template_log_monitoring_interval_secs)                                                 | Timer interval in seconds to check the counts of messages logged during the interval.                                                                                                                                                                                               |
[log_monitoring_throttle_message_length](#wls_server_template_log_monitoring_throttle_message_length)                             | Cut-off length of the log message for evaluation during throttle period.                                                                                                                                                                                                            |
[log_monitoring_throttle_threshold](#wls_server_template_log_monitoring_throttle_threshold)                                       | The threshold number of messages logged during the evaluation period which enables or disables the throttling.                                                                                                                                                                      |
[log_notes](#wls_server_template_log_notes)                                                                                       | Optional information that you can include to describe this configuration.                                                                                                                                                                                                           |
[log_number_of_files_limited](#wls_server_template_log_number_of_files_limited)                                                   | Indicates whether to limit the number of log files that this server instance creates to store old messages.                                                                                                                                                                         |
[log_platform_logger_levels](#wls_server_template_log_platform_logger_levels)                                                     | Specifies the platform logger and the associated level names set through the WebLogic Server configuration.                                                                                                                                                                         |
[log_redirect_stderr_to_server_log_enabled](#wls_server_template_log_redirect_stderr_to_server_log_enabled)                       | Specifies whether the stderr of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic Logging system.                                                                                                                                                      |
[log_redirect_stdout_to_server_log_enabled](#wls_server_template_log_redirect_stdout_to_server_log_enabled)                       | Specifies whether the stdout of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic logging system.                                                                                                                                                      |
[log_remote_exceptions_enabled](#wls_server_template_log_remote_exceptions_enabled)                                               | Specifies whether the server message log includes exceptions that are raised in remote systems.                                                                                                                                                                                     |
[log_rotate_log_on_startup](#wls_server_template_log_rotate_log_on_startup)                                                       | Specifies whether a server rotates its log file during its startup cycle.                                                                                                                                                                                                           |
[log_rotation_time](#wls_server_template_log_rotation_time)                                                                       | Determines the start time (hour and minute) for a time-based rotation sequence.                                                                                                                                                                                                     |
[log_rotation_type](#wls_server_template_log_rotation_type)                                                                       | Criteria for moving old log messages to a separate file.                                                                                                                                                                                                                            |
[log_server_logging_bridge_use_parent_loggers_enabled](#wls_server_template_log_server_logging_bridge_use_parent_loggers_enabled) | Specifies whether application log messages are propagated to the parent node in the Logger tree or to the WebLogic Server log by means of the Logging Bridge.                                                                                                                       |
[log_stdout_filter](#wls_server_template_log_stdout_filter)                                                                       | The filter configuration for log events being sent to the standard out.                                                                                                                                                                                                             |
[log_stdout_format](#wls_server_template_log_stdout_format)                                                                       | The output format to use when logging to the console.                                                                                                                                                                                                                               |
[log_stdout_log_stack](#wls_server_template_log_stdout_log_stack)                                                                 | Specifies whether to dump stack traces to the console when included in logged message.                                                                                                                                                                                              |
[log_stdout_severity](#wls_server_template_log_stdout_severity)                                                                   | The minimum severity of log messages going to the standard out.                                                                                                                                                                                                                     |
[log_tags](#wls_server_template_log_tags)                                                                                         | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                        |
[login_timeout_millis](#wls_server_template_login_timeout_millis)                                                                 | The login timeout for this server's default regular (non-SSL) listen port.                                                                                                                                                                                                          |
[low_memory_gc_threshold](#wls_server_template_low_memory_gc_threshold)                                                           | The threshold level (in percent) that this server uses for logging low memory conditions and changing the server health state to <tt>Warning</tt>.                                                                                                                                  |
[low_memory_granularity_level](#wls_server_template_low_memory_granularity_level)                                                 | The granularity level (in percent) that this server uses for logging low memory conditions and changing the server health state to <tt>Warning</tt>.                                                                                                                                |
[low_memory_sample_size](#wls_server_template_low_memory_sample_size)                                                             | The number of times this server samples free memory during the time period specified by LowMemoryTimeInterval.                                                                                                                                                                      |
[low_memory_time_interval](#wls_server_template_low_memory_time_interval)                                                         | The amount of time (in seconds) that defines the interval over which this server determines average free memory values.                                                                                                                                                             |
[machine](#wls_server_template_machine)                                                                                           | The WebLogic Server host computer (machine) on which this server is meant to run.                                                                                                                                                                                                   |
[managed_server_independence_enabled](#wls_server_template_managed_server_independence_enabled)                                   | Specifies whether this Managed Server can be started when the Administration Server is unavailable.                                                                                                                                                                                 |
[max_com_message_size](#wls_server_template_max_com_message_size)                                                                 | The maximum number of bytes allowed in messages that are received over the COM protocol.                                                                                                                                                                                            |
[max_concurrent_long_running_requests](#wls_server_template_max_concurrent_long_running_requests)                                 | The maximum number of running long-running requests that can be submitted to all the Managed Executor Services or Managed Scheduled Executor Services in the server.                                                                                                                |
[max_concurrent_new_threads](#wls_server_template_max_concurrent_new_threads)                                                     | The maximum number of running threads that can be created by all the Managed Thread Factories in the server.                                                                                                                                                                        |
[max_http_message_size](#wls_server_template_max_http_message_size)                                                               | The maximum number of bytes allowed in messages that are received over the HTTP protocol.                                                                                                                                                                                           |
[max_iiop_message_size](#wls_server_template_max_iiop_message_size)                                                               | The maximum number of bytes allowed in messages that are received over the IIOP protocol.                                                                                                                                                                                           |
[max_message_size](#wls_server_template_max_message_size)                                                                         | The maximum number of bytes allowed in messages that are received over all supported protocols, unless overridden by a protocol-specific setting or a custom channel setting.                                                                                                       |
[max_open_sock_count](#wls_server_template_max_open_sock_count)                                                                   | The maximum number of open sockets allowed in server at a given point of time.                                                                                                                                                                                                      |
[max_t3_message_size](#wls_server_template_max_t3_message_size)                                                                   | The maximum number of bytes allowed in messages that are received over the T3 protocol.                                                                                                                                                                                             |
[message_id_prefix_enabled](#wls_server_template_message_id_prefix_enabled)                                                       | Indicates whether message IDs in logged messages will include a prefix.                                                                                                                                                                                                             |
[messaging_bridge_thread_pool_size](#wls_server_template_messaging_bridge_thread_pool_size)                                       | Returns the size of the messaging bridge execute thread pool.                                                                                                                                                                                                                       |
[msi_file_replication_enabled](#wls_server_template_msi_file_replication_enabled)                                                 | Specifies whether the Administration Server replicates its configuration files to this Managed Server.                                                                                                                                                                              |
[muxer_class](#wls_server_template_muxer_class)                                                                                   | Non-blocking IO is enabled by default on the server side.                                                                                                                                                                                                                           |
[name](#wls_server_template_name)                                                                                                 | The name.                                                                                                                                                                                                                                                                           |
[native_io_enabled](#wls_server_template_native_io_enabled)                                                                       | Specifies whether native I/O is enabled for the server.                                                                                                                                                                                                                             |
[nm_socket_create_timeout_in_millis](#wls_server_template_nm_socket_create_timeout_in_millis)                                     | Returns the timeout value to be used by NodeManagerRuntime when creating a a socket connection to the agent.                                                                                                                                                                        |
[notes](#wls_server_template_notes)                                                                                               | Optional information that you can include to describe this configuration.                                                                                                                                                                                                           |
[num_of_retries_before_msi_mode](#wls_server_template_num_of_retries_before_msi_mode)                                             | Get the number of retries to contact admin server, before starting in Managed Server Independence Mode
                                                                                                                                                                             |
[outbound_enabled](#wls_server_template_outbound_enabled)                                                                         | Specifies whether new server-to-server connections may consider the default server channel when initiating a connection.                                                                                                                                                            |
[outbound_private_key_enabled](#wls_server_template_outbound_private_key_enabled)                                                 | Specifies whether the SSL identity specified by {@link SSLMBean#getServerPrivateKeyAlias() getSSLMBean#ServerPrivateKeyAlias} for this server should be used for outbound SSL connections on the default server channel.                                                            |
[period_length](#wls_server_template_period_length)                                                                               | The time interval in milliseconds of the heartbeat period.                                                                                                                                                                                                                          |
[preferred_secondary_group](#wls_server_template_preferred_secondary_group)                                                       | Defines secondary clustered instances considered for hosting replicas of the primary HTTP session states created on the server.                                                                                                                                                     |
[print_stack_trace_in_production](#wls_server_template_print_stack_trace_in_production)                                           | Specifies whether the server message log includes exception stack trace that are raised in remote systems.                                                                                                                                                                          |
[provider](#wls_server_template_provider)                                                                                         | resource.                                                                                                                                                                                                                                                                           |
[reliable_delivery_policy](#wls_server_template_reliable_delivery_policy)                                                         | The reliable delivery policy for web services.                                                                                                                                                                                                                                      |
[replication_group](#wls_server_template_replication_group)                                                                       | Defines preferred clustered instances considered for hosting replicas of the primary HTTP session states created on the server.                                                                                                                                                     |
[replication_ports](#wls_server_template_replication_ports)                                                                       | When WLS is running on Exalogic machines, cluster replication traffic could go over multiple replication channels.                                                                                                                                                                  |
[resolve_dns_name](#wls_server_template_resolve_dns_name)                                                                         | Resolve the listen address to use for all T3 communication
                                                                                                                                                                                                                         |
[restart_delay_seconds](#wls_server_template_restart_delay_seconds)                                                               | The number of seconds the Node Manager should wait before restarting this server.                                                                                                                                                                                                   |
[restart_interval_seconds](#wls_server_template_restart_interval_seconds)                                                         | The number of seconds during which this server can be restarted, up to the number of times specified in RestartMax.                                                                                                                                                                 |
[restart_max](#wls_server_template_restart_max)                                                                                   | The number of times that the Node Manager can restart this server within the interval specified in RestartIntervalSeconds.                                                                                                                                                          |
[retry_interval_before_msi_mode](#wls_server_template_retry_interval_before_msi_mode)                                             | Get the number of seconds between the retries to contact admin server, before starting in Managed Server Independence Mode
                                                                                                                                                         |
[reverse_dns_allowed](#wls_server_template_reverse_dns_allowed)                                                                   | Specifies whether the kernel is allowed to perform reverse DNS lookups.                                                                                                                                                                                                             |
[scattered_reads_enabled](#wls_server_template_scattered_reads_enabled)                                                           | Enables scattered reads over NIO socket channels.                                                                                                                                                                                                                                   |
[server_life_cycle_timeout_val](#wls_server_template_server_life_cycle_timeout_val)                                               | Number of seconds a force shutdown operation waits before timing out and killing itself.                                                                                                                                                                                            |
[server_version](#wls_server_template_server_version)                                                                             | The release identifier for the server.                                                                                                                                                                                                                                              |
[socket_buffer_size_as_chunk_size](#wls_server_template_socket_buffer_size_as_chunk_size)                                         | Specifies whether the server's buffer size for sending or receiving data through a raw socket should be set to 4KB.                                                                                                                                                                 |
[socket_readers](#wls_server_template_socket_readers)                                                                             | The number of socket reader threads
                                                                                                                                                                                                                                                |
[ssl_accept_kss_demo_certs_enabled](#wls_server_template_ssl_accept_kss_demo_certs_enabled)                                       | 
                                                                                                                                                                                                                                                                                   |
[ssl_allow_unencrypted_null_cipher](#wls_server_template_ssl_allow_unencrypted_null_cipher)                                       | Test if the AllowUnEncryptedNullCipher is enabled see <code>setAllowUnencryptedNullCipher(boolean enable)</code> for the NullCipher feature.                                                                                                                                        |
[ssl_cert_authenticator](#wls_server_template_ssl_cert_authenticator)                                                             | The name of the Java class that implements the <code>weblogic.security.acl.CertAuthenticator</code> class, which is deprecated in this release of WebLogic Server.                                                                                                                  |
[ssl_ciphersuites](#wls_server_template_ssl_ciphersuites)                                                                         | Indicates the cipher suites being used on a particular WebLogic Server.                                                                                                                                                                                                             |
[ssl_client_cert_alias](#wls_server_template_ssl_client_cert_alias)                                                               | Determines the alias of the client SSL certificate to be used as identity for outbound SSL connections.                                                                                                                                                                             |
[ssl_client_cert_private_key_pass_phrase](#wls_server_template_ssl_client_cert_private_key_pass_phrase)                           | The passphrase used to retrieve the private key for the client SSL certificate specified in <code>{@link #getClientCertAlias}</code> from the server configured keystore.                                                                                                           |
[ssl_client_certificate_enforced](#wls_server_template_ssl_client_certificate_enforced)                                           | Indicates whether or not clients must present digital certificates from a trusted certificate authority to WebLogic Server.                                                                                                                                                         |
[ssl_enabled](#wls_server_template_ssl_enabled)                                                                                   | Indicates whether the server can be reached through the default SSL listen port.                                                                                                                                                                                                    |
[ssl_export_key_lifespan](#wls_server_template_ssl_export_key_lifespan)                                                           | Indicates the number of times WebLogic Server can use an exportable key between a domestic server and an exportable client before generating a new key.                                                                                                                             |
[ssl_hostname_verification_ignored](#wls_server_template_ssl_hostname_verification_ignored)                                       | Specifies whether to ignore the installed implementation of the <code>weblogic.security.SSL.HostnameVerifier</code> interface (when this server is acting as a client to another application server).                                                                               |
[ssl_hostname_verifier](#wls_server_template_ssl_hostname_verifier)                                                               | The name of the class that implements the <code>weblogic.security.SSL.HostnameVerifier</code> interface.                                                                                                                                                                            |
[ssl_identity_and_trust_locations](#wls_server_template_ssl_identity_and_trust_locations)                                         | Indicates where SSL should find the server's identity (certificate and private key) as well as the server's trust (trusted CAs).                                                                                                                                                    |
[ssl_inbound_certificate_validation](#wls_server_template_ssl_inbound_certificate_validation)                                     | Indicates the client certificate validation rules for inbound SSL.                                                                                                                                                                                                                  |
[ssl_jsse_enabled](#wls_server_template_ssl_jsse_enabled)                                                                         | Determines whether the SSL implementation in Weblogic Server is JSSE based.                                                                                                                                                                                                         |
[ssl_listen_port](#wls_server_template_ssl_listen_port)                                                                           | The TCP/IP port at which this server listens for SSL connection requests.                                                                                                                                                                                                           |
[ssl_login_timeout_millis](#wls_server_template_ssl_login_timeout_millis)                                                         | Specifies the number of milliseconds that WebLogic Server waits for an SSL connection before timing out.                                                                                                                                                                            |
[ssl_minimum_tls_protocol_version](#wls_server_template_ssl_minimum_tls_protocol_version)                                         | Get the minimum SSL/TLS protocol version currently configured.                                                                                                                                                                                                                      |
[ssl_notes](#wls_server_template_ssl_notes)                                                                                       | Optional information that you can include to describe this configuration.                                                                                                                                                                                                           |
[ssl_outbound_certificate_validation](#wls_server_template_ssl_outbound_certificate_validation)                                   | Indicates the server certificate validation rules for outbound SSL.                                                                                                                                                                                                                 |
[ssl_outbound_private_key_alias](#wls_server_template_ssl_outbound_private_key_alias)                                             | The string alias used to store and retrieve the outbound private key in the keystore.                                                                                                                                                                                               |
[ssl_rejection_logging_enabled](#wls_server_template_ssl_rejection_logging_enabled)                                               | Indicates whether warning messages are logged in the server log when SSL connections are rejected.                                                                                                                                                                                  |
[ssl_server_certificate_chain_file_name](#wls_server_template_ssl_server_certificate_chain_file_name)                             | The full directory location and name of the file containing an ordered list of certificate authorities trusted by WebLogic Server.                                                                                                                                                  |
[ssl_server_certificate_file_name](#wls_server_template_ssl_server_certificate_file_name)                                         | The full directory location of the digital certificate file (<code>.der</code> or <code>.pem</code>) for the server.                                                                                                                                                                |
[ssl_server_key_file_name](#wls_server_template_ssl_server_key_file_name)                                                         | The full directory location of the private key file (<code>.der</code> or <code>.pem</code>) for the server.                                                                                                                                                                        |
[ssl_server_private_key_alias](#wls_server_template_ssl_server_private_key_alias)                                                 | The string alias used to store and retrieve the server's private key in the keystore.                                                                                                                                                                                               |
[ssl_server_private_key_pass_phrase](#wls_server_template_ssl_server_private_key_pass_phrase)                                     | The passphrase used to retrieve the server's private key from the keystore.                                                                                                                                                                                                         |
[ssl_ss_lv2_hello_enabled](#wls_server_template_ssl_ss_lv2_hello_enabled)                                                         | Indicate whether SSLv2Hello is enabled
                                                                                                                                                                                                                                             |
[ssl_tags](#wls_server_template_ssl_tags)                                                                                         | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                        |
[ssl_trusted_ca_file_name](#wls_server_template_ssl_trusted_ca_file_name)                                                         | The full directory location of the file that specifies the certificate authorities trusted by the server.                                                                                                                                                                           |
[ssl_two_way_ssl_enabled](#wls_server_template_ssl_two_way_ssl_enabled)                                                           | The form of SSL that should be used.                                                                                                                                                                                                                                                |
[ssl_use_client_cert_for_outbound](#wls_server_template_ssl_use_client_cert_for_outbound)                                         | Determines whether to use the configured client SSL certificate as identity for outbound SSL connections.                                                                                                                                                                           |
[ssl_use_server_certs](#wls_server_template_ssl_use_server_certs)                                                                 | Sets whether the client should use the server certificates/key as the client identity when initiating an outbound connection over https.                                                                                                                                            |
[sslenabled](#wls_server_template_sslenabled)                                                                                     | The ssl enabled on the server
                                                                                                                                                                                                                                                      |
[ssllistenport](#wls_server_template_ssllistenport)                                                                               | The server ssl port
                                                                                                                                                                                                                                                                |
[staging_directory_name](#wls_server_template_staging_directory_name)                                                             | The directory path on the Managed Server where all staged (prepared) applications are placed.                                                                                                                                                                                       |
[staging_mode](#wls_server_template_staging_mode)                                                                                 | The mode that specifies whether an application's files are copied from a source on the Administration Server to the Managed Server's staging area during application preparation.                                                                                                   |
[startup_mode](#wls_server_template_startup_mode)                                                                                 | The state in which this server should be started.                                                                                                                                                                                                                                   |
[startup_timeout](#wls_server_template_startup_timeout)                                                                           | Timeout value for server start and resume operations.                                                                                                                                                                                                                               |
[stuck_thread_max_time](#wls_server_template_stuck_thread_max_time)                                                               | The number of seconds that a thread must be continually working before this server considers the thread stuck.                                                                                                                                                                      |
[stuck_thread_timer_interval](#wls_server_template_stuck_thread_timer_interval)                                                   | The number of seconds after which WebLogic Server periodically scans threads to see if they have been continually working for the configured maximum length of time.                                                                                                                |
[tags](#wls_server_template_tags)                                                                                                 | Return all tags on this Configuration MBean
                                                                                                                                                                                                                                        |
[template_name](#wls_server_template_template_name)                                                                               | The server template name
                                                                                                                                                                                                                                                           |
[tgiop_enabled](#wls_server_template_tgiop_enabled)                                                                               | Specifies whether this server supports Tuxedo GIOP (TGIOP) requests.                                                                                                                                                                                                                |
[thread_pool_percent_socket_readers](#wls_server_template_thread_pool_percent_socket_readers)                                     | The percentage of execute threads from the default queue that can be used as socket readers.                                                                                                                                                                                        |
[timeout](#wls_server_template_timeout)                                                                                           | Timeout for applying a resource.                                                                                                                                                                                                                                                    |
[transaction_log_file_prefix](#wls_server_template_transaction_log_file_prefix)                                                   | The path prefix for the server's JTA transaction log files.                                                                                                                                                                                                                         |
[transaction_log_file_write_policy](#wls_server_template_transaction_log_file_write_policy)                                       | The policy that determines how transaction log file entries are written to disk.                                                                                                                                                                                                    |
[tunneling_client_ping_secs](#wls_server_template_tunneling_client_ping_secs)                                                     | The interval (in seconds) at which to ping a tunneled client to see if it is still alive.                                                                                                                                                                                           |
[tunneling_client_timeout_secs](#wls_server_template_tunneling_client_timeout_secs)                                               | The amount of time (in seconds) after which a missing tunneled client is considered dead.                                                                                                                                                                                           |
[tunneling_enabled](#wls_server_template_tunneling_enabled)                                                                       | Specifies whether tunneling for the T3, T3S, HTTP, HTTPS, IIOP, and IIOPS protocols should be enabled for this server.                                                                                                                                                              |
[upload_directory_name](#wls_server_template_upload_directory_name)                                                               | The directory path on the Administration Server where all uploaded applications are placed.                                                                                                                                                                                         |
[use81_style_execute_queues](#wls_server_template_use81_style_execute_queues)                                                     | Backward compatibility mode to switch to 8.1 execute queues instead of WorkManagers.                                                                                                                                                                                                |
[use_concurrent_queue_for_request_manager](#wls_server_template_use_concurrent_queue_for_request_manager)                         | Reduces lock contention by using concurrent buffer queue to park incoming requests.                                                                                                                                                                                                 |
[use_detailed_thread_name](#wls_server_template_use_detailed_thread_name)                                                         | Whether to includes detail information in self-tuning thread pool thread names.                                                                                                                                                                                                     |
[use_enhanced_increment_advisor](#wls_server_template_use_enhanced_increment_advisor)                                             | Whether the self-tuning should use the enhanced IncrementAdvisor implementation that uses a different algorithm to adjust the size of the self-tuning thread pool.                                                                                                                  |
[use_enhanced_priority_queue_for_request_manager](#wls_server_template_use_enhanced_priority_queue_for_request_manager)           | Reduces lock contention by using the enhanced ConcurrentCalendarQueue as the priority based queue for pending requests that are waiting for a thread  This attribute should be enabled only in an Oracle Exalogic environment.                                                      |
[use_fusion_for_llr](#wls_server_template_use_fusion_for_llr)                                                                     | Enables the use of the <code>ADM_DDL </code> store procedure for LLR.                                                                                                                                                                                                               |
[verbose_ejb_deployment_enabled](#wls_server_template_verbose_ejb_deployment_enabled)                                             | Whether or not verbose deployment of EJBs is enabled.                                                                                                                                                                                                                               |
[virtual_machine_name](#wls_server_template_virtual_machine_name)                                                                 | When WLS is running on JRVE, this specifies the name of the virtual machine running this server
                                                                                                                                                                                    |
[weblogic_plugin_enabled](#wls_server_template_weblogic_plugin_enabled)                                                           | Specifies whether this server uses the proprietary <tt>WL-Proxy-Client-IP</tt> header, which is recommended if the server instance will receive requests from a proxy plug-in.                                                                                                      |
[xml_entity_cache](#wls_server_template_xml_entity_cache)                                                                         | The server's XML entity cache, which is used to configure the behavior of JAXP (Java API for XML Parsing).                                                                                                                                                                          |
[xml_registry](#wls_server_template_xml_registry)                                                                                 | The server's XML registry, which is used to configure the behavior of JAXP (Java API for XML Parsing).                                                                                                                                                                              |




### accept_backlog<a name='wls_server_template_accept_backlog'>

The number of backlogged, new TCP connection requests that should be allowed for this server's regular and SSL ports.  Setting the backlog to <code>0</code> may prevent this server from accepting any incoming connection on some operating systems.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       accept_backlog => '300'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:accept_backlog']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### add_work_manager_threads_by_cpu_count<a name='wls_server_template_add_work_manager_threads_by_cpu_count'>

Enables increased efficiency of the self-tuning thread pool by aligning it with the Exalogic processor architecture threading capabilities. Use only when configuring a WebLogic domain for Oracle Exalogic. <ul> <li>Enabling this attribute increases efficiency during I/O in environments with high network throughput.</li> <li>Disabling this attribute allows the thread pool to self-tune to match the demand of the workload at the expense of longer ramp up time.</li> </ul>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       add_work_manager_threads_by_cpu_count => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:add_work_manager_threads_by_cpu_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### admin_reconnect_interval_seconds<a name='wls_server_template_admin_reconnect_interval_seconds'>

The number of seconds between reconnection attempts to the admin server. When the admin server fails the managed server will periodically try to connect back to it.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       admin_reconnect_interval_seconds => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:admin_reconnect_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### administration_port<a name='wls_server_template_administration_port'>

The secure administration port for the server. This port requires that you enable the domain's administration port and that SSL is configured and enabled.  By default, the server uses the administration port that is specified at the domain level. To override the domain-level administration port for the current server instance, set this server's administration port.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       administration_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:administration_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### administration_protocol<a name='wls_server_template_administration_protocol'>

Returns the protocol to be used for administrative connections when none is specified.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       administration_protocol => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:administration_protocol']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### allow_shrinking_priority_request_queue<a name='wls_server_template_allow_shrinking_priority_request_queue'>

Whether the self-tuning should allow shrinking of its priority based queue for pending requests after it has grown in size due to busy workload. Setting this to true would help reduce memory footprint after the busy work period has ended, at the expense of the overhead of growing the request queue again at the next period of busy workload.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       allow_shrinking_priority_request_queue => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:allow_shrinking_priority_request_queue']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### arguments<a name='wls_server_template_arguments'>

The server arguments of the server


[Back to overview of wls_server_template](#attributes)


### auto_kill_if_failed<a name='wls_server_template_auto_kill_if_failed'>

This is the equivalent of setting the OverloadProtectionMBean failureAction to "force-shutdown" and the panicAction to "system-exit".

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       auto_kill_if_failed => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:auto_kill_if_failed']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### auto_migration_enabled<a name='wls_server_template_auto_migration_enabled'>

Specifies whether Node Manager can automatically restart this server and its services on another machine if the server fails.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       auto_migration_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:auto_migration_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### auto_restart<a name='wls_server_template_auto_restart'>

Specifies whether the Node Manager can automatically restart this server if it crashes or otherwise goes down unexpectedly.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       auto_restart => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:auto_restart']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### buzz_address<a name='wls_server_template_buzz_address'>

Buzz endpoint address.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       buzz_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:buzz_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### buzz_enabled<a name='wls_server_template_buzz_enabled'>

Enables Buzz for sending/receiving messages with peers. Enabling this attribute increases efficiency during I/O in environments with high network throughput and should be used only when configuring a WebLogic domain for Oracle Exalogic.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       buzz_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:buzz_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### buzz_port<a name='wls_server_template_buzz_port'>

Buzz endpoint port.  A value of <code>0</code> means system-allocated (dynamic) port.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       buzz_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:buzz_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### classpath<a name='wls_server_template_classpath'>

The classpath (path on the machine running Node Manager) to use when starting this server.
At a minimum you will need to specify the following values for the class path option: WL_HOME/server/lib/weblogic_sp.jar;WL_HOME/server/lib/weblogic.jar
where WL_HOME is the directory in which you installed WebLogic Server on the Node Manager machine.
The shell environment determines which character you use to separate path elements. On Windows, you typically use a semicolon (;). In a BASH shell, you typically use a colon (:).


[Back to overview of wls_server_template](#attributes)


### classpath_servlet_disabled<a name='wls_server_template_classpath_servlet_disabled'>

The ClasspathServlet will serve any class file in the classpath and is registered by default in every Web application (including management). It does not need to be turned on for many applications though, and represents a security hole if unchecked.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       classpath_servlet_disabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:classpath_servlet_disabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### client_cert_proxy_enabled<a name='wls_server_template_client_cert_proxy_enabled'>

Specifies whether the <tt>HttpClusterServlet</tt> proxies the client certificate in a special header.  By default (or if you specify <code>false</code>), the <code>weblogic.xml</code> deployment descriptor for each web application that is deployed on this server determines whether the web application trusts certificates sent from the proxy server plugin. By default (or if the deployment descriptor specifies <code>false</code>), users cannot log in to the web application from a proxy server plugin.  A value of <code>true</code> causes proxy-server plugins to pass identity certifications from clients to all web applications that are deployed on this server instance. A proxy-server plugin encodes each identify certification in the <code>WL-Proxy-Client-Cert</code> header and passes the header to WebLogic Server instances. A WebLogic Server instance takes the certificate information from the header, trusting that it came from a secure source, and uses that information to authenticate the user.  If you specify <code>true</code>, use a <code>weblogic.security.net.ConnectionFilter</code> to ensure that this WebLogic Server instance accepts connections only from the machine on which the proxy-server plugin is running. Specifying <code>true</code> without using a connection filter creates a security vulnerability because the <code>WL-Proxy-Client-Cert</code> header can be spoofed.  A cluster can also specify whether the <tt>HttpClusterServlet</tt> proxies the client certificate in a special header. The cluster-level setting overrides the setting in individual servers that are part of the cluster.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       client_cert_proxy_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:client_cert_proxy_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### cluster_weight<a name='wls_server_template_cluster_weight'>

The proportion of the load that this server will bear, relative to other servers in a cluster.  If all servers have the default weight or the same weight, each bears an equal proportion of the load. If one server has weight 50 and all other servers have weight 100, the 50-weight server will bear half as much load as any other server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       cluster_weight => '100'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:cluster_weight']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### coherence_cluster_system_resource<a name='wls_server_template_coherence_cluster_system_resource'>

The system-level Coherence cluster resource associated with this server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       coherence_cluster_system_resource => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:coherence_cluster_system_resource']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### com_enabled<a name='wls_server_template_com_enabled'>

Specifies whether COM support is enabled on the regular (non-SSL) port. COM is not supported on the SSL port. (The remaining fields on this page are relevant only if you check this box.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       com_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:com_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### complete_com_message_timeout<a name='wls_server_template_complete_com_message_timeout'>

The maximum number of seconds spent waiting for a complete COM message to be received. This setting does not apply to any network channels that you have configured for this server.  This timeout helps guard against a denial of service attack in which a caller indicates that they will be sending a message of a certain size which they never finish sending.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       complete_com_message_timeout => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:complete_com_message_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### complete_http_message_timeout<a name='wls_server_template_complete_http_message_timeout'>

The maximum number of seconds spent waiting for a complete HTTP message to be received. If you configure network channels for this server, each channel can override this HTTP message timeout.  This timeout helps guard against a denial of service attack in which a caller indicates that it will be sending a message of a certain size which it never finishes sending.  A value of -1 indicates that this value should be obtained from network channels configured for this server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       complete_http_message_timeout => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:complete_http_message_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### complete_iiop_message_timeout<a name='wls_server_template_complete_iiop_message_timeout'>

The maximum number of seconds spent waiting for a complete IIOP message to be received. This timeout helps guard against denial of service attacks in which a caller indicates that they will be sending a message of a certain size which they never finish sending.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       complete_iiop_message_timeout => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:complete_iiop_message_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### complete_message_timeout<a name='wls_server_template_complete_message_timeout'>

The maximum number of seconds that this server waits for a complete message to be received. If you configure network channels for this server, each channel can override this message timeout.  This timeout helps guard against a denial of service attack in which a caller indicates that it will be sending a message of a certain size which it never finishes sending.  CompleteMessageTimeout affects the HTTP Response, such that if WebLogic Server discovers sockets inactive for longer than the CompleteMessageTimeout, the server will close these sockets.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       complete_message_timeout => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:complete_message_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### complete_t3_message_timeout<a name='wls_server_template_complete_t3_message_timeout'>

The maximum number of seconds spent waiting for a complete T3 message to be received. If you configure network channels for this server, each channel can override this T3 message timeout.  This timeout helps guard against a denial of service attack in which a caller indicates that it will be sending a message of a certain size which it never finishes sending.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       complete_t3_message_timeout => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:complete_t3_message_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### complete_write_timeout<a name='wls_server_template_complete_write_timeout'>

The maximum number of seconds that this server waits for a complete HTTP response to be sent.  A value of <code>0</code> disables the complete write timeout. The default value is derived from the CompleteHTTPMessageTimeout. If it is <tt>-1</tt>, then the CompleteMessageTimeout value is used for the default value.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       complete_write_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:complete_write_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### connect_timeout<a name='wls_server_template_connect_timeout'>

The amount of time that this server should wait to establish an outbound socket connection before timing out. A value of <code>0</code> disables server connect timeout.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       connect_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:connect_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### custom_identity_key_store_file_name<a name='wls_server_template_custom_identity_key_store_file_name'>

The source of the identity keystore. For a JKS keystore, the source is the path and file name. For an Oracle Key Store Service (KSS) keystore, the source is the KSS URI.  If using a JKS keystore, the keystore path name must either be absolute or relative to where the server was booted.  If using a KSS keystore, the keystore URI must be of the form:<br/> &quot;<code>kss://system/keystorename</code>&quot;<br/> where &quot;<code>keystorename</code>&quot; is the name of the keystore registered in KSS.   The value in this attribute is only used if KeyStores is CUSTOM_IDENTITY_AND_JAVA_STANDARD_TRUST, CUSTOM_IDENTITY_AND_CUSTOM_TRUST or CUSTOM_IDENTITY_AND_COMMAND_LINE_TRUST.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       custom_identity_key_store_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:custom_identity_key_store_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### custom_identity_key_store_pass_phrase<a name='wls_server_template_custom_identity_key_store_pass_phrase'>

The encrypted custom identity keystore's passphrase. If empty or null, then the keystore will be opened without a passphrase.  This attribute is only used if KeyStores is CUSTOM_IDENTITY_AND_JAVA_STANDARD_TRUST, CUSTOM_IDENTITY_AND_CUSTOM_TRUST or CUSTOM_IDENTITY_AND_COMMAND_LINE_TRUST.  When you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>CustomIdentityKeyStorePassPhraseEncrypted</code> attribute.</li> <li>Decrypts the value and returns the unencrypted password as a String.</li> </ol>  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>CustomIdentityKeyStorePassPhraseEncrypted</code> attribute to the encrypted value.</li> </ol> Using this attribute (<code>CustomIdentityKeyStorePassPhrase</code>) is a potential security risk because the String object (which contains the unencrypted password) remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, use <code>CustomIdentityKeyStorePassPhraseEncrypted</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       custom_identity_key_store_pass_phrase => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:custom_identity_key_store_pass_phrase']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### custom_identity_key_store_type<a name='wls_server_template_custom_identity_key_store_type'>

The type of the keystore. Generally, this is <code>JKS</code>. If using the Oracle Key Store Service, this would be <code>KSS</code>  If empty or null, then the JDK's default keystore type (specified in <code>java.security</code>) is used. The custom identity key store type is only used if KeyStores is CUSTOM_IDENTITY_AND_JAVA_STANDARD_TRUST, CUSTOM_IDENTITY_AND_CUSTOM_TRUST or CUSTOM_IDENTITY_AND_COMMAND_LINE_TRUST.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       custom_identity_key_store_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:custom_identity_key_store_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### custom_trust_key_store_file_name<a name='wls_server_template_custom_trust_key_store_file_name'>

The source of the custom trust keystore. For a JKS keystore, the source is the path and file name. For an Oracle Key Store Service (KSS) keystore, the source is the KSS URI.  If using a JKS keystore, the keystore path name must either be absolute or relative to where the server was booted.  If using a KSS keystore, the keystore URI must be of the form:<br/> &quot;<code>kss://system/keystorename</code>&quot;<br/> where &quot;<code>keystorename</code>&quot; is the name of the keystore registered in KSS.   The value in this attribute is only used if KeyStores is  CUSTOM_IDENTITY_AND_CUSTOM_TRUST.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       custom_trust_key_store_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:custom_trust_key_store_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### custom_trust_key_store_pass_phrase<a name='wls_server_template_custom_trust_key_store_pass_phrase'>

The custom trust keystore's passphrase. If empty or null, then the keystore will be opened without a passphrase.  This attribute is only used if KeyStores is CUSTOM_IDENTITY_AND_CUSTOM_TRUST.  When you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>CustomTrustKeyStorePassPhraseEncrypted</code> attribute.</li> <li>Decrypts the value and returns the unencrypted password as a String.</li> </ol>  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>CustomTrustKeyStorePassPhraseEncrypted</code> attribute to the encrypted value.</li> </ol> Using this attribute (<code>CustomTrustKeyStorePassPhrase</code>) is a potential security risk because the String object (which contains the unencrypted password) remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, use <code>CustomTrustKeyStorePassPhraseEncrypted</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       custom_trust_key_store_pass_phrase => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:custom_trust_key_store_pass_phrase']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### custom_trust_key_store_type<a name='wls_server_template_custom_trust_key_store_type'>

The type of the keystore. Generally, this is <code>JKS</code>. If using the Oracle Key Store Service, this would be <code>KSS</code>  If empty or null, then the JDK's default keystore type (specified in java.security) is used. This keystore type is only used if KeyStores is CUSTOM_IDENTITY_AND_CUSTOM_TRUST.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       custom_trust_key_store_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:custom_trust_key_store_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### default_iiop_password<a name='wls_server_template_default_iiop_password'>

The password for the default IIOP user. (Requires you to enable IIOP.) As of 8.1 sp4, when you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>DefaultIIOPPasswordEncrypted</code> attribute.</li> <li>Decrypts the value and returns the unencrypted password as a String.</li> </ol>  Using this attribute (<code>DefaultIIOPPassword</code>) is a potential security risk because the String object (which contains the unencrypted password) remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, use <code>DefaultIIOPPasswordEncrypted</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_iiop_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_iiop_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### default_iiop_user<a name='wls_server_template_default_iiop_user'>

The user name of the default IIOP user. (Requires you to enable IIOP.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_iiop_user => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_iiop_user']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### default_internal_servlets_disabled<a name='wls_server_template_default_internal_servlets_disabled'>

Specifies whether all default servlets in the servlet engine are disabled.  This includes: weblogic.servlet.ClasspathServlet weblogic.servlet.utils.iiop.GetIORServlet weblogic.rjvm.http.TunnelSendServlet weblogic.rjvm.http.TunnelRecvServlet weblogic.rjvm.http.TunnelLoginServlet weblogic.rjvm.http.TunnelCloseServlet If set to true, this property overrides the ClasspathServletDisabled property.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_internal_servlets_disabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_internal_servlets_disabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### default_protocol<a name='wls_server_template_default_protocol'>

The protocol to use for connections when none is specified.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_protocol => 't3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_protocol']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### default_secure_protocol<a name='wls_server_template_default_secure_protocol'>

The protocol to use for secure connections when none is specified.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_secure_protocol => 't3s'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_secure_protocol']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### default_tgiop_password<a name='wls_server_template_default_tgiop_password'>

The password for the default user associated with the Tuxedo GIOP (TGIOP) protocol. (Requires you to configure WebLogic Tuxedo Connector (WTC) for this server.)  As of 8.1 sp4, when you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>DefaultTGIOPPasswordEncrypted</code> attribute.</li> <li>Decrypts the value and returns the unencrypted password as a String.</li> </ol> When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>DefaultTGIOPPasswordEncrypted</code> attribute to the encrypted value.</li> </ol>  Using this attribute (<code>DefaultTGIOPPassword</code>) is a potential security risk in because the String object (which contains the unencrypted password) remains the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, use <code>DefaultTGIOPPasswordEncrypted</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_tgiop_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_tgiop_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### default_tgiop_user<a name='wls_server_template_default_tgiop_user'>

The default user associated with the Tuxedo GIOP (TGIOP) protocol. (Requires you to configure WebLogic Tuxedo Connector (WTC) for this server.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       default_tgiop_user => 'guest'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:default_tgiop_user']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### dgc_idle_periods_until_timeout<a name='wls_server_template_dgc_idle_periods_until_timeout'>

The number of idle periods allowed before object is collected.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       dgc_idle_periods_until_timeout => '5'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:dgc_idle_periods_until_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### domain<a name='wls_server_template_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_server_template](#attributes)


### eager_thread_local_cleanup<a name='wls_server_template_eager_thread_local_cleanup'>

Specifies whether to clean up all ThreadLocals storage from self-tuning thread pool threads after they have finished processing each work request. By default, the self-tuning thread pool only cleans up ThreadLocal storage in its threads after an application is undeployed to avoid ClassLoader memory leak.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       eager_thread_local_cleanup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:eager_thread_local_cleanup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ensure<a name='wls_server_template_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_server_template](#attributes)


### external_dns_name<a name='wls_server_template_external_dns_name'>

The external IP address or DNS name for this server.  This address will be sent with HTTP session cookies and with dynamic server lists to HTTP proxies. It will also be used by external application clients to enable the propagation of RMI traffic through network address translating (NAT) firewalls.  You must specify an external DNS name for configurations in which a firewall is performing network address translation, unless clients are accessing WebLogic Server using t3 and the default channel. For example, define the external DNS name for configurations in which a firewall is performing network address translation, and clients are accessing WebLogic Server using HTTP via a proxy plug-in.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       external_dns_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:external_dns_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### extra_ejbc_options<a name='wls_server_template_extra_ejbc_options'>

The options passed to the EJB compiler during server-side generation.  Each EJB component can override the compiler options that you specify here. The following options are valid:  <dl> <dt>-forcegeneration</dt> <dd>Forces generation of wrapper classes. Without this flag the classes may not be regenerated if it is determined to be unnecessary.</dd>  <dt>-disableHotCodeGen</dt> <dd>Generate ejb stub and skel as part of ejbc. Avoid HotCodeGen to have better performance. </dd>  <dt>-keepgenerated</dt> <dd>Keep the generated .java files.</dd>   <dt>-compiler javac</dt> <dd>Java compiler to exec.  If not specified, the -compilerclass option will be used.</dd>  <dt>-compilerclass com.sun.tools.javac.Main</dt> <dd>Specifies the compiler class to invoke.</dd>  <dt>-g</dt> <dd>Compile debugging info into class file.</dd>  <dt>-normi</dt> <dd>Passed through to Symantec's sj.</dd>  <dt>-classpath path</dt> <dd>Classpath to use.</dd>  <dt>-source source</dt> <dd>Source version.</dd>  <dt>-Joption</dt> <dd>Flags passed through to java runtime.</dd> </dl>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       extra_ejbc_options => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:extra_ejbc_options']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### extra_rmic_options<a name='wls_server_template_extra_rmic_options'>

The options passed to the RMIC compiler during server-side generation.  Each EJB component can override the compiler options that you specify here.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       extra_rmic_options => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:extra_rmic_options']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### gathered_writes_enabled<a name='wls_server_template_gathered_writes_enabled'>

Enables gathered writes over NIO socket channels. Enabling this attribute increases efficiency during I/O in environments with high network throughput and should be used only when configuring a WebLogic domain for Oracle Exalogic.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       gathered_writes_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:gathered_writes_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### graceful_shutdown_timeout<a name='wls_server_template_graceful_shutdown_timeout'>

Number of seconds a graceful shutdown operation waits before forcing a shut down. A graceful shutdown gives WebLogic Server subsystems time to complete certain application processing currently in progress. If subsystems are unable to complete processing within the number of seconds that you specify here, then the server will force shutdown automatically.  A value of <code>0</code> means that the server will wait indefinitely for graceful shutdown to complete.  The graceful shutdown timeout applies only to graceful shutdown operations.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       graceful_shutdown_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:graceful_shutdown_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### health_check_interval_seconds<a name='wls_server_template_health_check_interval_seconds'>

The number of seconds that defines the frequency of this server's self-health monitoring. The server monitors the health of it's subsystems every HealthCheckIntervalSeconds and changes the Server's overall state if required.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       health_check_interval_seconds => '180'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:health_check_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### health_check_start_delay_seconds<a name='wls_server_template_health_check_start_delay_seconds'>

The number of seconds the Node Manager should wait before starting to monitor the server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       health_check_start_delay_seconds => '120'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:health_check_start_delay_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### health_check_timeout_seconds<a name='wls_server_template_health_check_timeout_seconds'>

The number of seconds the Node Manager should wait before timing out its health query to this server.  If the timeout is reached, Node Managed assumes the Managed Server has failed.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       health_check_timeout_seconds => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:health_check_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### hosts_migratable_services<a name='wls_server_template_hosts_migratable_services'>

Gets the hostsMigratableServices attribute of the ServerMBean object

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       hosts_migratable_services => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:hosts_migratable_services']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### http_trace_support_enabled<a name='wls_server_template_http_trace_support_enabled'>

Returns the HttpTraceSupportEnabled value

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       http_trace_support_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:http_trace_support_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### httpd_enabled<a name='wls_server_template_httpd_enabled'>

Whether or not HTTP support is enabled on the regular port or SSL port.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       httpd_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:httpd_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### idle_connection_timeout<a name='wls_server_template_idle_connection_timeout'>

The maximum number of seconds that a connection is allowed to be idle before it is closed by the server. The T3 and T3S protocols ignore this attribute. If you configure network channels for this server, each channel can override this idle connection message timeout.  This timeout helps guard against server deadlock through too many open connections.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       idle_connection_timeout => '65'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:idle_connection_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### idle_iiop_connection_timeout<a name='wls_server_template_idle_iiop_connection_timeout'>

The maximum number of seconds an IIOP connection is allowed to be idle before it is closed by the server. This timeout helps guard against server deadlock through too many open connections.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       idle_iiop_connection_timeout => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:idle_iiop_connection_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### idle_periods_until_timeout<a name='wls_server_template_idle_periods_until_timeout'>

The number of idle periods until peer is considered unreachable

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       idle_periods_until_timeout => '4'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:idle_periods_until_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ignore_sessions_during_shutdown<a name='wls_server_template_ignore_sessions_during_shutdown'>

Indicates whether a graceful shutdown operation drops all HTTP sessions immediately. If this is set to <code>false</code>, a graceful shutdown operation waits for HTTP sessions to complete or timeout.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ignore_sessions_during_shutdown => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ignore_sessions_during_shutdown']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### iiop_enabled<a name='wls_server_template_iiop_enabled'>

Specifies whether this server has IIOP support enabled for both the regular (non-SSL) and SSL ports.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       iiop_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:iiop_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### iiop_tx_mechanism<a name='wls_server_template_iiop_tx_mechanism'>

Configures IIOP propagate transactions using either WebLogic-specific JTA or the OMG-specified OTS.  It is not possible to use both because it affects the way transactions are negotiated.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       iiop_tx_mechanism => 'ots'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:iiop_tx_mechanism']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### instrument_stack_trace_enabled<a name='wls_server_template_instrument_stack_trace_enabled'>

Specifies whether the server returns stack traces for RMI calls that generate exceptions.  With RMI stack tracking enabled, if a client issues an RMI call to a server subsystem or to a module running within the server, and if the subsystem or module generates an exception that includes a stack trace, the server will return the exception as well as the stack trace. With it disabled, the server will return the exception without the stack trace details.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       instrument_stack_trace_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:instrument_stack_trace_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### interface_address<a name='wls_server_template_interface_address'>

The IP address of the NIC that this server should use for multicast traffic.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       interface_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:interface_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### java_compiler<a name='wls_server_template_java_compiler'>

The Java compiler to use for all applications hosted on this server that need to compile Java code.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       java_compiler => 'javac'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:java_compiler']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### java_compiler_post_class_path<a name='wls_server_template_java_compiler_post_class_path'>

The options to append to the Java compiler classpath when compiling Java code.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       java_compiler_post_class_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:java_compiler_post_class_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### java_compiler_pre_class_path<a name='wls_server_template_java_compiler_pre_class_path'>

The options to prepend to the Java compiler classpath when compiling Java code.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       java_compiler_pre_class_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:java_compiler_pre_class_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### java_standard_trust_key_store_pass_phrase<a name='wls_server_template_java_standard_trust_key_store_pass_phrase'>

The password for the Java Standard Trust keystore. This password is defined when the keystore is created. If empty or null, then the keystore will be opened without a passphrase.  This attribute is only used if KeyStores is CUSTOM_IDENTITY_AND_JAVA_STANDARD_TRUST or DEMO_IDENTITY_AND_DEMO_TRUST.  When you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>JavaStandardTrustKeyStorePassPhraseEncrypted</code> attribute.</li> <li>Decrypts the value and returns the unencrypted password as a String.</li> </ol>  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>JavaStandardTrustKeyStorePassPhraseEncrypted</code> attribute to the encrypted value.</li> </ol> Using this attribute (<code>JavaStandardTrustKeyStorePassPhrase</code>) is a potential security risk because the String object (which contains the unencrypted password) remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, use <code>JavaStandardTrustKeyStorePassPhraseEncrypted</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       java_standard_trust_key_store_pass_phrase => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:java_standard_trust_key_store_pass_phrase']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### jdbc_logging_enabled<a name='wls_server_template_jdbc_logging_enabled'>

Specifies whether this server maintains a JDBC log file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jdbc_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jdbc_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### jdbc_login_timeout_seconds<a name='wls_server_template_jdbc_login_timeout_seconds'>

The JDBC Login Timeout value. Specified value is passed into java.sql.DriverManager.setLoginTimeout(). Note that this DriverManager setting will impact *all* JDBC drivers loaded into this JVM. Feature is disabled by default.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jdbc_login_timeout_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jdbc_login_timeout_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### jdbcllr_table_name<a name='wls_server_template_jdbcllr_table_name'>

The table name for this server's Logging Last Resource (LLR) database table(s). WebLogic Server creates the table(s) and then uses them during transaction processing for the LLR transaction optimization. This setting must be unique for each server. The default table name is <code>WL_LLR_SERVERNAME</code>.  This setting only applies if this server hosts one or more LLR-enabled JDBC data sources.  The format for the tables that WebLogic Server creates is [[[catalog.]schema.]name.] Each "." in the table name is significant, and schema generally corresponds to username in many databases.  IMPORTANT: If this value is changed but the LLR table already exists in the database, you must preserve the existing table's data. Consequently, when changing the table name, the existing database table must be renamed by a database administrator to match the new configured table name. Otherwise, transaction records may be lost, resulting in heuristic failures that aren't logged.  IMPORTANT: Each server's table name must be unique. Multiple LLR-enabled data sources within the same server may share the same table, but multiple servers must not share the same table. If multiple same-named servers share a table, the behavior is undefined and it is likely that transactions will not recover properly after a crash, creating heuristic hazards.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jdbcllr_table_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jdbcllr_table_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### jms_connection_factory_unmapped_res_ref_mode<a name='wls_server_template_jms_connection_factory_unmapped_res_ref_mode'>

 Use this unmapped resource reference mode to specify the behavior of any resource reference to a Connection Factory when the resource reference does not directly specify a JNDI name by a lookup attribute, or by a mappedName attribute, or by a jndi-name in a descriptor file. If a JNDI name is specified, the resource reference either resolves to the specified object in the JNDI tree or generates a javax.naming.NameNotFoundException.    Following are the available unmapped resource reference modes:  <ul> <li> <code>FailSafe :</code> In this mode, an application JMS connection factory resource reference that does not specify a JNDI name resolves to an object bound to the JNDI tree with the same name as the resource reference name if one can be found in JNDI tree. Otherwise, it throws a javax.naming.NameNotFoundException. A resource reference without a JNDI name never returns a Java EE 7 Default Connection Factory in this mode.  This mode yields pre-12.2.1 WebLogic Server behavior. This mode is Java EE compliant, but the Java EE 7 specification disallows it from being the default mode.  </li> </ul>   <ul> <li> <code>ReturnDefault :</code> This policy is a Java EE compliant mode and it is the default mode. It complies with Java EE 7 while doing a best effort to try delivering FailSafe behavior when it is expected.  (a) If the resource reference name matches the local JNDI name of a configured foreign JMS provider mapping, then WebLogic Server returns the remote JNDI entry from the mapping if it can be resolved, or it throws a javax.naming.NameNotFoundException.   (b) If the resource reference does not match with a foreign JMS provider mapping, and if the resource reference name matches the name of an object that is already bound to the JNDI tree, WebLogic Server returns the JNDI tree object.   (c) If neither (a) nor (b) apply, then WebLogic Server returns "java:comp/DefaultJMSConnectionFactory". In addition, it adds an 'Info' message in the server log indicating that a special behavior has occurred. This log message will occur at most once per application per server boot.  </li> </ul>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jms_connection_factory_unmapped_res_ref_mode => 'ReturnDefault'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jms_connection_factory_unmapped_res_ref_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### jms_default_connection_factories_enabled<a name='wls_server_template_jms_default_connection_factories_enabled'>

Specifies whether this server uses JMS default connection factories.  WebLogic Server provides the following JMS default connection factories:  <ul> <li> <code>weblogic.jms.ConnectionFactory</code> </li>  <li> <code>weblogic.jms.XAConnectionFactory</code> An XA factory is required for JMS applications to use JTA user-transactions, but is not required for transacted sessions. All other preconfigured attributes for the default connection factories are set to the same default values as a user-defined connection factory. If the preconfigured settings of the default factories are appropriate for your application, you do not need to configure any additional factories for your application. </li> </ul>  Note: When using the default connection factories, you have no control over targeting the WebLogic Server instances where the connection factory may be deployed. However, you can disable the default connection factories on a per-server basis. To deploy a connection factory on independent servers, on specific servers within a cluster, or on an entire cluster, you need to configure a connection factory and specify the appropriate server targets.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jms_default_connection_factories_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jms_default_connection_factories_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### jndi_transportable_object_factory_list<a name='wls_server_template_jndi_transportable_object_factory_list'>

List of factories that create transportable objects.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jndi_transportable_object_factory_list => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jndi_transportable_object_factory_list']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### jta_migratable_target<a name='wls_server_template_jta_migratable_target'>

Returns the JTAMigratableTargetMBean that is used to deploy the JTA Recovery Service to (is the server's cluster is not null).

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       jta_migratable_target => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:jta_migratable_target']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### key_stores<a name='wls_server_template_key_stores'>

Which configuration rules should be used for finding the server's identity and trust keystores?

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       key_stores => 'DemoIdentityAndDemoTrust'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:key_stores']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### listen_address<a name='wls_server_template_listen_address'>

The IP address or DNS name this server uses to listen for incoming connections.  Servers can be reached through the following URL:<br> protocol://listen-address:listen-port  Any network channel that you configure for this server can override this listen address.  If a server's listen address is undefined, clients can reach the server through an IP address of the computer that hosts the server, a DNS name that resolves to the host, or the localhost string. The localhost string can be used only for requests from clients that are running on the same computer as the server.  If you want to limit the valid addresses for a server instance, specify one of the following:  <ul> <li> IP address. If you provide an IP address, clients can specify either the IP address or a DNS name that maps to the IP address. Clients that specify an IP address and attempt to connect through an SSL port must disable hostname verification. </li>  <li> DNS name. If you provide a DNS name, clients can specify either the DNS name or the corresponding IP address. </li> </ul>  Do not leave the listen address undefined on a computer that uses multiple IP address (a multihomed computer). On such a computer, the server will bind to all available IP addresses.  <dl> <dt>Notes:</dt>  <dd> To resolve a DNS name to an IP address, WebLogic Server must be able to contact an appropriate DNS server or obtain the IP address mapping locally. Therefore, if you specify a DNS name for the listen address, you must either leave a port open long enough for the WebLogic Server instance to connect to a DNS server and cache its mapping or you must specify the IP address mapping in a local file. If you specify an IP address for ListenAddress and then a client request specifies a DNS name, WebLogic Server will attempt to resolve the DNS name, but if it cannot access DNS name mapping, the request fails. Note also that if you are using the demo certificates in a multi-server domain, Managed Server instances will fail to boot if you specify the fully-qualified DNS name. For information about this limitation and suggested workarounds, see "Limitation on CertGen Usage" in Administering Security for Oracle WebLogic Server. </dd> </dl>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       listen_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:listen_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### listen_delay_secs<a name='wls_server_template_listen_delay_secs'>

Perpetuated for compatibility with 6.1 only.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       listen_delay_secs => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:listen_delay_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### listen_port<a name='wls_server_template_listen_port'>

The default TCP port that this server uses to listen for regular (non-SSL) incoming connections.  Administrators must have the right privileges before binding to a port or else this operation will not be successful and it will render the console un-reachable.  If this port is disabled, the SSL port must be enabled. Additional ports can be configured using network channels. The cluster (multicast) port is configured separately.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       listen_port => '7001'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### listen_port_enabled<a name='wls_server_template_listen_port_enabled'>

Specifies whether this server can be reached through the default plain-text (non-SSL) listen port.  If you disable this listen port, you must enable the default SSL listen port.  You can define additional listen ports for this server by configuring network channels.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       listen_port_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:listen_port_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### listen_thread_start_delay_secs<a name='wls_server_template_listen_thread_start_delay_secs'>

Returns the maximum time that the server will wait for server sockets to bind before starting a listen thread.  Properties to consider for removal

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       listen_thread_start_delay_secs => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:listen_thread_start_delay_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### listenaddress<a name='wls_server_template_listenaddress'>

The listenaddress of the server


[Back to overview of wls_server_template](#attributes)


### listeners_bind_early<a name='wls_server_template_listeners_bind_early'>

Determines whether the server should bind server sockets early. Early binding detects port conflicts quickly and also gives user feedback on the default listen port as to the server state.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       listeners_bind_early => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:listeners_bind_early']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### listenport<a name='wls_server_template_listenport'>

The listenport of the server


[Back to overview of wls_server_template](#attributes)


### log_buffer_size_kb<a name='wls_server_template_log_buffer_size_kb'>

Gets the underlying log buffer size in kilobytes

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_buffer_size_kb => '8'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_buffer_size_kb']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_date_format_pattern<a name='wls_server_template_log_date_format_pattern'>

The date format pattern used for rendering dates in the  log. The DateFormatPattern string conforms to the specification of the <code>java.text.SimpleDateFormat</code> class.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_date_format_pattern => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_date_format_pattern']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_domain_log_broadcast_filter<a name='wls_server_template_log_domain_log_broadcast_filter'>

The filter configuration for log events being sent to the domain log.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_domain_log_broadcast_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_domain_log_broadcast_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_domain_log_broadcast_severity<a name='wls_server_template_log_domain_log_broadcast_severity'>

The minimum severity of log messages going to the domain log from this server's log broadcaster. Messages with a lower severity than the specified value will not be published to the domain log.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_domain_log_broadcast_severity => 'Notice'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_domain_log_broadcast_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_domain_log_broadcaster_buffer_size<a name='wls_server_template_log_domain_log_broadcaster_buffer_size'>

Broadcasts log messages to the domain log in batch mode.  The size of the buffer for log messages that are sent to the domain log. The buffer is maintained on the Managed Server and is broadcasted to the domain log when it is full.  If you notice performance issues due to a high rate of log messages being generated, set this value higher. This will cause the buffer to be broadcasted less frequently from the Managed Server to the domain log. In production environments, it is not recommended to set the buffer size lower than the production default of 10.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_domain_log_broadcaster_buffer_size => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_domain_log_broadcaster_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_count<a name='wls_server_template_log_file_count'>

The maximum number of log files that the server creates when it rotates the log. This number does not include the file that the server uses to store current messages. (Requires that you enable Number of Files Limited.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_count => '7'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_filter<a name='wls_server_template_log_file_filter'>

The filter configuration for the server log file.  A filter configuration defines simple filtering rules to limit the volume of log messages written to the log file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_min_size<a name='wls_server_template_log_file_min_size'>

The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file. The default is 500 kilobytes. After the log file reaches the specified minimum size, the next time the server checks the file size, it will rename the current log file as <code>SERVER_NAME.lognnnnn</code> and create a new one to store subsequent messages. (Requires that you specify a file rotation type of <code>Size</code>.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_min_size => '500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_min_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_name<a name='wls_server_template_log_file_name'>

The name of the file that stores current log messages. Usually it is a computed value based on the name of the parent of this MBean. For example, for a server log, it is <code>SERVER_NAME.log</code>.  However, if the name of the parent cannot be obtained, the file name is <code>weblogic.log</code>. If you specify a relative pathname, it is interpreted as relative to the server's root directory.  To include a time and date stamp in the file name when the log file is rotated, add <code>java.text.SimpleDateFormat</code> variables to the file name. Surround each variable with percentage (<code>%</code>) characters.  For example, if the file name is defined to be <code>myserver_%yyyy%_%MM%_%dd%_%hh%_%mm%.log</code>, the log file will be named <code>myserver_yyyy_mm_dd_hh_mm.log</code>.  When the log file is rotated, the rotated file name contains the date stamp. For example, if the log file is rotated for the first time on 2 April, 2003 at 10:05 AM, the log file that contains the old messages will be named <code>myserver_2003_04_02_10_05.log00001</code>.  If you do not include a time and date stamp, the rotated log files are numbered in order of creation. For example, <code>myserver.log00007</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_rotation_dir<a name='wls_server_template_log_file_rotation_dir'>

The directory where the rotated log files will be stored. By default the rotated files are stored in the same directory where the log file is stored.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_rotation_dir => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_rotation_dir']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_severity<a name='wls_server_template_log_file_severity'>

The minimum severity of log messages going to the server log file. By default all messages go to the log file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_severity => 'Trace'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_file_time_span<a name='wls_server_template_log_file_time_span'>

The interval (in hours) at which the server saves old log messages to another file. (Requires that you specify a file rotation type of <code>TIME</code>.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_file_time_span => '24'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_file_time_span']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_log4j_logging_enabled<a name='wls_server_template_log_log4j_logging_enabled'>

Specifies whether the server logging is based on a Log4j implementation. By default, WebLogic logging uses an implementation based on the Java Logging APIs which are part of the JDK.  Applications that use the WebLogic Message Catalog framework or the NonCatalogLogger will not be affected by the underlying Logging implementation.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_log4j_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_log4j_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_logger_severity<a name='wls_server_template_log_logger_severity'>

The minimum severity of log messages going to all log destinations. By default all messages are published.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_logger_severity => 'Info'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_logger_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_logger_severity_properties<a name='wls_server_template_log_logger_severity_properties'>

The configuration of the different logger severities keyed by name. The values are one of the predefined Severity strings namely Emergency, Alert, Critical, Error, Warning, Notice, Info, Debug, Trace.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_logger_severity_properties => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_logger_severity_properties']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_memory_buffer_filter<a name='wls_server_template_log_memory_buffer_filter'>

The filter configuration for messages that are stored in the log memory buffer. By default, all log messages are cached.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_memory_buffer_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_memory_buffer_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_memory_buffer_severity<a name='wls_server_template_log_memory_buffer_severity'>

The minimum severity of log messages going to the memory buffer of recent log events. Messages with a lower severity than the specified value will not be cached in the buffer.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_memory_buffer_severity => 'Trace'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_memory_buffer_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_memory_buffer_size<a name='wls_server_template_log_memory_buffer_size'>

The size of the memory buffer that holds the last n log records. This is used to support viewing the most recent log record entries (tail viewing) from the WebLogic Administration Console.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_memory_buffer_size => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_memory_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_monitoring_enabled<a name='wls_server_template_log_monitoring_enabled'>

Enable or disable log monitoring.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_monitoring_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_monitoring_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_monitoring_interval_secs<a name='wls_server_template_log_monitoring_interval_secs'>

Timer interval in seconds to check the counts of messages logged during the interval.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_monitoring_interval_secs => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_monitoring_interval_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_monitoring_throttle_message_length<a name='wls_server_template_log_monitoring_throttle_message_length'>

Cut-off length of the log message for evaluation during throttle period. The log message length is truncated to this length for evaluation of repeated logging events.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_monitoring_throttle_message_length => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_monitoring_throttle_message_length']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_monitoring_throttle_threshold<a name='wls_server_template_log_monitoring_throttle_threshold'>

The threshold number of messages logged during the evaluation period which enables or disables the throttling.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_monitoring_throttle_threshold => '1500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_monitoring_throttle_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_notes<a name='wls_server_template_log_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_number_of_files_limited<a name='wls_server_template_log_number_of_files_limited'>

Indicates whether to limit the number of log files that this server instance creates to store old messages. (Requires that you specify a file rotation type of <code>SIZE</code> or <code>TIME</code>.)  After the server reaches this limit, it deletes the oldest log file and creates a new log file with the latest suffix.  If you do not enable this option, the server creates new files indefinitely and you must clean up these files as you require.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_number_of_files_limited => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_number_of_files_limited']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_platform_logger_levels<a name='wls_server_template_log_platform_logger_levels'>

Specifies the platform logger and the associated level names set through the WebLogic Server configuration.  Note the following behavior: <ul> <li>The configuration is applicable for <code>java.util.logging.Logger</code> instances in the JDK's default global LogManager.</li> <li>WebLogic Server loggers are configured in terms of <code>weblogic.logging.Severities</code> through the <code>LoggerSeverities</code> attribute. These loggers are not available in the JDK's default global LogManager.</li> </ul>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_platform_logger_levels => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_platform_logger_levels']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_redirect_stderr_to_server_log_enabled<a name='wls_server_template_log_redirect_stderr_to_server_log_enabled'>

Specifies whether the stderr of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic Logging system. When this attribute is enabled, the stderr content is published to all the registered log destinations, such as the server terminal console and log file.  Note that JVM messages are redirected asynchronously. In the event of an overload situation, these messages may be dropped. As a best practice, Oracle recommends using one of the supported logging APIs instead.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_redirect_stderr_to_server_log_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_redirect_stderr_to_server_log_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_redirect_stdout_to_server_log_enabled<a name='wls_server_template_log_redirect_stdout_to_server_log_enabled'>

Specifies whether the stdout of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic logging system. When this attribute is enabled, the stdout content is published to all the registered log destinations, such as the server terminal console and log file.  Note that JVM messages are redirected asynchronously. In the event of an overload situation, these messages may be dropped. As a best practice, Oracle recommends using one of the supported logging APIs instead.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_redirect_stdout_to_server_log_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_redirect_stdout_to_server_log_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_remote_exceptions_enabled<a name='wls_server_template_log_remote_exceptions_enabled'>

Specifies whether the server message log includes exceptions that are raised in remote systems.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_remote_exceptions_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_remote_exceptions_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_rotate_log_on_startup<a name='wls_server_template_log_rotate_log_on_startup'>

Specifies whether a server rotates its log file during its startup cycle. The default value in production mode is false.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_rotate_log_on_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_rotate_log_on_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_rotation_time<a name='wls_server_template_log_rotation_time'>

Determines the start time (hour and minute) for a time-based rotation sequence.  At the time that this value specifies, the server renames the current log file. Thereafter, the server renames the log file at an interval that you specify in File Time Span.  Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.   Use the following format: <code>H:mm</code>, where <ul><li><code>H</code> is Hour in day (0-23). <li><code>mm</code> is the minute in hour </ul>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_rotation_time => '00:00'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_rotation_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_rotation_type<a name='wls_server_template_log_rotation_type'>

Criteria for moving old log messages to a separate file. <ul> <li><code>NONE</code> Messages accumulate in a single file. You must erase the contents of the file when the size is too large. Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.  <li><code>SIZE</code> When the log file reaches the size that you specify in <code>FileMinSize</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>.  <li><code>TIME</code> At each time interval that you specify in <code>TimeSpan</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>. </ul>  After the server renames a file, subsequent messages accumulate in a new file with the name that you specified as the log file name.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_rotation_type => 'bySize'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_rotation_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_server_logging_bridge_use_parent_loggers_enabled<a name='wls_server_template_log_server_logging_bridge_use_parent_loggers_enabled'>

Specifies whether application log messages are propagated to the parent node in the Logger tree or to the WebLogic Server log by means of the Logging Bridge. By default, this attribute is disabled, which results in application log messages being propagated to the WebLogic Server log.  Note the following behavior: <ul> <li>If WebLogic Server is configured to be based upon the the Java Logging API (the default), the Logging Bridge is made available as a <code>java.util.logging.Handler</code> object.</li> <li>If  WebLogic Server is configured to be based upon a Log4j implementation, the Logging Bridge is made available as a <code>org.apache.log4j.Appender</code> object.</li> <li>If the <code>ServerLoggingBridgeUseParentLoggersEnabled</code> is disabled, applications that use either the Java Logging API or Log4j have their log messages redirected by the Logging Bridge to the WebLogic Server log. <li>If the <code>ServerLoggingBridgeUseParentLoggersEnabled</code> is enabled, applications that use the Java Logging API have their log messages propagated to the parent node in the global Java Logging Logger tree.</li> <li>If the <code>ServerLoggingBridgeUseParentLoggersEnabled</code> is enabled, applications that use Log4j have their log messages propagated to the parent node in the Log4j Logger tree.</li> </ul>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_server_logging_bridge_use_parent_loggers_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_server_logging_bridge_use_parent_loggers_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_stdout_filter<a name='wls_server_template_log_stdout_filter'>

The filter configuration for log events being sent to the standard out.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_stdout_filter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_stdout_filter']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_stdout_format<a name='wls_server_template_log_stdout_format'>

The output format to use when logging to the console.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_stdout_format => 'standard'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_stdout_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_stdout_log_stack<a name='wls_server_template_log_stdout_log_stack'>

Specifies whether to dump stack traces to the console when included in logged message.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_stdout_log_stack => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_stdout_log_stack']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### log_stdout_severity<a name='wls_server_template_log_stdout_severity'>

The minimum severity of log messages going to the standard out. Messages with a lower severity than the specified value will not be published to standard out.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_stdout_severity => 'Notice'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_stdout_severity']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### log_tags<a name='wls_server_template_log_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       log_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:log_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### login_timeout_millis<a name='wls_server_template_login_timeout_millis'>

The login timeout for this server's default regular (non-SSL) listen port. This is the maximum amount of time allowed for a new connection to establish.  A value of <code>0</code> indicates there is no maximum.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       login_timeout_millis => '5000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:login_timeout_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### low_memory_gc_threshold<a name='wls_server_template_low_memory_gc_threshold'>

The threshold level (in percent) that this server uses for logging low memory conditions and changing the server health state to <tt>Warning</tt>.  For example, if you specify 5, the server logs a low memory warning in the log file and changes the server health state to <tt>Warning</tt> after the average free memory reaches 5% of the initial free memory measured at the server's boot time.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       low_memory_gc_threshold => '5'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:low_memory_gc_threshold']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### low_memory_granularity_level<a name='wls_server_template_low_memory_granularity_level'>

The granularity level (in percent) that this server uses for logging low memory conditions and changing the server health state to <tt>Warning</tt>.  For example, if you specify 5 and the average free memory drops by 5% or more over two measured intervals, the server logs a low memory warning in the log file and changes the server health state to <tt>Warning</tt>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       low_memory_granularity_level => '5'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:low_memory_granularity_level']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### low_memory_sample_size<a name='wls_server_template_low_memory_sample_size'>

The number of times this server samples free memory during the time period specified by LowMemoryTimeInterval.  Increasing the sample size can improve the accuracy of the reading.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       low_memory_sample_size => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:low_memory_sample_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### low_memory_time_interval<a name='wls_server_template_low_memory_time_interval'>

The amount of time (in seconds) that defines the interval over which this server determines average free memory values.  By default, the server obtains an average free memory value every 3600 seconds.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       low_memory_time_interval => '3600'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:low_memory_time_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### machine<a name='wls_server_template_machine'>

The WebLogic Server host computer (machine) on which this server is meant to run.  If you want to use Node Manager to start this server, you must assign the server to a machine and you must configure the machine for Node Manager.  You cannot change this value if a server instance is already running.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       machine => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:machine']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### managed_server_independence_enabled<a name='wls_server_template_managed_server_independence_enabled'>

Specifies whether this Managed Server can be started when the Administration Server is unavailable.  In such a case, the Managed Server retrieves its configuration by reading a configuration file and other files directly.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       managed_server_independence_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:managed_server_independence_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### max_com_message_size<a name='wls_server_template_max_com_message_size'>

The maximum number of bytes allowed in messages that are received over the COM protocol. If you configure custom network channels for this server, each channel can override this maximum message size.  This maximum message size helps guard against a denial of service attack in which a caller attempts to force the server to allocate more memory than is available thereby keeping the server from responding quickly to other requests.  A value of -1 causes the COM protocol to use the maximums that are specified elsewhere along the order of precedence.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_com_message_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_com_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_concurrent_long_running_requests<a name='wls_server_template_max_concurrent_long_running_requests'>

The maximum number of running long-running requests that can be submitted to all the Managed Executor Services or Managed Scheduled Executor Services in the server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_concurrent_long_running_requests => '100'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_concurrent_long_running_requests']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_concurrent_new_threads<a name='wls_server_template_max_concurrent_new_threads'>

The maximum number of running threads that can be created by all the Managed Thread Factories in the server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_concurrent_new_threads => '100'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_concurrent_new_threads']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_http_message_size<a name='wls_server_template_max_http_message_size'>

The maximum number of bytes allowed in messages that are received over the HTTP protocol. If you configure custom network channels for this server, each channel can override this maximum message size.  This maximum message size helps guard against a denial of service attack in which a caller attempts to force the server to allocate more memory than is available thereby keeping the server from responding quickly to other requests.  A value of -1 causes the HTTP protocol to use the maximums that are specified elsewhere along the order of precedence.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_http_message_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_http_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_iiop_message_size<a name='wls_server_template_max_iiop_message_size'>

The maximum number of bytes allowed in messages that are received over the IIOP protocol. If you configure custom network channels for this server, each channel can override this maximum message size.  This maximum message size helps guard against a denial of service attack in which a caller attempts to force the server to allocate more memory than is available thereby keeping the server from responding quickly to other requests.  A value of -1 causes the IIOP protocol to use the maximums that are specified elsewhere along the order of precedence.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_iiop_message_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_iiop_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_message_size<a name='wls_server_template_max_message_size'>

The maximum number of bytes allowed in messages that are received over all supported protocols, unless overridden by a protocol-specific setting or a custom channel setting.  The order of precedence for setting message size maximums is as follows:  <ol> <li> A channel-wide maximum in a custom network channel. </li>  <li> A protocol-specific setting in the default network channel. <br/>See<ul> <li>{@link #getMaxCOMMessageSize() getMaxCOMMessageSize}</li> <li>{@link #getMaxHTTPMessageSize() getMaxHTTPMessageSize}</li> <li>{@link #getMaxIIOPMessageSize() getMaxIIOPessageSize}</li> <li>{@link #getMaxT3MessageSize() getMaxT3MessageSize}</li> </ul> </li>  <li> The message maximum in this attribute. </li> </ol>  This maximum message size helps guard against a denial of service attack in which a caller attempts to force the server to allocate more memory than is available thereby keeping the server from responding quickly to other requests. A client can set this value using the <code>-Dweblogic.MaxMessageSize</code> property.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_message_size => '10000000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_open_sock_count<a name='wls_server_template_max_open_sock_count'>

The maximum number of open sockets allowed in server at a given point of time.  When the maximum threshold is reached, the server stops accepting new requests until the number of sockets drops below the threshold.  A value less than <code>0</code> indicates an unlimited size.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_open_sock_count => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_open_sock_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### max_t3_message_size<a name='wls_server_template_max_t3_message_size'>

The maximum number of bytes allowed in messages that are received over the T3 protocol. If you configure custom network channels for this server, each channel can override this maximum message size.  This maximum message size helps guard against a denial of service attack in which a caller attempts to force the server to allocate more memory than is available thereby keeping the server from responding quickly to other requests.  A value of -1 causes the T3 protocol to use the maximums that are specified elsewhere along the order of precedence.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       max_t3_message_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:max_t3_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### message_id_prefix_enabled<a name='wls_server_template_message_id_prefix_enabled'>

Indicates whether message IDs in logged messages will include a prefix. Message ids are 6 digit numeric strings that can be optionally presented in a log entry with a prefix. The prefix used by server messages is "BEA-".

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       message_id_prefix_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:message_id_prefix_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### messaging_bridge_thread_pool_size<a name='wls_server_template_messaging_bridge_thread_pool_size'>

Returns the size of the messaging bridge execute thread pool.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       messaging_bridge_thread_pool_size => '5'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:messaging_bridge_thread_pool_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### msi_file_replication_enabled<a name='wls_server_template_msi_file_replication_enabled'>

Specifies whether the Administration Server replicates its configuration files to this Managed Server.  With file replication enabled, the Administration Server copies its configuration file and <code>SerializedSystemIni.dat</code> into the Managed Server's root directory every 5 minutes. This option does not replicate a boot identity file.  Regardless of the name of the configuration file that you used to start the Administration Server, the replicated file is always named <code>msi-config.xml</code>. For example, if you specified <code>-Dweblogic.ConfigFile=MyConfig.xml</code> when you started the Administration Server, if you have enabled file replication, the Administration Server copies <code>MyConfig.xml</code> and names the copy <code>msi-config.xml</code>.  Depending on your backup schemes and the frequency with which you update your domain's configuration, this option might not be worth the performance cost of copying potentially large files across a network.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       msi_file_replication_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:msi_file_replication_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### muxer_class<a name='wls_server_template_muxer_class'>

Non-blocking IO is enabled by default on the server side. The default value is <code>weblogic.socket.NIOSocketMuxer</code>.  The Certicom SSL implementation is not supported with NIOSocketMuxer. If you need to secure internet communication, Oracle recommends enabling JSSE (Java Secure Socket Extension).

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       muxer_class => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:muxer_class']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### name<a name='wls_server_template_name'>

The name.


[Back to overview of wls_server_template](#attributes)


### native_io_enabled<a name='wls_server_template_native_io_enabled'>

Specifies whether native I/O is enabled for the server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       native_io_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:native_io_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### nm_socket_create_timeout_in_millis<a name='wls_server_template_nm_socket_create_timeout_in_millis'>

Returns the timeout value to be used by NodeManagerRuntime when creating a a socket connection to the agent. Default set high as SSH agent may require a high connection establishment time.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       nm_socket_create_timeout_in_millis => '180000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:nm_socket_create_timeout_in_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### notes<a name='wls_server_template_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### num_of_retries_before_msi_mode<a name='wls_server_template_num_of_retries_before_msi_mode'>

Get the number of retries to contact admin server, before starting in Managed Server Independence Mode

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       num_of_retries_before_msi_mode => '3'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:num_of_retries_before_msi_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### outbound_enabled<a name='wls_server_template_outbound_enabled'>

Specifies whether new server-to-server connections may consider the default server channel when initiating a connection. This is only relevant if the connection needs to be bound to the default listen address. This will only work for binary protocols that support both outbound and inbound traffic.  When this feature is not enabled, connections are initiated using a local address selected by the underlying hardware. For the default channel this is usually what is wanted for IP-routing to be effective. Note that since the default is false, other outbound channels will be considered in preference to the default channel.  Default administration channels, created when the domain-wide administration port is turned on, are always considered and bound when initiating an administrative connection. To allow IP-routing for administration traffic create custom admin with {@link NetworkAccessPointMBean#isOutboundEnabled isOutboundEnabled} set to false instead of enabling the domain-wide ADMIN port.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       outbound_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:outbound_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### outbound_private_key_enabled<a name='wls_server_template_outbound_private_key_enabled'>

Specifies whether the SSL identity specified by {@link SSLMBean#getServerPrivateKeyAlias() getSSLMBean#ServerPrivateKeyAlias} for this server should be used for outbound SSL connections on the default server channel. In normal circumstances the outbound identity is determined by the caller's environment.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       outbound_private_key_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:outbound_private_key_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### period_length<a name='wls_server_template_period_length'>

The time interval in milliseconds of the heartbeat period. A value of 0 indicates that heartbeats are turned off.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       period_length => '60000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:period_length']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### preferred_secondary_group<a name='wls_server_template_preferred_secondary_group'>

Defines secondary clustered instances considered for hosting replicas of the primary HTTP session states created on the server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       preferred_secondary_group => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:preferred_secondary_group']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### print_stack_trace_in_production<a name='wls_server_template_print_stack_trace_in_production'>

Specifies whether the server message log includes exception stack trace that are raised in remote systems.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       print_stack_trace_in_production => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:print_stack_trace_in_production']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### provider<a name='wls_server_template_provider'>

The specific backend to use for this `wls_server_template`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage server template for dynamic clusters


[Back to overview of wls_server_template](#attributes)


### reliable_delivery_policy<a name='wls_server_template_reliable_delivery_policy'>

The reliable delivery policy for web services.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       reliable_delivery_policy => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:reliable_delivery_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### replication_group<a name='wls_server_template_replication_group'>

Defines preferred clustered instances considered for hosting replicas of the primary HTTP session states created on the server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       replication_group => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:replication_group']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### replication_ports<a name='wls_server_template_replication_ports'>

When WLS is running on Exalogic machines, cluster replication traffic could go over multiple replication channels. However multiple replication channels need not be configured on each clustered server instance. Only one replication channel with explicit IP-Address needs to be configured for each server and replicationPorts range can be specified for each server. For eg. range 7001-7010 will create 10 replication channels with ports 7001 to 7010 for the given server. These channels inherits all the properties of the configured replication channel except the listen port.Names of these channels will be derived from the configured replication channel with suffic {x} added where x could be 1,2.. as per the number of ports specified. Public ports are same as the listen port for these additional channels.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       replication_ports => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:replication_ports']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### resolve_dns_name<a name='wls_server_template_resolve_dns_name'>

Resolve the listen address to use for all T3 communication

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       resolve_dns_name => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:resolve_dns_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### restart_delay_seconds<a name='wls_server_template_restart_delay_seconds'>

The number of seconds the Node Manager should wait before restarting this server.  After killing a server process, the system might need several seconds to release the TCP port(s) the server was using. If Node Manager attempts to restart the Managed Server while its ports are still active, the startup attempt fails.  If AutoMigration is enabled and RestartDelaySeconds is 0, the RestartDelaySeconds is automatically set to the lease time. This prevents the server from failing to restart after migration when the previous lease is still valid.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       restart_delay_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:restart_delay_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### restart_interval_seconds<a name='wls_server_template_restart_interval_seconds'>

The number of seconds during which this server can be restarted, up to the number of times specified in RestartMax.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       restart_interval_seconds => '3600'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:restart_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### restart_max<a name='wls_server_template_restart_max'>

The number of times that the Node Manager can restart this server within the interval specified in RestartIntervalSeconds.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       restart_max => '2'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:restart_max']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### retry_interval_before_msi_mode<a name='wls_server_template_retry_interval_before_msi_mode'>

Get the number of seconds between the retries to contact admin server, before starting in Managed Server Independence Mode

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       retry_interval_before_msi_mode => '5'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:retry_interval_before_msi_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### reverse_dns_allowed<a name='wls_server_template_reverse_dns_allowed'>

Specifies whether the kernel is allowed to perform reverse DNS lookups.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       reverse_dns_allowed => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:reverse_dns_allowed']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### scattered_reads_enabled<a name='wls_server_template_scattered_reads_enabled'>

Enables scattered reads over NIO socket channels. Enabling this attribute increases efficiency during I/O in environments with high network throughput and should be used only when configuring a WebLogic domain for Oracle Exalogic.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       scattered_reads_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:scattered_reads_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### server_life_cycle_timeout_val<a name='wls_server_template_server_life_cycle_timeout_val'>

Number of seconds a force shutdown operation waits before timing out and killing itself. If the operation does not complete within the configured timeout seconds, the server will shutdown automatically if the state of the server at that time was <code>SHUTTING_DOWN</code>.  A value of <code>0</code> means that the server will wait indefinitely for life cycle operation to complete.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       server_life_cycle_timeout_val => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:server_life_cycle_timeout_val']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### server_version<a name='wls_server_template_server_version'>

The release identifier for the server. Since this is a configured attribute it is only as accurate as the configuration. The form of the version is major.minor.servicepack.rollingpatch. Not all parts of the version are required. i.e. "7" is acceptable.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       server_version => 'unknown'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:server_version']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### socket_buffer_size_as_chunk_size<a name='wls_server_template_socket_buffer_size_as_chunk_size'>

Specifies whether the server's buffer size for sending or receiving data through a raw socket should be set to 4KB.  Otherwise, the server does not impose a limit to the buffer size and defers to the operating system. This option is useful only on some operating systems for improving performance. It should be disabled in most environments.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       socket_buffer_size_as_chunk_size => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:socket_buffer_size_as_chunk_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### socket_readers<a name='wls_server_template_socket_readers'>

The number of socket reader threads

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       socket_readers => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:socket_readers']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_accept_kss_demo_certs_enabled<a name='wls_server_template_ssl_accept_kss_demo_certs_enabled'>



An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_accept_kss_demo_certs_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_accept_kss_demo_certs_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_allow_unencrypted_null_cipher<a name='wls_server_template_ssl_allow_unencrypted_null_cipher'>

Test if the AllowUnEncryptedNullCipher is enabled see <code>setAllowUnencryptedNullCipher(boolean enable)</code> for the NullCipher feature.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_allow_unencrypted_null_cipher => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_allow_unencrypted_null_cipher']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_cert_authenticator<a name='wls_server_template_ssl_cert_authenticator'>

The name of the Java class that implements the <code>weblogic.security.acl.CertAuthenticator</code> class, which is deprecated in this release of WebLogic Server. This field is for Compatibility security only, and is only used when the Realm Adapter Authentication provider is configured.  The <code>weblogic.security.acl.CertAuthenticator</code> class maps the digital certificate of a client to a WebLogic Server user. The class has an <code>authenticate()</code> method that WebLogic Server calls after validating the digital certificate presented by the client.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_cert_authenticator => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_cert_authenticator']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_ciphersuites<a name='wls_server_template_ssl_ciphersuites'>

Indicates the cipher suites being used on a particular WebLogic Server.  The strongest negotiated cipher suite is chosen during the SSL handshake. The set of cipher suites used by default by JSEE depends on the specific JDK version with which WebLogic Server is configured.  For a list of possible values, see <a href="http://www.oracle.com/pls/topic/lookup?ctx=fmw121300&id=SECMG502">Cipher Suites.</a>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_ciphersuites => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_ciphersuites']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_client_cert_alias<a name='wls_server_template_ssl_client_cert_alias'>

Determines the alias of the client SSL certificate to be used as identity for outbound SSL connections. The certificate is assumed to be stored in the server configured keystore. <p/> Note that to use the client SSL certificate, <code>{@link #setUseClientCertForOutbound}</code> must be enabled.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_client_cert_alias => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_client_cert_alias']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_client_cert_private_key_pass_phrase<a name='wls_server_template_ssl_client_cert_private_key_pass_phrase'>

The passphrase used to retrieve the private key for the client SSL certificate specified in <code>{@link #getClientCertAlias}</code> from the server configured keystore. This passphrase is assigned to the private key when the private key is generated. <p/> Note that this attribute is usually used when outbound SSL connections specify a client SSL certificate identity. <p/> Note that when you get the value of this attribute, WebLogic Server does the following: <ol> <li>Retrieves the value of the <code>ClientCertPrivateKeyPassPhraseEncrypted</code> attribute. <li>Decrypts the value and returns the unencrypted passphrase. </ol>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_client_cert_private_key_pass_phrase => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_client_cert_private_key_pass_phrase']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_client_certificate_enforced<a name='wls_server_template_ssl_client_certificate_enforced'>

Indicates whether or not clients must present digital certificates from a trusted certificate authority to WebLogic Server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_client_certificate_enforced => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_client_certificate_enforced']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_enabled<a name='wls_server_template_ssl_enabled'>

Indicates whether the server can be reached through the default SSL listen port.  If the administration port is enabled for the WebLogic Server domain, then administrative traffic travels over the administration port and application traffic travels over the Listen Port and SSL Listen Port. If the administration port is disabled, then all traffic travels over the Listen Port and SSL Listen Port.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_export_key_lifespan<a name='wls_server_template_ssl_export_key_lifespan'>

Indicates the number of times WebLogic Server can use an exportable key between a domestic server and an exportable client before generating a new key. The more secure you want WebLogic Server to be, the fewer times the key should be used before generating a new key.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_export_key_lifespan => '500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_export_key_lifespan']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_hostname_verification_ignored<a name='wls_server_template_ssl_hostname_verification_ignored'>

Specifies whether to ignore the installed implementation of the <code>weblogic.security.SSL.HostnameVerifier</code> interface (when this server is acting as a client to another application server).

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_hostname_verification_ignored => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_hostname_verification_ignored']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_hostname_verifier<a name='wls_server_template_ssl_hostname_verifier'>

The name of the class that implements the <code>weblogic.security.SSL.HostnameVerifier</code> interface.  This class verifies whether the connection to the host with the hostname from URL should be allowed. The class is used to prevent man-in-the-middle attacks. The <code>weblogic.security.SSL.HostnameVerifier</code> has a <code>verify()</code> method that WebLogic Server calls on the client during the SSL handshake.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_hostname_verifier => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_hostname_verifier']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_identity_and_trust_locations<a name='wls_server_template_ssl_identity_and_trust_locations'>

Indicates where SSL should find the server's identity (certificate and private key) as well as the server's trust (trusted CAs).  <ul> <li> If set to <code>KEYSTORES</code>, then SSL retrieves the identity and trust from the server's keystores (that are configured on the Server). </li>  <li> If set to <code>FILES_OR_KEYSTORE_PROVIDERS</code>, then SSL first looks in the deprecated KeyStore providers for the identity and trust. If not found, then it looks in the flat files indicated by the SSL Trusted CA File Name, Server Certificate File Name, and Server Key File Name attributes. </li> </ul>  Domains created in WebLogic Server version 8.1 or later, default to <code>KEYSTORES</code>. Domains created before WebLogic Server version 8.1, default to <code>FILES_OR_KEYSTORE_PROVIDERS.</code>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_identity_and_trust_locations => 'KeyStores'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_identity_and_trust_locations']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_inbound_certificate_validation<a name='wls_server_template_ssl_inbound_certificate_validation'>

Indicates the client certificate validation rules for inbound SSL.  This attribute only applies to ports and network channels using 2-way SSL.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_inbound_certificate_validation => 'BuiltinSSLValidationOnly'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_inbound_certificate_validation']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_jsse_enabled<a name='wls_server_template_ssl_jsse_enabled'>

Determines whether the SSL implementation in Weblogic Server is JSSE based.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_jsse_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_jsse_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_listen_port<a name='wls_server_template_ssl_listen_port'>

The TCP/IP port at which this server listens for SSL connection requests.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_listen_port => '7002'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_login_timeout_millis<a name='wls_server_template_ssl_login_timeout_millis'>

Specifies the number of milliseconds that WebLogic Server waits for an SSL connection before timing out. SSL connections take longer to negotiate than regular connections.  If clients are connecting over the Internet, raise the default number to accommodate additional network latency.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_login_timeout_millis => '25000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_login_timeout_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_minimum_tls_protocol_version<a name='wls_server_template_ssl_minimum_tls_protocol_version'>

Get the minimum SSL/TLS protocol version currently configured.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_minimum_tls_protocol_version => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_minimum_tls_protocol_version']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_notes<a name='wls_server_template_ssl_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_outbound_certificate_validation<a name='wls_server_template_ssl_outbound_certificate_validation'>

Indicates the server certificate validation rules for outbound SSL.  This attribute always applies to outbound SSL that is part of WebLogic Server (that is, an Administration Server talking to the Node Manager). It does not apply to application code in the server that is using outbound SSL unless the application code uses a <code>weblogic.security.SSL.ServerTrustManager</code> that is configured to use outbound SSL validation.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_outbound_certificate_validation => 'BuiltinSSLValidationOnly'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_outbound_certificate_validation']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_outbound_private_key_alias<a name='wls_server_template_ssl_outbound_private_key_alias'>

The string alias used to store and retrieve the outbound private key in the keystore. This private key is associated with either a server or a client digital certificate. This attribute value is derived from other settings and cannot be physically set.   The returned value is determined as follows: <ul> <li>If the <code>{@link #isUseClientCertForOutbound}</code> returns true, the value from <code>{@link #getClientCertAlias}</code> is returned. <li> Otherwise, the value from <code>{@link #getServerPrivateKeyAlias}</code> is returned. </ul>

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_outbound_private_key_alias => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_outbound_private_key_alias']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_rejection_logging_enabled<a name='wls_server_template_ssl_rejection_logging_enabled'>

Indicates whether warning messages are logged in the server log when SSL connections are rejected.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_rejection_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_rejection_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_server_certificate_chain_file_name<a name='wls_server_template_ssl_server_certificate_chain_file_name'>

The full directory location and name of the file containing an ordered list of certificate authorities trusted by WebLogic Server.  The <code>.pem</code> file extension indicates that method that should be used to read the file. Note that as of WebLogic Server version 7.0, the digital certificate for WebLogic Server should not be stored in a file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_server_certificate_chain_file_name => 'server-certchain.pem'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_server_certificate_chain_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_server_certificate_file_name<a name='wls_server_template_ssl_server_certificate_file_name'>

The full directory location of the digital certificate file (<code>.der</code> or <code>.pem</code>) for the server.  The pathname should either be absolute or relative to the directory from which the server is booted. This field provides backward compatibility for security configurations that stored digital certificates in files.  The file extension ( <code>.der</code> or <code>.pem</code>) tells WebLogic Server how to read the contents of the file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_server_certificate_file_name => 'server-cert.der'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_server_certificate_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_server_key_file_name<a name='wls_server_template_ssl_server_key_file_name'>

The full directory location of the private key file (<code>.der</code> or <code>.pem</code>) for the server.  The pathname should either be absolute or relative to the directory from which the server is booted. This field provides backward compatibility for security configurations that store private keys in files. For a more secure deployment, Oracle recommends saving private keys in keystores.  The file extension (<code>.der</code> or <code>.pem</code>) indicates the method that should be used to read the file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_server_key_file_name => 'server-key.der'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_server_key_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_server_private_key_alias<a name='wls_server_template_ssl_server_private_key_alias'>

The string alias used to store and retrieve the server's private key in the keystore. This private key is associated with the server's digital certificate.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_server_private_key_alias => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_server_private_key_alias']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_server_private_key_pass_phrase<a name='wls_server_template_ssl_server_private_key_pass_phrase'>

The passphrase used to retrieve the server's private key from the keystore. This passphrase is assigned to the private key when it is generated.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_server_private_key_pass_phrase => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_server_private_key_pass_phrase']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_ss_lv2_hello_enabled<a name='wls_server_template_ssl_ss_lv2_hello_enabled'>

Indicate whether SSLv2Hello is enabled

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_ss_lv2_hello_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_ss_lv2_hello_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_tags<a name='wls_server_template_ssl_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_trusted_ca_file_name<a name='wls_server_template_ssl_trusted_ca_file_name'>

The full directory location of the file that specifies the certificate authorities trusted by the server.  The pathname should either be absolute or relative to the directory from which the server is booted. This field provides backward compatibility for security configurations that store trusted certificate authorities in files.  The file specified in this attribute can contain a single digital certificate or multiple digital certificates. The file extension ( <code>.der</code> or <code>.pem</code>) tells WebLogic Server how to read the contents of the file.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_trusted_ca_file_name => 'trusted-ca.pem'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_trusted_ca_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### ssl_two_way_ssl_enabled<a name='wls_server_template_ssl_two_way_ssl_enabled'>

The form of SSL that should be used.  By default, WebLogic Server is configured to use one-way SSL (implied by the <code>Client Certs Not Requested</code> value). Selecting <code>Client Certs Requested But Not Enforced</code> enables two-way SSL. With this option, the server requests a certificate from the client, but the connection continues if the client does not present a certificate. Selecting <code>Client Certs Requested And Enforced</code> also enables two-way SSL and requires a client to present a certificate. However, if a certificate is not presented, the SSL connection is terminated.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_two_way_ssl_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_two_way_ssl_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_use_client_cert_for_outbound<a name='wls_server_template_ssl_use_client_cert_for_outbound'>

Determines whether to use the configured client SSL certificate as identity for outbound SSL connections. <p/> Note that to use a client SSL certificate, one must be specified in <code>{@link #setClientCertAlias}</code>.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_use_client_cert_for_outbound => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_use_client_cert_for_outbound']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### ssl_use_server_certs<a name='wls_server_template_ssl_use_server_certs'>

Sets whether the client should use the server certificates/key as the client identity when initiating an outbound connection over https.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       ssl_use_server_certs => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:ssl_use_server_certs']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### sslenabled<a name='wls_server_template_sslenabled'>

The ssl enabled on the server

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_server_template](#attributes)


### ssllistenport<a name='wls_server_template_ssllistenport'>

The server ssl port


[Back to overview of wls_server_template](#attributes)


### staging_directory_name<a name='wls_server_template_staging_directory_name'>

The directory path on the Managed Server where all staged (prepared) applications are placed.  If an absolute directory name is not specified, the path is relative to the root directory "/". Once configured, you cannot change the staging directory name. Remove all applications from the server prior to changing this attribute. The default staging directory is "stage", relative to the server root.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       staging_directory_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:staging_directory_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### staging_mode<a name='wls_server_template_staging_mode'>

The mode that specifies whether an application's files are copied from a source on the Administration Server to the Managed Server's staging area during application preparation.  During application preparation, the application's files are copied from the source on the Administration Server to the Managed Server's staging area. If you specify <code>nostage</code> or <code>external_stage</code>, the copy will not occur. This is useful when the staging area is a shared directory, already containing the application files, or if this is a single server domain. The administrator must ensure that the Managed Server's staging directory is set appropriately. Deployment errors will result if the application is not available during the preparation or activation of the application. Each application can override the staging mode specified here.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       staging_mode => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:staging_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### startup_mode<a name='wls_server_template_startup_mode'>

The state in which this server should be started. If you specify <tt>STANDBY</tt>, you must also enable the domain-wide administration port.  In the <code>RUNNING</code> state, a server offers its services to clients and can operate as a full member of a cluster. In the <code>ADMIN</code> state, the server is up and running, but available only for administration operations, allowing you to perform server and application-level administration tasks without risk to running applications. In the <code>STANDBY</code> state, a server instance does not process any request; its regular Listen Port is closed. The Administration Port is open. It only accepts life cycle commands that transition the server instance to either the <code>RUNNING</code> or the <code>SHUTDOWN</code> state. Other Administration requests are not accepted. A <code>STANDBY</code> server's only purpose is to resume into the <code>RUNNING</code> state quickly; it saves server startup time.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       startup_mode => 'RUNNING'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:startup_mode']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### startup_timeout<a name='wls_server_template_startup_timeout'>

Timeout value for server start and resume operations. If the server fails to start in the timeout period, it will force shutdown.  A value of <code>0</code> means that the server will wait indefinitely for the operation to complete.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       startup_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:startup_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### stuck_thread_max_time<a name='wls_server_template_stuck_thread_max_time'>

The number of seconds that a thread must be continually working before this server considers the thread stuck.  For example, if you set this to 600 seconds, WebLogic Server considers a thread to be "stuck" after 600 seconds of continuous use.  In Web Logic Server 9.x and later, it is recommended that you use the ServerFailureTriggerMBean in the OverloadProtectionMBean. The ServerFailureTriggerMBean transitions the server to a FAILED state after the specified number of stuck threads are detected. The OverloadProtectionMBean has options to suspend or shutdown a failed server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       stuck_thread_max_time => '600'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:stuck_thread_max_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### stuck_thread_timer_interval<a name='wls_server_template_stuck_thread_timer_interval'>

The number of seconds after which WebLogic Server periodically scans threads to see if they have been continually working for the configured maximum length of time.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       stuck_thread_timer_interval => '60'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:stuck_thread_timer_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### tags<a name='wls_server_template_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### template_name<a name='wls_server_template_template_name'>

The server template name


[Back to overview of wls_server_template](#attributes)


### tgiop_enabled<a name='wls_server_template_tgiop_enabled'>

Specifies whether this server supports Tuxedo GIOP (TGIOP) requests. (Requires you to configure WebLogic Tuxedo Connector (WTC) for this server.)

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       tgiop_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:tgiop_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### thread_pool_percent_socket_readers<a name='wls_server_template_thread_pool_percent_socket_readers'>

The percentage of execute threads from the default queue that can be used as socket readers.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       thread_pool_percent_socket_readers => '33'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:thread_pool_percent_socket_readers']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### timeout<a name='wls_server_template_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_server_template](#attributes)


### transaction_log_file_prefix<a name='wls_server_template_transaction_log_file_prefix'>

The path prefix for the server's JTA transaction log files. If the pathname is not absolute, the path is assumed to be relative to the server's root directory.  For a clustered server, if you plan to be able to migrate the Transaction Recovery Service from this server if it fails to another server (backup server) in the same cluster, you must store transaction log files on persistent storage, such as a Storage Area Network (SAN) device or a dual-ported disk, available to both servers.  Do not use an NFS file system to store transaction log files. Because of the caching scheme in NFS, transaction log files on disk may not always be current. Using transaction log files stored on an NFS device for recovery may cause data corruption.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       transaction_log_file_prefix => './'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:transaction_log_file_prefix']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### transaction_log_file_write_policy<a name='wls_server_template_transaction_log_file_write_policy'>

The policy that determines how transaction log file entries are written to disk. This policy can affect transaction performance. (Note: To be transactionally safe, the Direct-Write policy may require additional OS or environment changes on some Windows systems.)  WebLogic Server supports the following policies:  <ul> <li> Cache-Flush. Flushes operating system and on-disk caches after each write. </li>  <li> Direct-Write. Tells the operating system to write directly to disk with each write. Direct-Write performs better than Cache-Flush. </li> </ul>  If Direct-Write is not supported on the host platform, the policy becomes Cache-Flush and a log message is printed.  Note: On Windows, the "Direct-Write" policy may leave transaction data in the on-disk cache without writing it to disk immediately. This is not transactionally safe because a power failure can cause loss of on-disk cache data. For transactionally safe writes using "Direct-Write" on Windows, either disable all write caching for the disk (enabled by default), or use a disk with a battery-backed cache.  The on-disk cache for a hard-drive on Windows can be disabled through system administration: Control-Panel -&gt; System -&gt; Hardware-tab -&gt; Device-Manager-button -&gt; Disk-Drives -&gt; name-of-drive -&gt; Policies-tab -&gt; "Enable write caching on the disk" check-box. Some file systems do not allow this value to be changed. For example, a RAID system that has a reliable cache.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       transaction_log_file_write_policy => 'Direct-Write'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:transaction_log_file_write_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### tunneling_client_ping_secs<a name='wls_server_template_tunneling_client_ping_secs'>

The interval (in seconds) at which to ping a tunneled client to see if it is still alive.  If you create network channels for this server, each channel can override this setting.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       tunneling_client_ping_secs => '45'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:tunneling_client_ping_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### tunneling_client_timeout_secs<a name='wls_server_template_tunneling_client_timeout_secs'>

The amount of time (in seconds) after which a missing tunneled client is considered dead.  If you create network channels for this server, each channel can override this setting.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       tunneling_client_timeout_secs => '40'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:tunneling_client_timeout_secs']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### tunneling_enabled<a name='wls_server_template_tunneling_enabled'>

Specifies whether tunneling for the T3, T3S, HTTP, HTTPS, IIOP, and IIOPS protocols should be enabled for this server.  If you create network channels for this server, each channel can override this setting.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       tunneling_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:tunneling_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### upload_directory_name<a name='wls_server_template_upload_directory_name'>

The directory path on the Administration Server where all uploaded applications are placed.  If an absolute directory name is not specified, the path is relative to the root directory "/". The default staging directory is "stage", relative to the server root. On the Managed Server this returns null, and is not configurable.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       upload_directory_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:upload_directory_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### use81_style_execute_queues<a name='wls_server_template_use81_style_execute_queues'>

Backward compatibility mode to switch to 8.1 execute queues instead of WorkManagers. Each of the WorkManagers is converted to an individual execute queue. Setting this attribute requires a server restart.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       use81_style_execute_queues => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:use81_style_execute_queues']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### use_concurrent_queue_for_request_manager<a name='wls_server_template_use_concurrent_queue_for_request_manager'>

Reduces lock contention by using concurrent buffer queue to park incoming requests. Enabling this attribute increases throughput as requests are scheduled with out acquiring any locks.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       use_concurrent_queue_for_request_manager => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:use_concurrent_queue_for_request_manager']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### use_detailed_thread_name<a name='wls_server_template_use_detailed_thread_name'>

Whether to includes detail information in self-tuning thread pool thread names. Setting this flag on would include additional information such as the name of the work manager that the execute thread is executing task for, but at the expense of overhead in keeping the thread name updated with such information.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       use_detailed_thread_name => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:use_detailed_thread_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### use_enhanced_increment_advisor<a name='wls_server_template_use_enhanced_increment_advisor'>

Whether the self-tuning should use the enhanced IncrementAdvisor implementation that uses a different algorithm to adjust the size of the self-tuning thread pool.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       use_enhanced_increment_advisor => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:use_enhanced_increment_advisor']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### use_enhanced_priority_queue_for_request_manager<a name='wls_server_template_use_enhanced_priority_queue_for_request_manager'>

Reduces lock contention by using the enhanced ConcurrentCalendarQueue as the priority based queue for pending requests that are waiting for a thread  This attribute should be enabled only in an Oracle Exalogic environment.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       use_enhanced_priority_queue_for_request_manager => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:use_enhanced_priority_queue_for_request_manager']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### use_fusion_for_llr<a name='wls_server_template_use_fusion_for_llr'>

Enables the use of the <code>ADM_DDL </code> store procedure for LLR. The default value is <code>false</code> (not enabled).  When enabled, a  <code>WLS_</code> prefix and <code>_DYD</code> suffix is is automatically added to the LLR table name at runtime so the LLR table name in server configuration is not consistent with the actual table name in database.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       use_fusion_for_llr => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:use_fusion_for_llr']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### verbose_ejb_deployment_enabled<a name='wls_server_template_verbose_ejb_deployment_enabled'>

Whether or not verbose deployment of EJBs is enabled.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       verbose_ejb_deployment_enabled => 'false'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:verbose_ejb_deployment_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### virtual_machine_name<a name='wls_server_template_virtual_machine_name'>

When WLS is running on JRVE, this specifies the name of the virtual machine running this server

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       virtual_machine_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:virtual_machine_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### weblogic_plugin_enabled<a name='wls_server_template_weblogic_plugin_enabled'>

Specifies whether this server uses the proprietary <tt>WL-Proxy-Client-IP</tt> header, which is recommended if the server instance will receive requests from a proxy plug-in.  If the server instance is a member of a cluster that will receive proxied requests, enable the WebLogic plugin at the cluster level. For servers that are members of a cluster, the setting at the cluster level overrides the server's setting.  When the WebLogic plugin is enabled, a call to <code>getRemoteAddr</code> will return the address of the browser client from the proprietary <code>WL-Proxy-Client-IP</code> header instead of the web server.

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       weblogic_plugin_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:weblogic_plugin_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_server_template](#attributes)


### xml_entity_cache<a name='wls_server_template_xml_entity_cache'>

The server's XML entity cache, which is used to configure the behavior of JAXP (Java API for XML Parsing).

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       xml_entity_cache => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:xml_entity_cache']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)


### xml_registry<a name='wls_server_template_xml_registry'>

The server's XML registry, which is used to configure the behavior of JAXP (Java API for XML Parsing).

An example on how to use this:

    wls_server_template {a_wls_server_template :
       ...
       xml_registry => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_server_template:xml_registry']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_server_template](#attributes)

